# Autogenerated by get_module_idx.py

d = { 'settings': {'lib_path': 'nbdev_numpy'},
  'syms': { 'numpy': { 'numpy.DataSource': 'https://numpy.org/doc/stable/reference/generated/numpy.DataSource.html#numpy.DataSource',
                       'numpy.DataSource.abspath': 'https://numpy.org/doc/stable/reference/generated/numpy.DataSource.abspath.html#numpy.DataSource.abspath',
                       'numpy.DataSource.exists': 'https://numpy.org/doc/stable/reference/generated/numpy.DataSource.exists.html#numpy.DataSource.exists',
                       'numpy.DataSource.open': 'https://numpy.org/doc/stable/reference/generated/numpy.DataSource.open.html#numpy.DataSource.open',
                       'numpy.MachAr': 'https://numpy.org/doc/stable/reference/generated/numpy.MachAr.html#numpy.MachAr',
                       'numpy.all': 'https://numpy.org/doc/stable/reference/generated/numpy.all.html#numpy.all',
                       'numpy.allclose': 'https://numpy.org/doc/stable/reference/generated/numpy.allclose.html#numpy.allclose',
                       'numpy.amax': 'https://numpy.org/doc/stable/reference/generated/numpy.amax.html#numpy.amax',
                       'numpy.amin': 'https://numpy.org/doc/stable/reference/generated/numpy.amin.html#numpy.amin',
                       'numpy.angle': 'https://numpy.org/doc/stable/reference/generated/numpy.angle.html#numpy.angle',
                       'numpy.any': 'https://numpy.org/doc/stable/reference/generated/numpy.any.html#numpy.any',
                       'numpy.append': 'https://numpy.org/doc/stable/reference/generated/numpy.append.html#numpy.append',
                       'numpy.apply_along_axis': 'https://numpy.org/doc/stable/reference/generated/numpy.apply_along_axis.html#numpy.apply_along_axis',
                       'numpy.apply_over_axes': 'https://numpy.org/doc/stable/reference/generated/numpy.apply_over_axes.html#numpy.apply_over_axes',
                       'numpy.arange': 'https://numpy.org/doc/stable/reference/generated/numpy.arange.html#numpy.arange',
                       'numpy.argmax': 'https://numpy.org/doc/stable/reference/generated/numpy.argmax.html#numpy.argmax',
                       'numpy.argmin': 'https://numpy.org/doc/stable/reference/generated/numpy.argmin.html#numpy.argmin',
                       'numpy.argpartition': 'https://numpy.org/doc/stable/reference/generated/numpy.argpartition.html#numpy.argpartition',
                       'numpy.argsort': 'https://numpy.org/doc/stable/reference/generated/numpy.argsort.html#numpy.argsort',
                       'numpy.argwhere': 'https://numpy.org/doc/stable/reference/generated/numpy.argwhere.html#numpy.argwhere',
                       'numpy.around': 'https://numpy.org/doc/stable/reference/generated/numpy.around.html#numpy.around',
                       'numpy.array': 'https://numpy.org/doc/stable/reference/generated/numpy.array.html#numpy.array',
                       'numpy.array2string': 'https://numpy.org/doc/stable/reference/generated/numpy.array2string.html#numpy.array2string',
                       'numpy.array_equal': 'https://numpy.org/doc/stable/reference/generated/numpy.array_equal.html#numpy.array_equal',
                       'numpy.array_equiv': 'https://numpy.org/doc/stable/reference/generated/numpy.array_equiv.html#numpy.array_equiv',
                       'numpy.array_repr': 'https://numpy.org/doc/stable/reference/generated/numpy.array_repr.html#numpy.array_repr',
                       'numpy.array_split': 'https://numpy.org/doc/stable/reference/generated/numpy.array_split.html#numpy.array_split',
                       'numpy.array_str': 'https://numpy.org/doc/stable/reference/generated/numpy.array_str.html#numpy.array_str',
                       'numpy.asanyarray': 'https://numpy.org/doc/stable/reference/generated/numpy.asanyarray.html#numpy.asanyarray',
                       'numpy.asarray': 'https://numpy.org/doc/stable/reference/generated/numpy.asarray.html#numpy.asarray',
                       'numpy.asarray_chkfinite': 'https://numpy.org/doc/stable/reference/generated/numpy.asarray_chkfinite.html#numpy.asarray_chkfinite',
                       'numpy.ascontiguousarray': 'https://numpy.org/doc/stable/reference/generated/numpy.ascontiguousarray.html#numpy.ascontiguousarray',
                       'numpy.asfarray': 'https://numpy.org/doc/stable/reference/generated/numpy.asfarray.html#numpy.asfarray',
                       'numpy.asfortranarray': 'https://numpy.org/doc/stable/reference/generated/numpy.asfortranarray.html#numpy.asfortranarray',
                       'numpy.asmatrix': 'https://numpy.org/doc/stable/reference/generated/numpy.asmatrix.html#numpy.asmatrix',
                       'numpy.atleast_1d': 'https://numpy.org/doc/stable/reference/generated/numpy.atleast_1d.html#numpy.atleast_1d',
                       'numpy.atleast_2d': 'https://numpy.org/doc/stable/reference/generated/numpy.atleast_2d.html#numpy.atleast_2d',
                       'numpy.atleast_3d': 'https://numpy.org/doc/stable/reference/generated/numpy.atleast_3d.html#numpy.atleast_3d',
                       'numpy.average': 'https://numpy.org/doc/stable/reference/generated/numpy.average.html#numpy.average',
                       'numpy.bartlett': 'https://numpy.org/doc/stable/reference/generated/numpy.bartlett.html#numpy.bartlett',
                       'numpy.base_repr': 'https://numpy.org/doc/stable/reference/generated/numpy.base_repr.html#numpy.base_repr',
                       'numpy.binary_repr': 'https://numpy.org/doc/stable/reference/generated/numpy.binary_repr.html#numpy.binary_repr',
                       'numpy.bincount': 'https://numpy.org/doc/stable/reference/generated/numpy.bincount.html#numpy.bincount',
                       'numpy.blackman': 'https://numpy.org/doc/stable/reference/generated/numpy.blackman.html#numpy.blackman',
                       'numpy.block': 'https://numpy.org/doc/stable/reference/generated/numpy.block.html#numpy.block',
                       'numpy.bmat': 'https://numpy.org/doc/stable/reference/generated/numpy.bmat.html#numpy.bmat',
                       'numpy.bool_': 'https://numpy.org/doc/stable/reference/arrays.scalars.html#numpy.bool_',
                       'numpy.broadcast': 'https://numpy.org/doc/stable/reference/generated/numpy.broadcast.html#numpy.broadcast',
                       'numpy.broadcast.reset': 'https://numpy.org/doc/stable/reference/generated/numpy.broadcast.reset.html#numpy.broadcast.reset',
                       'numpy.broadcast_arrays': 'https://numpy.org/doc/stable/reference/generated/numpy.broadcast_arrays.html#numpy.broadcast_arrays',
                       'numpy.broadcast_shapes': 'https://numpy.org/doc/stable/reference/generated/numpy.broadcast_shapes.html#numpy.broadcast_shapes',
                       'numpy.broadcast_to': 'https://numpy.org/doc/stable/reference/generated/numpy.broadcast_to.html#numpy.broadcast_to',
                       'numpy.busday_count': 'https://numpy.org/doc/stable/reference/generated/numpy.busday_count.html#numpy.busday_count',
                       'numpy.busday_offset': 'https://numpy.org/doc/stable/reference/generated/numpy.busday_offset.html#numpy.busday_offset',
                       'numpy.busdaycalendar': 'https://numpy.org/doc/stable/reference/generated/numpy.busdaycalendar.html#numpy.busdaycalendar',
                       'numpy.byte': 'https://numpy.org/doc/stable/reference/arrays.scalars.html#numpy.byte',
                       'numpy.byte_bounds': 'https://numpy.org/doc/stable/reference/generated/numpy.byte_bounds.html#numpy.byte_bounds',
                       'numpy.bytes_': 'https://numpy.org/doc/stable/reference/arrays.scalars.html#numpy.bytes_',
                       'numpy.can_cast': 'https://numpy.org/doc/stable/reference/generated/numpy.can_cast.html#numpy.can_cast',
                       'numpy.cdouble': 'https://numpy.org/doc/stable/reference/arrays.scalars.html#numpy.cdouble',
                       'numpy.char': 'https://numpy.org/doc/stable/reference/routines.char.html#module-numpy.char',
                       'numpy.chararray': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.html#numpy.chararray',
                       'numpy.chararray.all': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.all.html#numpy.chararray.all',
                       'numpy.chararray.any': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.any.html#numpy.chararray.any',
                       'numpy.chararray.argmax': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.argmax.html#numpy.chararray.argmax',
                       'numpy.chararray.argmin': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.argmin.html#numpy.chararray.argmin',
                       'numpy.chararray.argpartition': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.argpartition.html#numpy.chararray.argpartition',
                       'numpy.chararray.argsort': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.argsort.html#numpy.chararray.argsort',
                       'numpy.chararray.astype': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.astype.html#numpy.chararray.astype',
                       'numpy.chararray.byteswap': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.byteswap.html#numpy.chararray.byteswap',
                       'numpy.chararray.capitalize': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.capitalize.html#numpy.chararray.capitalize',
                       'numpy.chararray.center': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.center.html#numpy.chararray.center',
                       'numpy.chararray.choose': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.choose.html#numpy.chararray.choose',
                       'numpy.chararray.clip': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.clip.html#numpy.chararray.clip',
                       'numpy.chararray.compress': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.compress.html#numpy.chararray.compress',
                       'numpy.chararray.conj': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.conj.html#numpy.chararray.conj',
                       'numpy.chararray.conjugate': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.conjugate.html#numpy.chararray.conjugate',
                       'numpy.chararray.copy': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.copy.html#numpy.chararray.copy',
                       'numpy.chararray.count': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.count.html#numpy.chararray.count',
                       'numpy.chararray.cumprod': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.cumprod.html#numpy.chararray.cumprod',
                       'numpy.chararray.cumsum': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.cumsum.html#numpy.chararray.cumsum',
                       'numpy.chararray.decode': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.decode.html#numpy.chararray.decode',
                       'numpy.chararray.diagonal': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.diagonal.html#numpy.chararray.diagonal',
                       'numpy.chararray.dot': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.dot.html#numpy.chararray.dot',
                       'numpy.chararray.dump': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.dump.html#numpy.chararray.dump',
                       'numpy.chararray.dumps': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.dumps.html#numpy.chararray.dumps',
                       'numpy.chararray.encode': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.encode.html#numpy.chararray.encode',
                       'numpy.chararray.endswith': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.endswith.html#numpy.chararray.endswith',
                       'numpy.chararray.expandtabs': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.expandtabs.html#numpy.chararray.expandtabs',
                       'numpy.chararray.fill': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.fill.html#numpy.chararray.fill',
                       'numpy.chararray.find': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.find.html#numpy.chararray.find',
                       'numpy.chararray.flatten': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.flatten.html#numpy.chararray.flatten',
                       'numpy.chararray.getfield': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.getfield.html#numpy.chararray.getfield',
                       'numpy.chararray.index': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.index.html#numpy.chararray.index',
                       'numpy.chararray.isalnum': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.isalnum.html#numpy.chararray.isalnum',
                       'numpy.chararray.isalpha': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.isalpha.html#numpy.chararray.isalpha',
                       'numpy.chararray.isdecimal': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.isdecimal.html#numpy.chararray.isdecimal',
                       'numpy.chararray.isdigit': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.isdigit.html#numpy.chararray.isdigit',
                       'numpy.chararray.islower': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.islower.html#numpy.chararray.islower',
                       'numpy.chararray.isnumeric': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.isnumeric.html#numpy.chararray.isnumeric',
                       'numpy.chararray.isspace': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.isspace.html#numpy.chararray.isspace',
                       'numpy.chararray.istitle': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.istitle.html#numpy.chararray.istitle',
                       'numpy.chararray.isupper': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.isupper.html#numpy.chararray.isupper',
                       'numpy.chararray.item': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.item.html#numpy.chararray.item',
                       'numpy.chararray.itemset': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.itemset.html#numpy.chararray.itemset',
                       'numpy.chararray.join': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.join.html#numpy.chararray.join',
                       'numpy.chararray.ljust': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.ljust.html#numpy.chararray.ljust',
                       'numpy.chararray.lower': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.lower.html#numpy.chararray.lower',
                       'numpy.chararray.lstrip': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.lstrip.html#numpy.chararray.lstrip',
                       'numpy.chararray.max': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.max.html#numpy.chararray.max',
                       'numpy.chararray.mean': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.mean.html#numpy.chararray.mean',
                       'numpy.chararray.min': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.min.html#numpy.chararray.min',
                       'numpy.chararray.newbyteorder': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.newbyteorder.html#numpy.chararray.newbyteorder',
                       'numpy.chararray.nonzero': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.nonzero.html#numpy.chararray.nonzero',
                       'numpy.chararray.partition': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.partition.html#numpy.chararray.partition',
                       'numpy.chararray.prod': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.prod.html#numpy.chararray.prod',
                       'numpy.chararray.ptp': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.ptp.html#numpy.chararray.ptp',
                       'numpy.chararray.put': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.put.html#numpy.chararray.put',
                       'numpy.chararray.ravel': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.ravel.html#numpy.chararray.ravel',
                       'numpy.chararray.repeat': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.repeat.html#numpy.chararray.repeat',
                       'numpy.chararray.replace': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.replace.html#numpy.chararray.replace',
                       'numpy.chararray.reshape': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.reshape.html#numpy.chararray.reshape',
                       'numpy.chararray.resize': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.resize.html#numpy.chararray.resize',
                       'numpy.chararray.rfind': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.rfind.html#numpy.chararray.rfind',
                       'numpy.chararray.rindex': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.rindex.html#numpy.chararray.rindex',
                       'numpy.chararray.rjust': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.rjust.html#numpy.chararray.rjust',
                       'numpy.chararray.round': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.round.html#numpy.chararray.round',
                       'numpy.chararray.rpartition': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.rpartition.html#numpy.chararray.rpartition',
                       'numpy.chararray.rsplit': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.rsplit.html#numpy.chararray.rsplit',
                       'numpy.chararray.rstrip': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.rstrip.html#numpy.chararray.rstrip',
                       'numpy.chararray.searchsorted': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.searchsorted.html#numpy.chararray.searchsorted',
                       'numpy.chararray.setfield': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.setfield.html#numpy.chararray.setfield',
                       'numpy.chararray.setflags': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.setflags.html#numpy.chararray.setflags',
                       'numpy.chararray.sort': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.sort.html#numpy.chararray.sort',
                       'numpy.chararray.split': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.split.html#numpy.chararray.split',
                       'numpy.chararray.splitlines': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.splitlines.html#numpy.chararray.splitlines',
                       'numpy.chararray.squeeze': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.squeeze.html#numpy.chararray.squeeze',
                       'numpy.chararray.startswith': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.startswith.html#numpy.chararray.startswith',
                       'numpy.chararray.std': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.std.html#numpy.chararray.std',
                       'numpy.chararray.strip': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.strip.html#numpy.chararray.strip',
                       'numpy.chararray.sum': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.sum.html#numpy.chararray.sum',
                       'numpy.chararray.swapaxes': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.swapaxes.html#numpy.chararray.swapaxes',
                       'numpy.chararray.swapcase': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.swapcase.html#numpy.chararray.swapcase',
                       'numpy.chararray.take': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.take.html#numpy.chararray.take',
                       'numpy.chararray.title': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.title.html#numpy.chararray.title',
                       'numpy.chararray.tobytes': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.tobytes.html#numpy.chararray.tobytes',
                       'numpy.chararray.tofile': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.tofile.html#numpy.chararray.tofile',
                       'numpy.chararray.tolist': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.tolist.html#numpy.chararray.tolist',
                       'numpy.chararray.tostring': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.tostring.html#numpy.chararray.tostring',
                       'numpy.chararray.trace': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.trace.html#numpy.chararray.trace',
                       'numpy.chararray.translate': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.translate.html#numpy.chararray.translate',
                       'numpy.chararray.transpose': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.transpose.html#numpy.chararray.transpose',
                       'numpy.chararray.upper': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.upper.html#numpy.chararray.upper',
                       'numpy.chararray.var': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.var.html#numpy.chararray.var',
                       'numpy.chararray.view': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.view.html#numpy.chararray.view',
                       'numpy.chararray.zfill': 'https://numpy.org/doc/stable/reference/generated/numpy.chararray.zfill.html#numpy.chararray.zfill',
                       'numpy.choose': 'https://numpy.org/doc/stable/reference/generated/numpy.choose.html#numpy.choose',
                       'numpy.class.__array__': 'https://numpy.org/doc/stable/reference/arrays.classes.html#numpy.class.__array__',
                       'numpy.class.__array_finalize__': 'https://numpy.org/doc/stable/reference/arrays.classes.html#numpy.class.__array_finalize__',
                       'numpy.class.__array_function__': 'https://numpy.org/doc/stable/reference/arrays.classes.html#numpy.class.__array_function__',
                       'numpy.class.__array_prepare__': 'https://numpy.org/doc/stable/reference/arrays.classes.html#numpy.class.__array_prepare__',
                       'numpy.class.__array_ufunc__': 'https://numpy.org/doc/stable/reference/arrays.classes.html#numpy.class.__array_ufunc__',
                       'numpy.class.__array_wrap__': 'https://numpy.org/doc/stable/reference/arrays.classes.html#numpy.class.__array_wrap__',
                       'numpy.clip': 'https://numpy.org/doc/stable/reference/generated/numpy.clip.html#numpy.clip',
                       'numpy.clongdouble': 'https://numpy.org/doc/stable/reference/arrays.scalars.html#numpy.clongdouble',
                       'numpy.column_stack': 'https://numpy.org/doc/stable/reference/generated/numpy.column_stack.html#numpy.column_stack',
                       'numpy.common_type': 'https://numpy.org/doc/stable/reference/generated/numpy.common_type.html#numpy.common_type',
                       'numpy.complexfloating': 'https://numpy.org/doc/stable/reference/arrays.scalars.html#numpy.complexfloating',
                       'numpy.compress': 'https://numpy.org/doc/stable/reference/generated/numpy.compress.html#numpy.compress',
                       'numpy.concatenate': 'https://numpy.org/doc/stable/reference/generated/numpy.concatenate.html#numpy.concatenate',
                       'numpy.convolve': 'https://numpy.org/doc/stable/reference/generated/numpy.convolve.html#numpy.convolve',
                       'numpy.copy': 'https://numpy.org/doc/stable/reference/generated/numpy.copy.html#numpy.copy',
                       'numpy.copyto': 'https://numpy.org/doc/stable/reference/generated/numpy.copyto.html#numpy.copyto',
                       'numpy.corrcoef': 'https://numpy.org/doc/stable/reference/generated/numpy.corrcoef.html#numpy.corrcoef',
                       'numpy.correlate': 'https://numpy.org/doc/stable/reference/generated/numpy.correlate.html#numpy.correlate',
                       'numpy.count_nonzero': 'https://numpy.org/doc/stable/reference/generated/numpy.count_nonzero.html#numpy.count_nonzero',
                       'numpy.cov': 'https://numpy.org/doc/stable/reference/generated/numpy.cov.html#numpy.cov',
                       'numpy.cross': 'https://numpy.org/doc/stable/reference/generated/numpy.cross.html#numpy.cross',
                       'numpy.csingle': 'https://numpy.org/doc/stable/reference/arrays.scalars.html#numpy.csingle',
                       'numpy.ctypeslib': 'https://numpy.org/doc/stable/reference/routines.ctypeslib.html#module-numpy.ctypeslib',
                       'numpy.cumprod': 'https://numpy.org/doc/stable/reference/generated/numpy.cumprod.html#numpy.cumprod',
                       'numpy.cumsum': 'https://numpy.org/doc/stable/reference/generated/numpy.cumsum.html#numpy.cumsum',
                       'numpy.datetime64': 'https://numpy.org/doc/stable/reference/arrays.scalars.html#numpy.datetime64',
                       'numpy.datetime_as_string': 'https://numpy.org/doc/stable/reference/generated/numpy.datetime_as_string.html#numpy.datetime_as_string',
                       'numpy.datetime_data': 'https://numpy.org/doc/stable/reference/generated/numpy.datetime_data.html#numpy.datetime_data',
                       'numpy.delete': 'https://numpy.org/doc/stable/reference/generated/numpy.delete.html#numpy.delete',
                       'numpy.deprecate': 'https://numpy.org/doc/stable/reference/generated/numpy.deprecate.html#numpy.deprecate',
                       'numpy.deprecate_with_doc': 'https://numpy.org/doc/stable/reference/generated/numpy.deprecate_with_doc.html#numpy.deprecate_with_doc',
                       'numpy.diag': 'https://numpy.org/doc/stable/reference/generated/numpy.diag.html#numpy.diag',
                       'numpy.diag_indices': 'https://numpy.org/doc/stable/reference/generated/numpy.diag_indices.html#numpy.diag_indices',
                       'numpy.diag_indices_from': 'https://numpy.org/doc/stable/reference/generated/numpy.diag_indices_from.html#numpy.diag_indices_from',
                       'numpy.diagflat': 'https://numpy.org/doc/stable/reference/generated/numpy.diagflat.html#numpy.diagflat',
                       'numpy.diagonal': 'https://numpy.org/doc/stable/reference/generated/numpy.diagonal.html#numpy.diagonal',
                       'numpy.diff': 'https://numpy.org/doc/stable/reference/generated/numpy.diff.html#numpy.diff',
                       'numpy.digitize': 'https://numpy.org/doc/stable/reference/generated/numpy.digitize.html#numpy.digitize',
                       'numpy.disp': 'https://numpy.org/doc/stable/reference/generated/numpy.disp.html#numpy.disp',
                       'numpy.distutils': 'https://numpy.org/doc/stable/reference/distutils.html#module-numpy.distutils',
                       'numpy.dot': 'https://numpy.org/doc/stable/reference/generated/numpy.dot.html#numpy.dot',
                       'numpy.double': 'https://numpy.org/doc/stable/reference/arrays.scalars.html#numpy.double',
                       'numpy.dsplit': 'https://numpy.org/doc/stable/reference/generated/numpy.dsplit.html#numpy.dsplit',
                       'numpy.dstack': 'https://numpy.org/doc/stable/reference/generated/numpy.dstack.html#numpy.dstack',
                       'numpy.dtype': 'https://numpy.org/doc/stable/reference/generated/numpy.dtype.html#numpy.dtype',
                       'numpy.dtype.__class_getitem__': 'https://numpy.org/doc/stable/reference/generated/numpy.dtype.__class_getitem__.html#numpy.dtype.__class_getitem__',
                       'numpy.dtype.__ge__': 'https://numpy.org/doc/stable/reference/generated/numpy.dtype.__ge__.html#numpy.dtype.__ge__',
                       'numpy.dtype.__gt__': 'https://numpy.org/doc/stable/reference/generated/numpy.dtype.__gt__.html#numpy.dtype.__gt__',
                       'numpy.dtype.__le__': 'https://numpy.org/doc/stable/reference/generated/numpy.dtype.__le__.html#numpy.dtype.__le__',
                       'numpy.dtype.__lt__': 'https://numpy.org/doc/stable/reference/generated/numpy.dtype.__lt__.html#numpy.dtype.__lt__',
                       'numpy.dtype.__reduce__': 'https://numpy.org/doc/stable/reference/generated/numpy.dtype.__reduce__.html#numpy.dtype.__reduce__',
                       'numpy.dtype.__setstate__': 'https://numpy.org/doc/stable/reference/generated/numpy.dtype.__setstate__.html#numpy.dtype.__setstate__',
                       'numpy.dtype.newbyteorder': 'https://numpy.org/doc/stable/reference/generated/numpy.dtype.newbyteorder.html#numpy.dtype.newbyteorder',
                       'numpy.dual': 'https://numpy.org/doc/stable/reference/routines.dual.html#module-numpy.dual',
                       'numpy.ediff1d': 'https://numpy.org/doc/stable/reference/generated/numpy.ediff1d.html#numpy.ediff1d',
                       'numpy.einsum': 'https://numpy.org/doc/stable/reference/generated/numpy.einsum.html#numpy.einsum',
                       'numpy.einsum_path': 'https://numpy.org/doc/stable/reference/generated/numpy.einsum_path.html#numpy.einsum_path',
                       'numpy.emath': 'https://numpy.org/doc/stable/reference/routines.emath.html#module-numpy.emath',
                       'numpy.empty': 'https://numpy.org/doc/stable/reference/generated/numpy.empty.html#numpy.empty',
                       'numpy.empty_like': 'https://numpy.org/doc/stable/reference/generated/numpy.empty_like.html#numpy.empty_like',
                       'numpy.errstate': 'https://numpy.org/doc/stable/reference/generated/numpy.errstate.html#numpy.errstate',
                       'numpy.errstate.__call__': 'https://numpy.org/doc/stable/reference/generated/numpy.errstate.__call__.html#numpy.errstate.__call__',
                       'numpy.expand_dims': 'https://numpy.org/doc/stable/reference/generated/numpy.expand_dims.html#numpy.expand_dims',
                       'numpy.extract': 'https://numpy.org/doc/stable/reference/generated/numpy.extract.html#numpy.extract',
                       'numpy.eye': 'https://numpy.org/doc/stable/reference/generated/numpy.eye.html#numpy.eye',
                       'numpy.f2py': 'https://numpy.org/doc/stable/f2py/usage.html#module-numpy.f2py',
                       'numpy.fft': 'https://numpy.org/doc/stable/reference/routines.fft.html#module-numpy.fft',
                       'numpy.fill_diagonal': 'https://numpy.org/doc/stable/reference/generated/numpy.fill_diagonal.html#numpy.fill_diagonal',
                       'numpy.find_common_type': 'https://numpy.org/doc/stable/reference/generated/numpy.find_common_type.html#numpy.find_common_type',
                       'numpy.finfo': 'https://numpy.org/doc/stable/reference/generated/numpy.finfo.html#numpy.finfo',
                       'numpy.fix': 'https://numpy.org/doc/stable/reference/generated/numpy.fix.html#numpy.fix',
                       'numpy.flatiter': 'https://numpy.org/doc/stable/reference/generated/numpy.flatiter.html#numpy.flatiter',
                       'numpy.flatiter.copy': 'https://numpy.org/doc/stable/reference/generated/numpy.flatiter.copy.html#numpy.flatiter.copy',
                       'numpy.flatnonzero': 'https://numpy.org/doc/stable/reference/generated/numpy.flatnonzero.html#numpy.flatnonzero',
                       'numpy.flexible': 'https://numpy.org/doc/stable/reference/arrays.scalars.html#numpy.flexible',
                       'numpy.flip': 'https://numpy.org/doc/stable/reference/generated/numpy.flip.html#numpy.flip',
                       'numpy.fliplr': 'https://numpy.org/doc/stable/reference/generated/numpy.fliplr.html#numpy.fliplr',
                       'numpy.flipud': 'https://numpy.org/doc/stable/reference/generated/numpy.flipud.html#numpy.flipud',
                       'numpy.floating': 'https://numpy.org/doc/stable/reference/arrays.scalars.html#numpy.floating',
                       'numpy.format_float_positional': 'https://numpy.org/doc/stable/reference/generated/numpy.format_float_positional.html#numpy.format_float_positional',
                       'numpy.format_float_scientific': 'https://numpy.org/doc/stable/reference/generated/numpy.format_float_scientific.html#numpy.format_float_scientific',
                       'numpy.format_parser': 'https://numpy.org/doc/stable/reference/generated/numpy.format_parser.html#numpy.format_parser',
                       'numpy.from_dlpack': 'https://numpy.org/doc/stable/reference/generated/numpy.from_dlpack.html#numpy.from_dlpack',
                       'numpy.frombuffer': 'https://numpy.org/doc/stable/reference/generated/numpy.frombuffer.html#numpy.frombuffer',
                       'numpy.fromfile': 'https://numpy.org/doc/stable/reference/generated/numpy.fromfile.html#numpy.fromfile',
                       'numpy.fromfunction': 'https://numpy.org/doc/stable/reference/generated/numpy.fromfunction.html#numpy.fromfunction',
                       'numpy.fromiter': 'https://numpy.org/doc/stable/reference/generated/numpy.fromiter.html#numpy.fromiter',
                       'numpy.frompyfunc': 'https://numpy.org/doc/stable/reference/generated/numpy.frompyfunc.html#numpy.frompyfunc',
                       'numpy.fromregex': 'https://numpy.org/doc/stable/reference/generated/numpy.fromregex.html#numpy.fromregex',
                       'numpy.fromstring': 'https://numpy.org/doc/stable/reference/generated/numpy.fromstring.html#numpy.fromstring',
                       'numpy.full': 'https://numpy.org/doc/stable/reference/generated/numpy.full.html#numpy.full',
                       'numpy.full_like': 'https://numpy.org/doc/stable/reference/generated/numpy.full_like.html#numpy.full_like',
                       'numpy.generic': 'https://numpy.org/doc/stable/reference/arrays.scalars.html#numpy.generic',
                       'numpy.generic.__array__': 'https://numpy.org/doc/stable/reference/generated/numpy.generic.__array__.html#numpy.generic.__array__',
                       'numpy.generic.__array_wrap__': 'https://numpy.org/doc/stable/reference/generated/numpy.generic.__array_wrap__.html#numpy.generic.__array_wrap__',
                       'numpy.generic.__reduce__': 'https://numpy.org/doc/stable/reference/generated/numpy.generic.__reduce__.html#numpy.generic.__reduce__',
                       'numpy.generic.__setstate__': 'https://numpy.org/doc/stable/reference/generated/numpy.generic.__setstate__.html#numpy.generic.__setstate__',
                       'numpy.generic.byteswap': 'https://numpy.org/doc/stable/reference/generated/numpy.generic.byteswap.html#numpy.generic.byteswap',
                       'numpy.generic.setflags': 'https://numpy.org/doc/stable/reference/generated/numpy.generic.setflags.html#numpy.generic.setflags',
                       'numpy.generic.squeeze': 'https://numpy.org/doc/stable/reference/generated/numpy.generic.squeeze.html#numpy.generic.squeeze',
                       'numpy.genfromtxt': 'https://numpy.org/doc/stable/reference/generated/numpy.genfromtxt.html#numpy.genfromtxt',
                       'numpy.geomspace': 'https://numpy.org/doc/stable/reference/generated/numpy.geomspace.html#numpy.geomspace',
                       'numpy.get_include': 'https://numpy.org/doc/stable/reference/generated/numpy.get_include.html#numpy.get_include',
                       'numpy.get_printoptions': 'https://numpy.org/doc/stable/reference/generated/numpy.get_printoptions.html#numpy.get_printoptions',
                       'numpy.getbufsize': 'https://numpy.org/doc/stable/reference/generated/numpy.getbufsize.html#numpy.getbufsize',
                       'numpy.geterr': 'https://numpy.org/doc/stable/reference/generated/numpy.geterr.html#numpy.geterr',
                       'numpy.geterrcall': 'https://numpy.org/doc/stable/reference/generated/numpy.geterrcall.html#numpy.geterrcall',
                       'numpy.geterrobj': 'https://numpy.org/doc/stable/reference/generated/numpy.geterrobj.html#numpy.geterrobj',
                       'numpy.gradient': 'https://numpy.org/doc/stable/reference/generated/numpy.gradient.html#numpy.gradient',
                       'numpy.half': 'https://numpy.org/doc/stable/reference/arrays.scalars.html#numpy.half',
                       'numpy.hamming': 'https://numpy.org/doc/stable/reference/generated/numpy.hamming.html#numpy.hamming',
                       'numpy.hanning': 'https://numpy.org/doc/stable/reference/generated/numpy.hanning.html#numpy.hanning',
                       'numpy.histogram': 'https://numpy.org/doc/stable/reference/generated/numpy.histogram.html#numpy.histogram',
                       'numpy.histogram2d': 'https://numpy.org/doc/stable/reference/generated/numpy.histogram2d.html#numpy.histogram2d',
                       'numpy.histogram_bin_edges': 'https://numpy.org/doc/stable/reference/generated/numpy.histogram_bin_edges.html#numpy.histogram_bin_edges',
                       'numpy.histogramdd': 'https://numpy.org/doc/stable/reference/generated/numpy.histogramdd.html#numpy.histogramdd',
                       'numpy.hsplit': 'https://numpy.org/doc/stable/reference/generated/numpy.hsplit.html#numpy.hsplit',
                       'numpy.hstack': 'https://numpy.org/doc/stable/reference/generated/numpy.hstack.html#numpy.hstack',
                       'numpy.i0': 'https://numpy.org/doc/stable/reference/generated/numpy.i0.html#numpy.i0',
                       'numpy.identity': 'https://numpy.org/doc/stable/reference/generated/numpy.identity.html#numpy.identity',
                       'numpy.iinfo': 'https://numpy.org/doc/stable/reference/generated/numpy.iinfo.html#numpy.iinfo',
                       'numpy.imag': 'https://numpy.org/doc/stable/reference/generated/numpy.imag.html#numpy.imag',
                       'numpy.in1d': 'https://numpy.org/doc/stable/reference/generated/numpy.in1d.html#numpy.in1d',
                       'numpy.indices': 'https://numpy.org/doc/stable/reference/generated/numpy.indices.html#numpy.indices',
                       'numpy.inexact': 'https://numpy.org/doc/stable/reference/arrays.scalars.html#numpy.inexact',
                       'numpy.info': 'https://numpy.org/doc/stable/reference/generated/numpy.info.html#numpy.info',
                       'numpy.inner': 'https://numpy.org/doc/stable/reference/generated/numpy.inner.html#numpy.inner',
                       'numpy.insert': 'https://numpy.org/doc/stable/reference/generated/numpy.insert.html#numpy.insert',
                       'numpy.int_': 'https://numpy.org/doc/stable/reference/arrays.scalars.html#numpy.int_',
                       'numpy.intc': 'https://numpy.org/doc/stable/reference/arrays.scalars.html#numpy.intc',
                       'numpy.integer': 'https://numpy.org/doc/stable/reference/arrays.scalars.html#numpy.integer',
                       'numpy.interp': 'https://numpy.org/doc/stable/reference/generated/numpy.interp.html#numpy.interp',
                       'numpy.intersect1d': 'https://numpy.org/doc/stable/reference/generated/numpy.intersect1d.html#numpy.intersect1d',
                       'numpy.is_busday': 'https://numpy.org/doc/stable/reference/generated/numpy.is_busday.html#numpy.is_busday',
                       'numpy.isclose': 'https://numpy.org/doc/stable/reference/generated/numpy.isclose.html#numpy.isclose',
                       'numpy.iscomplex': 'https://numpy.org/doc/stable/reference/generated/numpy.iscomplex.html#numpy.iscomplex',
                       'numpy.iscomplexobj': 'https://numpy.org/doc/stable/reference/generated/numpy.iscomplexobj.html#numpy.iscomplexobj',
                       'numpy.isfortran': 'https://numpy.org/doc/stable/reference/generated/numpy.isfortran.html#numpy.isfortran',
                       'numpy.isin': 'https://numpy.org/doc/stable/reference/generated/numpy.isin.html#numpy.isin',
                       'numpy.isneginf': 'https://numpy.org/doc/stable/reference/generated/numpy.isneginf.html#numpy.isneginf',
                       'numpy.isposinf': 'https://numpy.org/doc/stable/reference/generated/numpy.isposinf.html#numpy.isposinf',
                       'numpy.isreal': 'https://numpy.org/doc/stable/reference/generated/numpy.isreal.html#numpy.isreal',
                       'numpy.isrealobj': 'https://numpy.org/doc/stable/reference/generated/numpy.isrealobj.html#numpy.isrealobj',
                       'numpy.isscalar': 'https://numpy.org/doc/stable/reference/generated/numpy.isscalar.html#numpy.isscalar',
                       'numpy.issctype': 'https://numpy.org/doc/stable/reference/generated/numpy.issctype.html#numpy.issctype',
                       'numpy.issubclass_': 'https://numpy.org/doc/stable/reference/generated/numpy.issubclass_.html#numpy.issubclass_',
                       'numpy.issubdtype': 'https://numpy.org/doc/stable/reference/generated/numpy.issubdtype.html#numpy.issubdtype',
                       'numpy.issubsctype': 'https://numpy.org/doc/stable/reference/generated/numpy.issubsctype.html#numpy.issubsctype',
                       'numpy.iterable': 'https://numpy.org/doc/stable/reference/generated/numpy.iterable.html#numpy.iterable',
                       'numpy.ix_': 'https://numpy.org/doc/stable/reference/generated/numpy.ix_.html#numpy.ix_',
                       'numpy.kaiser': 'https://numpy.org/doc/stable/reference/generated/numpy.kaiser.html#numpy.kaiser',
                       'numpy.kron': 'https://numpy.org/doc/stable/reference/generated/numpy.kron.html#numpy.kron',
                       'numpy.lexsort': 'https://numpy.org/doc/stable/reference/generated/numpy.lexsort.html#numpy.lexsort',
                       'numpy.linalg': 'https://numpy.org/doc/stable/reference/routines.linalg.html#module-numpy.linalg',
                       'numpy.linspace': 'https://numpy.org/doc/stable/reference/generated/numpy.linspace.html#numpy.linspace',
                       'numpy.load': 'https://numpy.org/doc/stable/reference/generated/numpy.load.html#numpy.load',
                       'numpy.loadtxt': 'https://numpy.org/doc/stable/reference/generated/numpy.loadtxt.html#numpy.loadtxt',
                       'numpy.logspace': 'https://numpy.org/doc/stable/reference/generated/numpy.logspace.html#numpy.logspace',
                       'numpy.longdouble': 'https://numpy.org/doc/stable/reference/arrays.scalars.html#numpy.longdouble',
                       'numpy.longlong': 'https://numpy.org/doc/stable/reference/arrays.scalars.html#numpy.longlong',
                       'numpy.lookfor': 'https://numpy.org/doc/stable/reference/generated/numpy.lookfor.html#numpy.lookfor',
                       'numpy.ma': 'https://numpy.org/doc/stable/reference/maskedarray.generic.html#module-numpy.ma',
                       'numpy.mask_indices': 'https://numpy.org/doc/stable/reference/generated/numpy.mask_indices.html#numpy.mask_indices',
                       'numpy.mat': 'https://numpy.org/doc/stable/reference/generated/numpy.mat.html#numpy.mat',
                       'numpy.matlib': 'https://numpy.org/doc/stable/reference/routines.matlib.html#module-numpy.matlib',
                       'numpy.matrix': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.html#numpy.matrix',
                       'numpy.matrix.all': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.all.html#numpy.matrix.all',
                       'numpy.matrix.any': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.any.html#numpy.matrix.any',
                       'numpy.matrix.argmax': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.argmax.html#numpy.matrix.argmax',
                       'numpy.matrix.argmin': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.argmin.html#numpy.matrix.argmin',
                       'numpy.matrix.argpartition': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.argpartition.html#numpy.matrix.argpartition',
                       'numpy.matrix.argsort': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.argsort.html#numpy.matrix.argsort',
                       'numpy.matrix.astype': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.astype.html#numpy.matrix.astype',
                       'numpy.matrix.byteswap': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.byteswap.html#numpy.matrix.byteswap',
                       'numpy.matrix.choose': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.choose.html#numpy.matrix.choose',
                       'numpy.matrix.clip': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.clip.html#numpy.matrix.clip',
                       'numpy.matrix.compress': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.compress.html#numpy.matrix.compress',
                       'numpy.matrix.conj': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.conj.html#numpy.matrix.conj',
                       'numpy.matrix.conjugate': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.conjugate.html#numpy.matrix.conjugate',
                       'numpy.matrix.copy': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.copy.html#numpy.matrix.copy',
                       'numpy.matrix.cumprod': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.cumprod.html#numpy.matrix.cumprod',
                       'numpy.matrix.cumsum': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.cumsum.html#numpy.matrix.cumsum',
                       'numpy.matrix.diagonal': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.diagonal.html#numpy.matrix.diagonal',
                       'numpy.matrix.dot': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.dot.html#numpy.matrix.dot',
                       'numpy.matrix.dump': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.dump.html#numpy.matrix.dump',
                       'numpy.matrix.dumps': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.dumps.html#numpy.matrix.dumps',
                       'numpy.matrix.fill': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.fill.html#numpy.matrix.fill',
                       'numpy.matrix.flatten': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.flatten.html#numpy.matrix.flatten',
                       'numpy.matrix.getA': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.getA.html#numpy.matrix.getA',
                       'numpy.matrix.getA1': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.getA1.html#numpy.matrix.getA1',
                       'numpy.matrix.getH': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.getH.html#numpy.matrix.getH',
                       'numpy.matrix.getI': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.getI.html#numpy.matrix.getI',
                       'numpy.matrix.getT': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.getT.html#numpy.matrix.getT',
                       'numpy.matrix.getfield': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.getfield.html#numpy.matrix.getfield',
                       'numpy.matrix.item': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.item.html#numpy.matrix.item',
                       'numpy.matrix.itemset': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.itemset.html#numpy.matrix.itemset',
                       'numpy.matrix.max': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.max.html#numpy.matrix.max',
                       'numpy.matrix.mean': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.mean.html#numpy.matrix.mean',
                       'numpy.matrix.min': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.min.html#numpy.matrix.min',
                       'numpy.matrix.newbyteorder': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.newbyteorder.html#numpy.matrix.newbyteorder',
                       'numpy.matrix.nonzero': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.nonzero.html#numpy.matrix.nonzero',
                       'numpy.matrix.partition': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.partition.html#numpy.matrix.partition',
                       'numpy.matrix.prod': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.prod.html#numpy.matrix.prod',
                       'numpy.matrix.ptp': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.ptp.html#numpy.matrix.ptp',
                       'numpy.matrix.put': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.put.html#numpy.matrix.put',
                       'numpy.matrix.ravel': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.ravel.html#numpy.matrix.ravel',
                       'numpy.matrix.repeat': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.repeat.html#numpy.matrix.repeat',
                       'numpy.matrix.reshape': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.reshape.html#numpy.matrix.reshape',
                       'numpy.matrix.resize': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.resize.html#numpy.matrix.resize',
                       'numpy.matrix.round': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.round.html#numpy.matrix.round',
                       'numpy.matrix.searchsorted': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.searchsorted.html#numpy.matrix.searchsorted',
                       'numpy.matrix.setfield': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.setfield.html#numpy.matrix.setfield',
                       'numpy.matrix.setflags': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.setflags.html#numpy.matrix.setflags',
                       'numpy.matrix.sort': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.sort.html#numpy.matrix.sort',
                       'numpy.matrix.squeeze': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.squeeze.html#numpy.matrix.squeeze',
                       'numpy.matrix.std': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.std.html#numpy.matrix.std',
                       'numpy.matrix.sum': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.sum.html#numpy.matrix.sum',
                       'numpy.matrix.swapaxes': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.swapaxes.html#numpy.matrix.swapaxes',
                       'numpy.matrix.take': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.take.html#numpy.matrix.take',
                       'numpy.matrix.tobytes': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.tobytes.html#numpy.matrix.tobytes',
                       'numpy.matrix.tofile': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.tofile.html#numpy.matrix.tofile',
                       'numpy.matrix.tolist': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.tolist.html#numpy.matrix.tolist',
                       'numpy.matrix.tostring': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.tostring.html#numpy.matrix.tostring',
                       'numpy.matrix.trace': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.trace.html#numpy.matrix.trace',
                       'numpy.matrix.transpose': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.transpose.html#numpy.matrix.transpose',
                       'numpy.matrix.var': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.var.html#numpy.matrix.var',
                       'numpy.matrix.view': 'https://numpy.org/doc/stable/reference/generated/numpy.matrix.view.html#numpy.matrix.view',
                       'numpy.maximum_sctype': 'https://numpy.org/doc/stable/reference/generated/numpy.maximum_sctype.html#numpy.maximum_sctype',
                       'numpy.may_share_memory': 'https://numpy.org/doc/stable/reference/generated/numpy.may_share_memory.html#numpy.may_share_memory',
                       'numpy.mean': 'https://numpy.org/doc/stable/reference/generated/numpy.mean.html#numpy.mean',
                       'numpy.median': 'https://numpy.org/doc/stable/reference/generated/numpy.median.html#numpy.median',
                       'numpy.memmap': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.html#numpy.memmap',
                       'numpy.memmap.all': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.all.html#numpy.memmap.all',
                       'numpy.memmap.any': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.any.html#numpy.memmap.any',
                       'numpy.memmap.argmax': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.argmax.html#numpy.memmap.argmax',
                       'numpy.memmap.argmin': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.argmin.html#numpy.memmap.argmin',
                       'numpy.memmap.argpartition': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.argpartition.html#numpy.memmap.argpartition',
                       'numpy.memmap.argsort': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.argsort.html#numpy.memmap.argsort',
                       'numpy.memmap.astype': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.astype.html#numpy.memmap.astype',
                       'numpy.memmap.byteswap': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.byteswap.html#numpy.memmap.byteswap',
                       'numpy.memmap.choose': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.choose.html#numpy.memmap.choose',
                       'numpy.memmap.clip': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.clip.html#numpy.memmap.clip',
                       'numpy.memmap.compress': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.compress.html#numpy.memmap.compress',
                       'numpy.memmap.conj': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.conj.html#numpy.memmap.conj',
                       'numpy.memmap.conjugate': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.conjugate.html#numpy.memmap.conjugate',
                       'numpy.memmap.copy': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.copy.html#numpy.memmap.copy',
                       'numpy.memmap.cumprod': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.cumprod.html#numpy.memmap.cumprod',
                       'numpy.memmap.cumsum': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.cumsum.html#numpy.memmap.cumsum',
                       'numpy.memmap.diagonal': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.diagonal.html#numpy.memmap.diagonal',
                       'numpy.memmap.dot': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.dot.html#numpy.memmap.dot',
                       'numpy.memmap.dump': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.dump.html#numpy.memmap.dump',
                       'numpy.memmap.dumps': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.dumps.html#numpy.memmap.dumps',
                       'numpy.memmap.fill': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.fill.html#numpy.memmap.fill',
                       'numpy.memmap.flatten': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.flatten.html#numpy.memmap.flatten',
                       'numpy.memmap.flush': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.flush.html#numpy.memmap.flush',
                       'numpy.memmap.getfield': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.getfield.html#numpy.memmap.getfield',
                       'numpy.memmap.item': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.item.html#numpy.memmap.item',
                       'numpy.memmap.itemset': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.itemset.html#numpy.memmap.itemset',
                       'numpy.memmap.max': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.max.html#numpy.memmap.max',
                       'numpy.memmap.mean': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.mean.html#numpy.memmap.mean',
                       'numpy.memmap.min': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.min.html#numpy.memmap.min',
                       'numpy.memmap.newbyteorder': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.newbyteorder.html#numpy.memmap.newbyteorder',
                       'numpy.memmap.nonzero': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.nonzero.html#numpy.memmap.nonzero',
                       'numpy.memmap.partition': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.partition.html#numpy.memmap.partition',
                       'numpy.memmap.prod': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.prod.html#numpy.memmap.prod',
                       'numpy.memmap.ptp': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.ptp.html#numpy.memmap.ptp',
                       'numpy.memmap.put': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.put.html#numpy.memmap.put',
                       'numpy.memmap.ravel': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.ravel.html#numpy.memmap.ravel',
                       'numpy.memmap.repeat': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.repeat.html#numpy.memmap.repeat',
                       'numpy.memmap.reshape': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.reshape.html#numpy.memmap.reshape',
                       'numpy.memmap.resize': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.resize.html#numpy.memmap.resize',
                       'numpy.memmap.round': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.round.html#numpy.memmap.round',
                       'numpy.memmap.searchsorted': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.searchsorted.html#numpy.memmap.searchsorted',
                       'numpy.memmap.setfield': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.setfield.html#numpy.memmap.setfield',
                       'numpy.memmap.setflags': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.setflags.html#numpy.memmap.setflags',
                       'numpy.memmap.sort': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.sort.html#numpy.memmap.sort',
                       'numpy.memmap.squeeze': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.squeeze.html#numpy.memmap.squeeze',
                       'numpy.memmap.std': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.std.html#numpy.memmap.std',
                       'numpy.memmap.sum': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.sum.html#numpy.memmap.sum',
                       'numpy.memmap.swapaxes': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.swapaxes.html#numpy.memmap.swapaxes',
                       'numpy.memmap.take': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.take.html#numpy.memmap.take',
                       'numpy.memmap.tobytes': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.tobytes.html#numpy.memmap.tobytes',
                       'numpy.memmap.tofile': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.tofile.html#numpy.memmap.tofile',
                       'numpy.memmap.tolist': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.tolist.html#numpy.memmap.tolist',
                       'numpy.memmap.tostring': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.tostring.html#numpy.memmap.tostring',
                       'numpy.memmap.trace': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.trace.html#numpy.memmap.trace',
                       'numpy.memmap.transpose': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.transpose.html#numpy.memmap.transpose',
                       'numpy.memmap.var': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.var.html#numpy.memmap.var',
                       'numpy.memmap.view': 'https://numpy.org/doc/stable/reference/generated/numpy.memmap.view.html#numpy.memmap.view',
                       'numpy.meshgrid': 'https://numpy.org/doc/stable/reference/generated/numpy.meshgrid.html#numpy.meshgrid',
                       'numpy.min_scalar_type': 'https://numpy.org/doc/stable/reference/generated/numpy.min_scalar_type.html#numpy.min_scalar_type',
                       'numpy.mintypecode': 'https://numpy.org/doc/stable/reference/generated/numpy.mintypecode.html#numpy.mintypecode',
                       'numpy.moveaxis': 'https://numpy.org/doc/stable/reference/generated/numpy.moveaxis.html#numpy.moveaxis',
                       'numpy.msort': 'https://numpy.org/doc/stable/reference/generated/numpy.msort.html#numpy.msort',
                       'numpy.nan_to_num': 'https://numpy.org/doc/stable/reference/generated/numpy.nan_to_num.html#numpy.nan_to_num',
                       'numpy.nanargmax': 'https://numpy.org/doc/stable/reference/generated/numpy.nanargmax.html#numpy.nanargmax',
                       'numpy.nanargmin': 'https://numpy.org/doc/stable/reference/generated/numpy.nanargmin.html#numpy.nanargmin',
                       'numpy.nancumprod': 'https://numpy.org/doc/stable/reference/generated/numpy.nancumprod.html#numpy.nancumprod',
                       'numpy.nancumsum': 'https://numpy.org/doc/stable/reference/generated/numpy.nancumsum.html#numpy.nancumsum',
                       'numpy.nanmax': 'https://numpy.org/doc/stable/reference/generated/numpy.nanmax.html#numpy.nanmax',
                       'numpy.nanmean': 'https://numpy.org/doc/stable/reference/generated/numpy.nanmean.html#numpy.nanmean',
                       'numpy.nanmedian': 'https://numpy.org/doc/stable/reference/generated/numpy.nanmedian.html#numpy.nanmedian',
                       'numpy.nanmin': 'https://numpy.org/doc/stable/reference/generated/numpy.nanmin.html#numpy.nanmin',
                       'numpy.nanpercentile': 'https://numpy.org/doc/stable/reference/generated/numpy.nanpercentile.html#numpy.nanpercentile',
                       'numpy.nanprod': 'https://numpy.org/doc/stable/reference/generated/numpy.nanprod.html#numpy.nanprod',
                       'numpy.nanquantile': 'https://numpy.org/doc/stable/reference/generated/numpy.nanquantile.html#numpy.nanquantile',
                       'numpy.nanstd': 'https://numpy.org/doc/stable/reference/generated/numpy.nanstd.html#numpy.nanstd',
                       'numpy.nansum': 'https://numpy.org/doc/stable/reference/generated/numpy.nansum.html#numpy.nansum',
                       'numpy.nanvar': 'https://numpy.org/doc/stable/reference/generated/numpy.nanvar.html#numpy.nanvar',
                       'numpy.ndarray': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.html#numpy.ndarray',
                       'numpy.ndarray.__abs__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__abs__.html#numpy.ndarray.__abs__',
                       'numpy.ndarray.__add__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__add__.html#numpy.ndarray.__add__',
                       'numpy.ndarray.__and__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__and__.html#numpy.ndarray.__and__',
                       'numpy.ndarray.__array__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__array__.html#numpy.ndarray.__array__',
                       'numpy.ndarray.__array_wrap__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__array_wrap__.html#numpy.ndarray.__array_wrap__',
                       'numpy.ndarray.__bool__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__bool__.html#numpy.ndarray.__bool__',
                       'numpy.ndarray.__class_getitem__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__class_getitem__.html#numpy.ndarray.__class_getitem__',
                       'numpy.ndarray.__complex__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__complex__.html#numpy.ndarray.__complex__',
                       'numpy.ndarray.__contains__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__contains__.html#numpy.ndarray.__contains__',
                       'numpy.ndarray.__copy__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__copy__.html#numpy.ndarray.__copy__',
                       'numpy.ndarray.__deepcopy__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__deepcopy__.html#numpy.ndarray.__deepcopy__',
                       'numpy.ndarray.__divmod__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__divmod__.html#numpy.ndarray.__divmod__',
                       'numpy.ndarray.__eq__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__eq__.html#numpy.ndarray.__eq__',
                       'numpy.ndarray.__float__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__float__.html#numpy.ndarray.__float__',
                       'numpy.ndarray.__floordiv__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__floordiv__.html#numpy.ndarray.__floordiv__',
                       'numpy.ndarray.__ge__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__ge__.html#numpy.ndarray.__ge__',
                       'numpy.ndarray.__getitem__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__getitem__.html#numpy.ndarray.__getitem__',
                       'numpy.ndarray.__gt__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__gt__.html#numpy.ndarray.__gt__',
                       'numpy.ndarray.__iadd__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__iadd__.html#numpy.ndarray.__iadd__',
                       'numpy.ndarray.__iand__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__iand__.html#numpy.ndarray.__iand__',
                       'numpy.ndarray.__ifloordiv__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__ifloordiv__.html#numpy.ndarray.__ifloordiv__',
                       'numpy.ndarray.__ilshift__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__ilshift__.html#numpy.ndarray.__ilshift__',
                       'numpy.ndarray.__imod__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__imod__.html#numpy.ndarray.__imod__',
                       'numpy.ndarray.__imul__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__imul__.html#numpy.ndarray.__imul__',
                       'numpy.ndarray.__int__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__int__.html#numpy.ndarray.__int__',
                       'numpy.ndarray.__invert__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__invert__.html#numpy.ndarray.__invert__',
                       'numpy.ndarray.__ior__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__ior__.html#numpy.ndarray.__ior__',
                       'numpy.ndarray.__ipow__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__ipow__.html#numpy.ndarray.__ipow__',
                       'numpy.ndarray.__irshift__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__irshift__.html#numpy.ndarray.__irshift__',
                       'numpy.ndarray.__isub__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__isub__.html#numpy.ndarray.__isub__',
                       'numpy.ndarray.__itruediv__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__itruediv__.html#numpy.ndarray.__itruediv__',
                       'numpy.ndarray.__ixor__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__ixor__.html#numpy.ndarray.__ixor__',
                       'numpy.ndarray.__le__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__le__.html#numpy.ndarray.__le__',
                       'numpy.ndarray.__len__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__len__.html#numpy.ndarray.__len__',
                       'numpy.ndarray.__lshift__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__lshift__.html#numpy.ndarray.__lshift__',
                       'numpy.ndarray.__lt__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__lt__.html#numpy.ndarray.__lt__',
                       'numpy.ndarray.__matmul__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__matmul__.html#numpy.ndarray.__matmul__',
                       'numpy.ndarray.__mod__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__mod__.html#numpy.ndarray.__mod__',
                       'numpy.ndarray.__mul__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__mul__.html#numpy.ndarray.__mul__',
                       'numpy.ndarray.__ne__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__ne__.html#numpy.ndarray.__ne__',
                       'numpy.ndarray.__neg__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__neg__.html#numpy.ndarray.__neg__',
                       'numpy.ndarray.__new__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__new__.html#numpy.ndarray.__new__',
                       'numpy.ndarray.__or__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__or__.html#numpy.ndarray.__or__',
                       'numpy.ndarray.__pos__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__pos__.html#numpy.ndarray.__pos__',
                       'numpy.ndarray.__pow__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__pow__.html#numpy.ndarray.__pow__',
                       'numpy.ndarray.__reduce__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__reduce__.html#numpy.ndarray.__reduce__',
                       'numpy.ndarray.__repr__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__repr__.html#numpy.ndarray.__repr__',
                       'numpy.ndarray.__rshift__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__rshift__.html#numpy.ndarray.__rshift__',
                       'numpy.ndarray.__setitem__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__setitem__.html#numpy.ndarray.__setitem__',
                       'numpy.ndarray.__setstate__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__setstate__.html#numpy.ndarray.__setstate__',
                       'numpy.ndarray.__str__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__str__.html#numpy.ndarray.__str__',
                       'numpy.ndarray.__sub__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__sub__.html#numpy.ndarray.__sub__',
                       'numpy.ndarray.__truediv__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__truediv__.html#numpy.ndarray.__truediv__',
                       'numpy.ndarray.__xor__': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.__xor__.html#numpy.ndarray.__xor__',
                       'numpy.ndarray.all': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.all.html#numpy.ndarray.all',
                       'numpy.ndarray.any': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.any.html#numpy.ndarray.any',
                       'numpy.ndarray.argmax': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.argmax.html#numpy.ndarray.argmax',
                       'numpy.ndarray.argmin': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.argmin.html#numpy.ndarray.argmin',
                       'numpy.ndarray.argpartition': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.argpartition.html#numpy.ndarray.argpartition',
                       'numpy.ndarray.argsort': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.argsort.html#numpy.ndarray.argsort',
                       'numpy.ndarray.astype': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.astype.html#numpy.ndarray.astype',
                       'numpy.ndarray.byteswap': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.byteswap.html#numpy.ndarray.byteswap',
                       'numpy.ndarray.choose': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.choose.html#numpy.ndarray.choose',
                       'numpy.ndarray.clip': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.clip.html#numpy.ndarray.clip',
                       'numpy.ndarray.compress': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.compress.html#numpy.ndarray.compress',
                       'numpy.ndarray.conj': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.conj.html#numpy.ndarray.conj',
                       'numpy.ndarray.conjugate': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.conjugate.html#numpy.ndarray.conjugate',
                       'numpy.ndarray.copy': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.copy.html#numpy.ndarray.copy',
                       'numpy.ndarray.cumprod': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.cumprod.html#numpy.ndarray.cumprod',
                       'numpy.ndarray.cumsum': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.cumsum.html#numpy.ndarray.cumsum',
                       'numpy.ndarray.diagonal': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.diagonal.html#numpy.ndarray.diagonal',
                       'numpy.ndarray.dot': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.dot.html#numpy.ndarray.dot',
                       'numpy.ndarray.dump': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.dump.html#numpy.ndarray.dump',
                       'numpy.ndarray.dumps': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.dumps.html#numpy.ndarray.dumps',
                       'numpy.ndarray.fill': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.fill.html#numpy.ndarray.fill',
                       'numpy.ndarray.flatten': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.flatten.html#numpy.ndarray.flatten',
                       'numpy.ndarray.getfield': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.getfield.html#numpy.ndarray.getfield',
                       'numpy.ndarray.item': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.item.html#numpy.ndarray.item',
                       'numpy.ndarray.itemset': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.itemset.html#numpy.ndarray.itemset',
                       'numpy.ndarray.max': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.max.html#numpy.ndarray.max',
                       'numpy.ndarray.mean': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.mean.html#numpy.ndarray.mean',
                       'numpy.ndarray.min': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.min.html#numpy.ndarray.min',
                       'numpy.ndarray.newbyteorder': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.newbyteorder.html#numpy.ndarray.newbyteorder',
                       'numpy.ndarray.nonzero': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.nonzero.html#numpy.ndarray.nonzero',
                       'numpy.ndarray.partition': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.partition.html#numpy.ndarray.partition',
                       'numpy.ndarray.prod': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.prod.html#numpy.ndarray.prod',
                       'numpy.ndarray.ptp': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.ptp.html#numpy.ndarray.ptp',
                       'numpy.ndarray.put': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.put.html#numpy.ndarray.put',
                       'numpy.ndarray.ravel': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.ravel.html#numpy.ndarray.ravel',
                       'numpy.ndarray.repeat': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.repeat.html#numpy.ndarray.repeat',
                       'numpy.ndarray.reshape': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.reshape.html#numpy.ndarray.reshape',
                       'numpy.ndarray.resize': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.resize.html#numpy.ndarray.resize',
                       'numpy.ndarray.round': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.round.html#numpy.ndarray.round',
                       'numpy.ndarray.searchsorted': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.searchsorted.html#numpy.ndarray.searchsorted',
                       'numpy.ndarray.setfield': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.setfield.html#numpy.ndarray.setfield',
                       'numpy.ndarray.setflags': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.setflags.html#numpy.ndarray.setflags',
                       'numpy.ndarray.sort': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.sort.html#numpy.ndarray.sort',
                       'numpy.ndarray.squeeze': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.squeeze.html#numpy.ndarray.squeeze',
                       'numpy.ndarray.std': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.std.html#numpy.ndarray.std',
                       'numpy.ndarray.sum': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.sum.html#numpy.ndarray.sum',
                       'numpy.ndarray.swapaxes': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.swapaxes.html#numpy.ndarray.swapaxes',
                       'numpy.ndarray.take': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.take.html#numpy.ndarray.take',
                       'numpy.ndarray.tobytes': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.tobytes.html#numpy.ndarray.tobytes',
                       'numpy.ndarray.tofile': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.tofile.html#numpy.ndarray.tofile',
                       'numpy.ndarray.tolist': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.tolist.html#numpy.ndarray.tolist',
                       'numpy.ndarray.tostring': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.tostring.html#numpy.ndarray.tostring',
                       'numpy.ndarray.trace': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.trace.html#numpy.ndarray.trace',
                       'numpy.ndarray.transpose': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.transpose.html#numpy.ndarray.transpose',
                       'numpy.ndarray.var': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.var.html#numpy.ndarray.var',
                       'numpy.ndarray.view': 'https://numpy.org/doc/stable/reference/generated/numpy.ndarray.view.html#numpy.ndarray.view',
                       'numpy.ndenumerate': 'https://numpy.org/doc/stable/reference/generated/numpy.ndenumerate.html#numpy.ndenumerate',
                       'numpy.ndindex': 'https://numpy.org/doc/stable/reference/generated/numpy.ndindex.html#numpy.ndindex',
                       'numpy.ndindex.ndincr': 'https://numpy.org/doc/stable/reference/generated/numpy.ndindex.ndincr.html#numpy.ndindex.ndincr',
                       'numpy.nditer': 'https://numpy.org/doc/stable/reference/generated/numpy.nditer.html#numpy.nditer',
                       'numpy.nditer.close': 'https://numpy.org/doc/stable/reference/generated/numpy.nditer.close.html#numpy.nditer.close',
                       'numpy.nditer.copy': 'https://numpy.org/doc/stable/reference/generated/numpy.nditer.copy.html#numpy.nditer.copy',
                       'numpy.nditer.debug_print': 'https://numpy.org/doc/stable/reference/generated/numpy.nditer.debug_print.html#numpy.nditer.debug_print',
                       'numpy.nditer.enable_external_loop': 'https://numpy.org/doc/stable/reference/generated/numpy.nditer.enable_external_loop.html#numpy.nditer.enable_external_loop',
                       'numpy.nditer.iternext': 'https://numpy.org/doc/stable/reference/generated/numpy.nditer.iternext.html#numpy.nditer.iternext',
                       'numpy.nditer.remove_axis': 'https://numpy.org/doc/stable/reference/generated/numpy.nditer.remove_axis.html#numpy.nditer.remove_axis',
                       'numpy.nditer.remove_multi_index': 'https://numpy.org/doc/stable/reference/generated/numpy.nditer.remove_multi_index.html#numpy.nditer.remove_multi_index',
                       'numpy.nditer.reset': 'https://numpy.org/doc/stable/reference/generated/numpy.nditer.reset.html#numpy.nditer.reset',
                       'numpy.nested_iters': 'https://numpy.org/doc/stable/reference/generated/numpy.nested_iters.html#numpy.nested_iters',
                       'numpy.nonzero': 'https://numpy.org/doc/stable/reference/generated/numpy.nonzero.html#numpy.nonzero',
                       'numpy.number': 'https://numpy.org/doc/stable/reference/arrays.scalars.html#numpy.number',
                       'numpy.number.__class_getitem__': 'https://numpy.org/doc/stable/reference/generated/numpy.number.__class_getitem__.html#numpy.number.__class_getitem__',
                       'numpy.obj2sctype': 'https://numpy.org/doc/stable/reference/generated/numpy.obj2sctype.html#numpy.obj2sctype',
                       'numpy.object_': 'https://numpy.org/doc/stable/reference/arrays.scalars.html#numpy.object_',
                       'numpy.ones': 'https://numpy.org/doc/stable/reference/generated/numpy.ones.html#numpy.ones',
                       'numpy.ones_like': 'https://numpy.org/doc/stable/reference/generated/numpy.ones_like.html#numpy.ones_like',
                       'numpy.outer': 'https://numpy.org/doc/stable/reference/generated/numpy.outer.html#numpy.outer',
                       'numpy.packbits': 'https://numpy.org/doc/stable/reference/generated/numpy.packbits.html#numpy.packbits',
                       'numpy.pad': 'https://numpy.org/doc/stable/reference/generated/numpy.pad.html#numpy.pad',
                       'numpy.partition': 'https://numpy.org/doc/stable/reference/generated/numpy.partition.html#numpy.partition',
                       'numpy.percentile': 'https://numpy.org/doc/stable/reference/generated/numpy.percentile.html#numpy.percentile',
                       'numpy.piecewise': 'https://numpy.org/doc/stable/reference/generated/numpy.piecewise.html#numpy.piecewise',
                       'numpy.place': 'https://numpy.org/doc/stable/reference/generated/numpy.place.html#numpy.place',
                       'numpy.poly': 'https://numpy.org/doc/stable/reference/generated/numpy.poly.html#numpy.poly',
                       'numpy.poly1d': 'https://numpy.org/doc/stable/reference/generated/numpy.poly1d.html#numpy.poly1d',
                       'numpy.poly1d.__call__': 'https://numpy.org/doc/stable/reference/generated/numpy.poly1d.__call__.html#numpy.poly1d.__call__',
                       'numpy.poly1d.deriv': 'https://numpy.org/doc/stable/reference/generated/numpy.poly1d.deriv.html#numpy.poly1d.deriv',
                       'numpy.poly1d.integ': 'https://numpy.org/doc/stable/reference/generated/numpy.poly1d.integ.html#numpy.poly1d.integ',
                       'numpy.polyadd': 'https://numpy.org/doc/stable/reference/generated/numpy.polyadd.html#numpy.polyadd',
                       'numpy.polyder': 'https://numpy.org/doc/stable/reference/generated/numpy.polyder.html#numpy.polyder',
                       'numpy.polydiv': 'https://numpy.org/doc/stable/reference/generated/numpy.polydiv.html#numpy.polydiv',
                       'numpy.polyfit': 'https://numpy.org/doc/stable/reference/generated/numpy.polyfit.html#numpy.polyfit',
                       'numpy.polyint': 'https://numpy.org/doc/stable/reference/generated/numpy.polyint.html#numpy.polyint',
                       'numpy.polymul': 'https://numpy.org/doc/stable/reference/generated/numpy.polymul.html#numpy.polymul',
                       'numpy.polynomial': 'https://numpy.org/doc/stable/reference/routines.polynomials.package.html#module-numpy.polynomial',
                       'numpy.polysub': 'https://numpy.org/doc/stable/reference/generated/numpy.polysub.html#numpy.polysub',
                       'numpy.polyval': 'https://numpy.org/doc/stable/reference/generated/numpy.polyval.html#numpy.polyval',
                       'numpy.printoptions': 'https://numpy.org/doc/stable/reference/generated/numpy.printoptions.html#numpy.printoptions',
                       'numpy.prod': 'https://numpy.org/doc/stable/reference/generated/numpy.prod.html#numpy.prod',
                       'numpy.promote_types': 'https://numpy.org/doc/stable/reference/generated/numpy.promote_types.html#numpy.promote_types',
                       'numpy.ptp': 'https://numpy.org/doc/stable/reference/generated/numpy.ptp.html#numpy.ptp',
                       'numpy.put': 'https://numpy.org/doc/stable/reference/generated/numpy.put.html#numpy.put',
                       'numpy.put_along_axis': 'https://numpy.org/doc/stable/reference/generated/numpy.put_along_axis.html#numpy.put_along_axis',
                       'numpy.putmask': 'https://numpy.org/doc/stable/reference/generated/numpy.putmask.html#numpy.putmask',
                       'numpy.quantile': 'https://numpy.org/doc/stable/reference/generated/numpy.quantile.html#numpy.quantile',
                       'numpy.random': 'https://numpy.org/doc/stable/reference/random/index.html#module-numpy.random',
                       'numpy.ravel': 'https://numpy.org/doc/stable/reference/generated/numpy.ravel.html#numpy.ravel',
                       'numpy.ravel_multi_index': 'https://numpy.org/doc/stable/reference/generated/numpy.ravel_multi_index.html#numpy.ravel_multi_index',
                       'numpy.real': 'https://numpy.org/doc/stable/reference/generated/numpy.real.html#numpy.real',
                       'numpy.real_if_close': 'https://numpy.org/doc/stable/reference/generated/numpy.real_if_close.html#numpy.real_if_close',
                       'numpy.recarray': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.html#numpy.recarray',
                       'numpy.recarray.all': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.all.html#numpy.recarray.all',
                       'numpy.recarray.any': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.any.html#numpy.recarray.any',
                       'numpy.recarray.argmax': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.argmax.html#numpy.recarray.argmax',
                       'numpy.recarray.argmin': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.argmin.html#numpy.recarray.argmin',
                       'numpy.recarray.argpartition': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.argpartition.html#numpy.recarray.argpartition',
                       'numpy.recarray.argsort': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.argsort.html#numpy.recarray.argsort',
                       'numpy.recarray.astype': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.astype.html#numpy.recarray.astype',
                       'numpy.recarray.byteswap': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.byteswap.html#numpy.recarray.byteswap',
                       'numpy.recarray.choose': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.choose.html#numpy.recarray.choose',
                       'numpy.recarray.clip': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.clip.html#numpy.recarray.clip',
                       'numpy.recarray.compress': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.compress.html#numpy.recarray.compress',
                       'numpy.recarray.conj': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.conj.html#numpy.recarray.conj',
                       'numpy.recarray.conjugate': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.conjugate.html#numpy.recarray.conjugate',
                       'numpy.recarray.copy': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.copy.html#numpy.recarray.copy',
                       'numpy.recarray.cumprod': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.cumprod.html#numpy.recarray.cumprod',
                       'numpy.recarray.cumsum': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.cumsum.html#numpy.recarray.cumsum',
                       'numpy.recarray.diagonal': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.diagonal.html#numpy.recarray.diagonal',
                       'numpy.recarray.dot': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.dot.html#numpy.recarray.dot',
                       'numpy.recarray.dump': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.dump.html#numpy.recarray.dump',
                       'numpy.recarray.dumps': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.dumps.html#numpy.recarray.dumps',
                       'numpy.recarray.field': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.field.html#numpy.recarray.field',
                       'numpy.recarray.fill': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.fill.html#numpy.recarray.fill',
                       'numpy.recarray.flatten': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.flatten.html#numpy.recarray.flatten',
                       'numpy.recarray.getfield': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.getfield.html#numpy.recarray.getfield',
                       'numpy.recarray.item': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.item.html#numpy.recarray.item',
                       'numpy.recarray.itemset': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.itemset.html#numpy.recarray.itemset',
                       'numpy.recarray.max': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.max.html#numpy.recarray.max',
                       'numpy.recarray.mean': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.mean.html#numpy.recarray.mean',
                       'numpy.recarray.min': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.min.html#numpy.recarray.min',
                       'numpy.recarray.newbyteorder': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.newbyteorder.html#numpy.recarray.newbyteorder',
                       'numpy.recarray.nonzero': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.nonzero.html#numpy.recarray.nonzero',
                       'numpy.recarray.partition': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.partition.html#numpy.recarray.partition',
                       'numpy.recarray.prod': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.prod.html#numpy.recarray.prod',
                       'numpy.recarray.ptp': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.ptp.html#numpy.recarray.ptp',
                       'numpy.recarray.put': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.put.html#numpy.recarray.put',
                       'numpy.recarray.ravel': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.ravel.html#numpy.recarray.ravel',
                       'numpy.recarray.repeat': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.repeat.html#numpy.recarray.repeat',
                       'numpy.recarray.reshape': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.reshape.html#numpy.recarray.reshape',
                       'numpy.recarray.resize': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.resize.html#numpy.recarray.resize',
                       'numpy.recarray.round': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.round.html#numpy.recarray.round',
                       'numpy.recarray.searchsorted': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.searchsorted.html#numpy.recarray.searchsorted',
                       'numpy.recarray.setfield': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.setfield.html#numpy.recarray.setfield',
                       'numpy.recarray.setflags': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.setflags.html#numpy.recarray.setflags',
                       'numpy.recarray.sort': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.sort.html#numpy.recarray.sort',
                       'numpy.recarray.squeeze': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.squeeze.html#numpy.recarray.squeeze',
                       'numpy.recarray.std': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.std.html#numpy.recarray.std',
                       'numpy.recarray.sum': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.sum.html#numpy.recarray.sum',
                       'numpy.recarray.swapaxes': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.swapaxes.html#numpy.recarray.swapaxes',
                       'numpy.recarray.take': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.take.html#numpy.recarray.take',
                       'numpy.recarray.tobytes': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.tobytes.html#numpy.recarray.tobytes',
                       'numpy.recarray.tofile': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.tofile.html#numpy.recarray.tofile',
                       'numpy.recarray.tolist': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.tolist.html#numpy.recarray.tolist',
                       'numpy.recarray.tostring': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.tostring.html#numpy.recarray.tostring',
                       'numpy.recarray.trace': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.trace.html#numpy.recarray.trace',
                       'numpy.recarray.transpose': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.transpose.html#numpy.recarray.transpose',
                       'numpy.recarray.var': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.var.html#numpy.recarray.var',
                       'numpy.recarray.view': 'https://numpy.org/doc/stable/reference/generated/numpy.recarray.view.html#numpy.recarray.view',
                       'numpy.record': 'https://numpy.org/doc/stable/reference/generated/numpy.record.html#numpy.record',
                       'numpy.record.all': 'https://numpy.org/doc/stable/reference/generated/numpy.record.all.html#numpy.record.all',
                       'numpy.record.any': 'https://numpy.org/doc/stable/reference/generated/numpy.record.any.html#numpy.record.any',
                       'numpy.record.argmax': 'https://numpy.org/doc/stable/reference/generated/numpy.record.argmax.html#numpy.record.argmax',
                       'numpy.record.argmin': 'https://numpy.org/doc/stable/reference/generated/numpy.record.argmin.html#numpy.record.argmin',
                       'numpy.record.argsort': 'https://numpy.org/doc/stable/reference/generated/numpy.record.argsort.html#numpy.record.argsort',
                       'numpy.record.astype': 'https://numpy.org/doc/stable/reference/generated/numpy.record.astype.html#numpy.record.astype',
                       'numpy.record.byteswap': 'https://numpy.org/doc/stable/reference/generated/numpy.record.byteswap.html#numpy.record.byteswap',
                       'numpy.record.choose': 'https://numpy.org/doc/stable/reference/generated/numpy.record.choose.html#numpy.record.choose',
                       'numpy.record.clip': 'https://numpy.org/doc/stable/reference/generated/numpy.record.clip.html#numpy.record.clip',
                       'numpy.record.compress': 'https://numpy.org/doc/stable/reference/generated/numpy.record.compress.html#numpy.record.compress',
                       'numpy.record.conj': 'https://numpy.org/doc/stable/reference/generated/numpy.record.conj.html#numpy.record.conj',
                       'numpy.record.conjugate': 'https://numpy.org/doc/stable/reference/generated/numpy.record.conjugate.html#numpy.record.conjugate',
                       'numpy.record.copy': 'https://numpy.org/doc/stable/reference/generated/numpy.record.copy.html#numpy.record.copy',
                       'numpy.record.cumprod': 'https://numpy.org/doc/stable/reference/generated/numpy.record.cumprod.html#numpy.record.cumprod',
                       'numpy.record.cumsum': 'https://numpy.org/doc/stable/reference/generated/numpy.record.cumsum.html#numpy.record.cumsum',
                       'numpy.record.diagonal': 'https://numpy.org/doc/stable/reference/generated/numpy.record.diagonal.html#numpy.record.diagonal',
                       'numpy.record.dump': 'https://numpy.org/doc/stable/reference/generated/numpy.record.dump.html#numpy.record.dump',
                       'numpy.record.dumps': 'https://numpy.org/doc/stable/reference/generated/numpy.record.dumps.html#numpy.record.dumps',
                       'numpy.record.fill': 'https://numpy.org/doc/stable/reference/generated/numpy.record.fill.html#numpy.record.fill',
                       'numpy.record.flatten': 'https://numpy.org/doc/stable/reference/generated/numpy.record.flatten.html#numpy.record.flatten',
                       'numpy.record.getfield': 'https://numpy.org/doc/stable/reference/generated/numpy.record.getfield.html#numpy.record.getfield',
                       'numpy.record.item': 'https://numpy.org/doc/stable/reference/generated/numpy.record.item.html#numpy.record.item',
                       'numpy.record.itemset': 'https://numpy.org/doc/stable/reference/generated/numpy.record.itemset.html#numpy.record.itemset',
                       'numpy.record.max': 'https://numpy.org/doc/stable/reference/generated/numpy.record.max.html#numpy.record.max',
                       'numpy.record.mean': 'https://numpy.org/doc/stable/reference/generated/numpy.record.mean.html#numpy.record.mean',
                       'numpy.record.min': 'https://numpy.org/doc/stable/reference/generated/numpy.record.min.html#numpy.record.min',
                       'numpy.record.newbyteorder': 'https://numpy.org/doc/stable/reference/generated/numpy.record.newbyteorder.html#numpy.record.newbyteorder',
                       'numpy.record.nonzero': 'https://numpy.org/doc/stable/reference/generated/numpy.record.nonzero.html#numpy.record.nonzero',
                       'numpy.record.pprint': 'https://numpy.org/doc/stable/reference/generated/numpy.record.pprint.html#numpy.record.pprint',
                       'numpy.record.prod': 'https://numpy.org/doc/stable/reference/generated/numpy.record.prod.html#numpy.record.prod',
                       'numpy.record.ptp': 'https://numpy.org/doc/stable/reference/generated/numpy.record.ptp.html#numpy.record.ptp',
                       'numpy.record.put': 'https://numpy.org/doc/stable/reference/generated/numpy.record.put.html#numpy.record.put',
                       'numpy.record.ravel': 'https://numpy.org/doc/stable/reference/generated/numpy.record.ravel.html#numpy.record.ravel',
                       'numpy.record.repeat': 'https://numpy.org/doc/stable/reference/generated/numpy.record.repeat.html#numpy.record.repeat',
                       'numpy.record.reshape': 'https://numpy.org/doc/stable/reference/generated/numpy.record.reshape.html#numpy.record.reshape',
                       'numpy.record.resize': 'https://numpy.org/doc/stable/reference/generated/numpy.record.resize.html#numpy.record.resize',
                       'numpy.record.round': 'https://numpy.org/doc/stable/reference/generated/numpy.record.round.html#numpy.record.round',
                       'numpy.record.searchsorted': 'https://numpy.org/doc/stable/reference/generated/numpy.record.searchsorted.html#numpy.record.searchsorted',
                       'numpy.record.setfield': 'https://numpy.org/doc/stable/reference/generated/numpy.record.setfield.html#numpy.record.setfield',
                       'numpy.record.setflags': 'https://numpy.org/doc/stable/reference/generated/numpy.record.setflags.html#numpy.record.setflags',
                       'numpy.record.sort': 'https://numpy.org/doc/stable/reference/generated/numpy.record.sort.html#numpy.record.sort',
                       'numpy.record.squeeze': 'https://numpy.org/doc/stable/reference/generated/numpy.record.squeeze.html#numpy.record.squeeze',
                       'numpy.record.std': 'https://numpy.org/doc/stable/reference/generated/numpy.record.std.html#numpy.record.std',
                       'numpy.record.sum': 'https://numpy.org/doc/stable/reference/generated/numpy.record.sum.html#numpy.record.sum',
                       'numpy.record.swapaxes': 'https://numpy.org/doc/stable/reference/generated/numpy.record.swapaxes.html#numpy.record.swapaxes',
                       'numpy.record.take': 'https://numpy.org/doc/stable/reference/generated/numpy.record.take.html#numpy.record.take',
                       'numpy.record.tobytes': 'https://numpy.org/doc/stable/reference/generated/numpy.record.tobytes.html#numpy.record.tobytes',
                       'numpy.record.tofile': 'https://numpy.org/doc/stable/reference/generated/numpy.record.tofile.html#numpy.record.tofile',
                       'numpy.record.tolist': 'https://numpy.org/doc/stable/reference/generated/numpy.record.tolist.html#numpy.record.tolist',
                       'numpy.record.tostring': 'https://numpy.org/doc/stable/reference/generated/numpy.record.tostring.html#numpy.record.tostring',
                       'numpy.record.trace': 'https://numpy.org/doc/stable/reference/generated/numpy.record.trace.html#numpy.record.trace',
                       'numpy.record.transpose': 'https://numpy.org/doc/stable/reference/generated/numpy.record.transpose.html#numpy.record.transpose',
                       'numpy.record.var': 'https://numpy.org/doc/stable/reference/generated/numpy.record.var.html#numpy.record.var',
                       'numpy.record.view': 'https://numpy.org/doc/stable/reference/generated/numpy.record.view.html#numpy.record.view',
                       'numpy.repeat': 'https://numpy.org/doc/stable/reference/generated/numpy.repeat.html#numpy.repeat',
                       'numpy.require': 'https://numpy.org/doc/stable/reference/generated/numpy.require.html#numpy.require',
                       'numpy.reshape': 'https://numpy.org/doc/stable/reference/generated/numpy.reshape.html#numpy.reshape',
                       'numpy.resize': 'https://numpy.org/doc/stable/reference/generated/numpy.resize.html#numpy.resize',
                       'numpy.result_type': 'https://numpy.org/doc/stable/reference/generated/numpy.result_type.html#numpy.result_type',
                       'numpy.roll': 'https://numpy.org/doc/stable/reference/generated/numpy.roll.html#numpy.roll',
                       'numpy.rollaxis': 'https://numpy.org/doc/stable/reference/generated/numpy.rollaxis.html#numpy.rollaxis',
                       'numpy.roots': 'https://numpy.org/doc/stable/reference/generated/numpy.roots.html#numpy.roots',
                       'numpy.rot90': 'https://numpy.org/doc/stable/reference/generated/numpy.rot90.html#numpy.rot90',
                       'numpy.round_': 'https://numpy.org/doc/stable/reference/generated/numpy.round_.html#numpy.round_',
                       'numpy.row_stack': 'https://numpy.org/doc/stable/reference/generated/numpy.row_stack.html#numpy.row_stack',
                       'numpy.save': 'https://numpy.org/doc/stable/reference/generated/numpy.save.html#numpy.save',
                       'numpy.savetxt': 'https://numpy.org/doc/stable/reference/generated/numpy.savetxt.html#numpy.savetxt',
                       'numpy.savez': 'https://numpy.org/doc/stable/reference/generated/numpy.savez.html#numpy.savez',
                       'numpy.savez_compressed': 'https://numpy.org/doc/stable/reference/generated/numpy.savez_compressed.html#numpy.savez_compressed',
                       'numpy.sctype2char': 'https://numpy.org/doc/stable/reference/generated/numpy.sctype2char.html#numpy.sctype2char',
                       'numpy.searchsorted': 'https://numpy.org/doc/stable/reference/generated/numpy.searchsorted.html#numpy.searchsorted',
                       'numpy.select': 'https://numpy.org/doc/stable/reference/generated/numpy.select.html#numpy.select',
                       'numpy.set_printoptions': 'https://numpy.org/doc/stable/reference/generated/numpy.set_printoptions.html#numpy.set_printoptions',
                       'numpy.set_string_function': 'https://numpy.org/doc/stable/reference/generated/numpy.set_string_function.html#numpy.set_string_function',
                       'numpy.setbufsize': 'https://numpy.org/doc/stable/reference/generated/numpy.setbufsize.html#numpy.setbufsize',
                       'numpy.setdiff1d': 'https://numpy.org/doc/stable/reference/generated/numpy.setdiff1d.html#numpy.setdiff1d',
                       'numpy.seterr': 'https://numpy.org/doc/stable/reference/generated/numpy.seterr.html#numpy.seterr',
                       'numpy.seterrcall': 'https://numpy.org/doc/stable/reference/generated/numpy.seterrcall.html#numpy.seterrcall',
                       'numpy.seterrobj': 'https://numpy.org/doc/stable/reference/generated/numpy.seterrobj.html#numpy.seterrobj',
                       'numpy.setxor1d': 'https://numpy.org/doc/stable/reference/generated/numpy.setxor1d.html#numpy.setxor1d',
                       'numpy.shape': 'https://numpy.org/doc/stable/reference/generated/numpy.shape.html#numpy.shape',
                       'numpy.shares_memory': 'https://numpy.org/doc/stable/reference/generated/numpy.shares_memory.html#numpy.shares_memory',
                       'numpy.short': 'https://numpy.org/doc/stable/reference/arrays.scalars.html#numpy.short',
                       'numpy.show_config': 'https://numpy.org/doc/stable/reference/generated/numpy.show_config.html#numpy.show_config',
                       'numpy.signedinteger': 'https://numpy.org/doc/stable/reference/arrays.scalars.html#numpy.signedinteger',
                       'numpy.sinc': 'https://numpy.org/doc/stable/reference/generated/numpy.sinc.html#numpy.sinc',
                       'numpy.single': 'https://numpy.org/doc/stable/reference/arrays.scalars.html#numpy.single',
                       'numpy.sort': 'https://numpy.org/doc/stable/reference/generated/numpy.sort.html#numpy.sort',
                       'numpy.sort_complex': 'https://numpy.org/doc/stable/reference/generated/numpy.sort_complex.html#numpy.sort_complex',
                       'numpy.source': 'https://numpy.org/doc/stable/reference/generated/numpy.source.html#numpy.source',
                       'numpy.split': 'https://numpy.org/doc/stable/reference/generated/numpy.split.html#numpy.split',
                       'numpy.squeeze': 'https://numpy.org/doc/stable/reference/generated/numpy.squeeze.html#numpy.squeeze',
                       'numpy.stack': 'https://numpy.org/doc/stable/reference/generated/numpy.stack.html#numpy.stack',
                       'numpy.std': 'https://numpy.org/doc/stable/reference/generated/numpy.std.html#numpy.std',
                       'numpy.str_': 'https://numpy.org/doc/stable/reference/arrays.scalars.html#numpy.str_',
                       'numpy.sum': 'https://numpy.org/doc/stable/reference/generated/numpy.sum.html#numpy.sum',
                       'numpy.swapaxes': 'https://numpy.org/doc/stable/reference/generated/numpy.swapaxes.html#numpy.swapaxes',
                       'numpy.take': 'https://numpy.org/doc/stable/reference/generated/numpy.take.html#numpy.take',
                       'numpy.take_along_axis': 'https://numpy.org/doc/stable/reference/generated/numpy.take_along_axis.html#numpy.take_along_axis',
                       'numpy.tensordot': 'https://numpy.org/doc/stable/reference/generated/numpy.tensordot.html#numpy.tensordot',
                       'numpy.test': 'https://numpy.org/doc/stable/reference/testing.html#numpy.test',
                       'numpy.testing': 'https://numpy.org/doc/stable/reference/routines.testing.html#module-numpy.testing',
                       'numpy.tile': 'https://numpy.org/doc/stable/reference/generated/numpy.tile.html#numpy.tile',
                       'numpy.timedelta64': 'https://numpy.org/doc/stable/reference/arrays.scalars.html#numpy.timedelta64',
                       'numpy.trace': 'https://numpy.org/doc/stable/reference/generated/numpy.trace.html#numpy.trace',
                       'numpy.transpose': 'https://numpy.org/doc/stable/reference/generated/numpy.transpose.html#numpy.transpose',
                       'numpy.trapz': 'https://numpy.org/doc/stable/reference/generated/numpy.trapz.html#numpy.trapz',
                       'numpy.tri': 'https://numpy.org/doc/stable/reference/generated/numpy.tri.html#numpy.tri',
                       'numpy.tril': 'https://numpy.org/doc/stable/reference/generated/numpy.tril.html#numpy.tril',
                       'numpy.tril_indices': 'https://numpy.org/doc/stable/reference/generated/numpy.tril_indices.html#numpy.tril_indices',
                       'numpy.tril_indices_from': 'https://numpy.org/doc/stable/reference/generated/numpy.tril_indices_from.html#numpy.tril_indices_from',
                       'numpy.trim_zeros': 'https://numpy.org/doc/stable/reference/generated/numpy.trim_zeros.html#numpy.trim_zeros',
                       'numpy.triu': 'https://numpy.org/doc/stable/reference/generated/numpy.triu.html#numpy.triu',
                       'numpy.triu_indices': 'https://numpy.org/doc/stable/reference/generated/numpy.triu_indices.html#numpy.triu_indices',
                       'numpy.triu_indices_from': 'https://numpy.org/doc/stable/reference/generated/numpy.triu_indices_from.html#numpy.triu_indices_from',
                       'numpy.typename': 'https://numpy.org/doc/stable/reference/generated/numpy.typename.html#numpy.typename',
                       'numpy.typing': 'https://numpy.org/doc/stable/reference/typing.html#module-numpy.typing',
                       'numpy.ubyte': 'https://numpy.org/doc/stable/reference/arrays.scalars.html#numpy.ubyte',
                       'numpy.ufunc': 'https://numpy.org/doc/stable/reference/generated/numpy.ufunc.html#numpy.ufunc',
                       'numpy.ufunc.__call__': 'https://numpy.org/doc/stable/reference/generated/numpy.ufunc.__call__.html#numpy.ufunc.__call__',
                       'numpy.ufunc.accumulate': 'https://numpy.org/doc/stable/reference/generated/numpy.ufunc.accumulate.html#numpy.ufunc.accumulate',
                       'numpy.ufunc.at': 'https://numpy.org/doc/stable/reference/generated/numpy.ufunc.at.html#numpy.ufunc.at',
                       'numpy.ufunc.outer': 'https://numpy.org/doc/stable/reference/generated/numpy.ufunc.outer.html#numpy.ufunc.outer',
                       'numpy.ufunc.reduce': 'https://numpy.org/doc/stable/reference/generated/numpy.ufunc.reduce.html#numpy.ufunc.reduce',
                       'numpy.ufunc.reduceat': 'https://numpy.org/doc/stable/reference/generated/numpy.ufunc.reduceat.html#numpy.ufunc.reduceat',
                       'numpy.uint': 'https://numpy.org/doc/stable/reference/arrays.scalars.html#numpy.uint',
                       'numpy.uintc': 'https://numpy.org/doc/stable/reference/arrays.scalars.html#numpy.uintc',
                       'numpy.ulonglong': 'https://numpy.org/doc/stable/reference/arrays.scalars.html#numpy.ulonglong',
                       'numpy.union1d': 'https://numpy.org/doc/stable/reference/generated/numpy.union1d.html#numpy.union1d',
                       'numpy.unique': 'https://numpy.org/doc/stable/reference/generated/numpy.unique.html#numpy.unique',
                       'numpy.unpackbits': 'https://numpy.org/doc/stable/reference/generated/numpy.unpackbits.html#numpy.unpackbits',
                       'numpy.unravel_index': 'https://numpy.org/doc/stable/reference/generated/numpy.unravel_index.html#numpy.unravel_index',
                       'numpy.unsignedinteger': 'https://numpy.org/doc/stable/reference/arrays.scalars.html#numpy.unsignedinteger',
                       'numpy.unwrap': 'https://numpy.org/doc/stable/reference/generated/numpy.unwrap.html#numpy.unwrap',
                       'numpy.ushort': 'https://numpy.org/doc/stable/reference/arrays.scalars.html#numpy.ushort',
                       'numpy.vander': 'https://numpy.org/doc/stable/reference/generated/numpy.vander.html#numpy.vander',
                       'numpy.var': 'https://numpy.org/doc/stable/reference/generated/numpy.var.html#numpy.var',
                       'numpy.vdot': 'https://numpy.org/doc/stable/reference/generated/numpy.vdot.html#numpy.vdot',
                       'numpy.vectorize': 'https://numpy.org/doc/stable/reference/generated/numpy.vectorize.html#numpy.vectorize',
                       'numpy.vectorize.__call__': 'https://numpy.org/doc/stable/reference/generated/numpy.vectorize.__call__.html#numpy.vectorize.__call__',
                       'numpy.void': 'https://numpy.org/doc/stable/reference/arrays.scalars.html#numpy.void',
                       'numpy.vsplit': 'https://numpy.org/doc/stable/reference/generated/numpy.vsplit.html#numpy.vsplit',
                       'numpy.vstack': 'https://numpy.org/doc/stable/reference/generated/numpy.vstack.html#numpy.vstack',
                       'numpy.where': 'https://numpy.org/doc/stable/reference/generated/numpy.where.html#numpy.where',
                       'numpy.who': 'https://numpy.org/doc/stable/reference/generated/numpy.who.html#numpy.who',
                       'numpy.zeros': 'https://numpy.org/doc/stable/reference/generated/numpy.zeros.html#numpy.zeros',
                       'numpy.zeros_like': 'https://numpy.org/doc/stable/reference/generated/numpy.zeros_like.html#numpy.zeros_like'},
            'numpy.char': { 'numpy.char.add': 'https://numpy.org/doc/stable/reference/generated/numpy.char.add.html#numpy.char.add',
                            'numpy.char.array': 'https://numpy.org/doc/stable/reference/generated/numpy.char.array.html#numpy.char.array',
                            'numpy.char.asarray': 'https://numpy.org/doc/stable/reference/generated/numpy.char.asarray.html#numpy.char.asarray',
                            'numpy.char.capitalize': 'https://numpy.org/doc/stable/reference/generated/numpy.char.capitalize.html#numpy.char.capitalize',
                            'numpy.char.center': 'https://numpy.org/doc/stable/reference/generated/numpy.char.center.html#numpy.char.center',
                            'numpy.char.chararray': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.html#numpy.char.chararray',
                            'numpy.char.chararray.all': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.all.html#numpy.char.chararray.all',
                            'numpy.char.chararray.any': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.any.html#numpy.char.chararray.any',
                            'numpy.char.chararray.argmax': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.argmax.html#numpy.char.chararray.argmax',
                            'numpy.char.chararray.argmin': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.argmin.html#numpy.char.chararray.argmin',
                            'numpy.char.chararray.argpartition': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.argpartition.html#numpy.char.chararray.argpartition',
                            'numpy.char.chararray.argsort': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.argsort.html#numpy.char.chararray.argsort',
                            'numpy.char.chararray.astype': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.astype.html#numpy.char.chararray.astype',
                            'numpy.char.chararray.byteswap': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.byteswap.html#numpy.char.chararray.byteswap',
                            'numpy.char.chararray.capitalize': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.capitalize.html#numpy.char.chararray.capitalize',
                            'numpy.char.chararray.center': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.center.html#numpy.char.chararray.center',
                            'numpy.char.chararray.choose': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.choose.html#numpy.char.chararray.choose',
                            'numpy.char.chararray.clip': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.clip.html#numpy.char.chararray.clip',
                            'numpy.char.chararray.compress': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.compress.html#numpy.char.chararray.compress',
                            'numpy.char.chararray.conj': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.conj.html#numpy.char.chararray.conj',
                            'numpy.char.chararray.conjugate': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.conjugate.html#numpy.char.chararray.conjugate',
                            'numpy.char.chararray.copy': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.copy.html#numpy.char.chararray.copy',
                            'numpy.char.chararray.count': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.count.html#numpy.char.chararray.count',
                            'numpy.char.chararray.cumprod': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.cumprod.html#numpy.char.chararray.cumprod',
                            'numpy.char.chararray.cumsum': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.cumsum.html#numpy.char.chararray.cumsum',
                            'numpy.char.chararray.decode': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.decode.html#numpy.char.chararray.decode',
                            'numpy.char.chararray.diagonal': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.diagonal.html#numpy.char.chararray.diagonal',
                            'numpy.char.chararray.dot': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.dot.html#numpy.char.chararray.dot',
                            'numpy.char.chararray.dump': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.dump.html#numpy.char.chararray.dump',
                            'numpy.char.chararray.dumps': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.dumps.html#numpy.char.chararray.dumps',
                            'numpy.char.chararray.encode': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.encode.html#numpy.char.chararray.encode',
                            'numpy.char.chararray.endswith': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.endswith.html#numpy.char.chararray.endswith',
                            'numpy.char.chararray.expandtabs': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.expandtabs.html#numpy.char.chararray.expandtabs',
                            'numpy.char.chararray.fill': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.fill.html#numpy.char.chararray.fill',
                            'numpy.char.chararray.find': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.find.html#numpy.char.chararray.find',
                            'numpy.char.chararray.flatten': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.flatten.html#numpy.char.chararray.flatten',
                            'numpy.char.chararray.getfield': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.getfield.html#numpy.char.chararray.getfield',
                            'numpy.char.chararray.index': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.index.html#numpy.char.chararray.index',
                            'numpy.char.chararray.isalnum': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.isalnum.html#numpy.char.chararray.isalnum',
                            'numpy.char.chararray.isalpha': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.isalpha.html#numpy.char.chararray.isalpha',
                            'numpy.char.chararray.isdecimal': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.isdecimal.html#numpy.char.chararray.isdecimal',
                            'numpy.char.chararray.isdigit': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.isdigit.html#numpy.char.chararray.isdigit',
                            'numpy.char.chararray.islower': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.islower.html#numpy.char.chararray.islower',
                            'numpy.char.chararray.isnumeric': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.isnumeric.html#numpy.char.chararray.isnumeric',
                            'numpy.char.chararray.isspace': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.isspace.html#numpy.char.chararray.isspace',
                            'numpy.char.chararray.istitle': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.istitle.html#numpy.char.chararray.istitle',
                            'numpy.char.chararray.isupper': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.isupper.html#numpy.char.chararray.isupper',
                            'numpy.char.chararray.item': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.item.html#numpy.char.chararray.item',
                            'numpy.char.chararray.itemset': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.itemset.html#numpy.char.chararray.itemset',
                            'numpy.char.chararray.join': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.join.html#numpy.char.chararray.join',
                            'numpy.char.chararray.ljust': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.ljust.html#numpy.char.chararray.ljust',
                            'numpy.char.chararray.lower': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.lower.html#numpy.char.chararray.lower',
                            'numpy.char.chararray.lstrip': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.lstrip.html#numpy.char.chararray.lstrip',
                            'numpy.char.chararray.max': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.max.html#numpy.char.chararray.max',
                            'numpy.char.chararray.mean': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.mean.html#numpy.char.chararray.mean',
                            'numpy.char.chararray.min': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.min.html#numpy.char.chararray.min',
                            'numpy.char.chararray.newbyteorder': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.newbyteorder.html#numpy.char.chararray.newbyteorder',
                            'numpy.char.chararray.nonzero': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.nonzero.html#numpy.char.chararray.nonzero',
                            'numpy.char.chararray.partition': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.partition.html#numpy.char.chararray.partition',
                            'numpy.char.chararray.prod': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.prod.html#numpy.char.chararray.prod',
                            'numpy.char.chararray.ptp': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.ptp.html#numpy.char.chararray.ptp',
                            'numpy.char.chararray.put': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.put.html#numpy.char.chararray.put',
                            'numpy.char.chararray.ravel': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.ravel.html#numpy.char.chararray.ravel',
                            'numpy.char.chararray.repeat': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.repeat.html#numpy.char.chararray.repeat',
                            'numpy.char.chararray.replace': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.replace.html#numpy.char.chararray.replace',
                            'numpy.char.chararray.reshape': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.reshape.html#numpy.char.chararray.reshape',
                            'numpy.char.chararray.resize': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.resize.html#numpy.char.chararray.resize',
                            'numpy.char.chararray.rfind': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.rfind.html#numpy.char.chararray.rfind',
                            'numpy.char.chararray.rindex': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.rindex.html#numpy.char.chararray.rindex',
                            'numpy.char.chararray.rjust': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.rjust.html#numpy.char.chararray.rjust',
                            'numpy.char.chararray.round': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.round.html#numpy.char.chararray.round',
                            'numpy.char.chararray.rpartition': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.rpartition.html#numpy.char.chararray.rpartition',
                            'numpy.char.chararray.rsplit': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.rsplit.html#numpy.char.chararray.rsplit',
                            'numpy.char.chararray.rstrip': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.rstrip.html#numpy.char.chararray.rstrip',
                            'numpy.char.chararray.searchsorted': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.searchsorted.html#numpy.char.chararray.searchsorted',
                            'numpy.char.chararray.setfield': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.setfield.html#numpy.char.chararray.setfield',
                            'numpy.char.chararray.setflags': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.setflags.html#numpy.char.chararray.setflags',
                            'numpy.char.chararray.sort': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.sort.html#numpy.char.chararray.sort',
                            'numpy.char.chararray.split': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.split.html#numpy.char.chararray.split',
                            'numpy.char.chararray.splitlines': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.splitlines.html#numpy.char.chararray.splitlines',
                            'numpy.char.chararray.squeeze': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.squeeze.html#numpy.char.chararray.squeeze',
                            'numpy.char.chararray.startswith': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.startswith.html#numpy.char.chararray.startswith',
                            'numpy.char.chararray.std': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.std.html#numpy.char.chararray.std',
                            'numpy.char.chararray.strip': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.strip.html#numpy.char.chararray.strip',
                            'numpy.char.chararray.sum': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.sum.html#numpy.char.chararray.sum',
                            'numpy.char.chararray.swapaxes': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.swapaxes.html#numpy.char.chararray.swapaxes',
                            'numpy.char.chararray.swapcase': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.swapcase.html#numpy.char.chararray.swapcase',
                            'numpy.char.chararray.take': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.take.html#numpy.char.chararray.take',
                            'numpy.char.chararray.title': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.title.html#numpy.char.chararray.title',
                            'numpy.char.chararray.tobytes': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.tobytes.html#numpy.char.chararray.tobytes',
                            'numpy.char.chararray.tofile': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.tofile.html#numpy.char.chararray.tofile',
                            'numpy.char.chararray.tolist': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.tolist.html#numpy.char.chararray.tolist',
                            'numpy.char.chararray.tostring': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.tostring.html#numpy.char.chararray.tostring',
                            'numpy.char.chararray.trace': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.trace.html#numpy.char.chararray.trace',
                            'numpy.char.chararray.translate': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.translate.html#numpy.char.chararray.translate',
                            'numpy.char.chararray.transpose': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.transpose.html#numpy.char.chararray.transpose',
                            'numpy.char.chararray.upper': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.upper.html#numpy.char.chararray.upper',
                            'numpy.char.chararray.var': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.var.html#numpy.char.chararray.var',
                            'numpy.char.chararray.view': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.view.html#numpy.char.chararray.view',
                            'numpy.char.chararray.zfill': 'https://numpy.org/doc/stable/reference/generated/numpy.char.chararray.zfill.html#numpy.char.chararray.zfill',
                            'numpy.char.compare_chararrays': 'https://numpy.org/doc/stable/reference/generated/numpy.char.compare_chararrays.html#numpy.char.compare_chararrays',
                            'numpy.char.count': 'https://numpy.org/doc/stable/reference/generated/numpy.char.count.html#numpy.char.count',
                            'numpy.char.decode': 'https://numpy.org/doc/stable/reference/generated/numpy.char.decode.html#numpy.char.decode',
                            'numpy.char.encode': 'https://numpy.org/doc/stable/reference/generated/numpy.char.encode.html#numpy.char.encode',
                            'numpy.char.endswith': 'https://numpy.org/doc/stable/reference/generated/numpy.char.endswith.html#numpy.char.endswith',
                            'numpy.char.equal': 'https://numpy.org/doc/stable/reference/generated/numpy.char.equal.html#numpy.char.equal',
                            'numpy.char.expandtabs': 'https://numpy.org/doc/stable/reference/generated/numpy.char.expandtabs.html#numpy.char.expandtabs',
                            'numpy.char.find': 'https://numpy.org/doc/stable/reference/generated/numpy.char.find.html#numpy.char.find',
                            'numpy.char.greater': 'https://numpy.org/doc/stable/reference/generated/numpy.char.greater.html#numpy.char.greater',
                            'numpy.char.greater_equal': 'https://numpy.org/doc/stable/reference/generated/numpy.char.greater_equal.html#numpy.char.greater_equal',
                            'numpy.char.index': 'https://numpy.org/doc/stable/reference/generated/numpy.char.index.html#numpy.char.index',
                            'numpy.char.isalnum': 'https://numpy.org/doc/stable/reference/generated/numpy.char.isalnum.html#numpy.char.isalnum',
                            'numpy.char.isalpha': 'https://numpy.org/doc/stable/reference/generated/numpy.char.isalpha.html#numpy.char.isalpha',
                            'numpy.char.isdecimal': 'https://numpy.org/doc/stable/reference/generated/numpy.char.isdecimal.html#numpy.char.isdecimal',
                            'numpy.char.isdigit': 'https://numpy.org/doc/stable/reference/generated/numpy.char.isdigit.html#numpy.char.isdigit',
                            'numpy.char.islower': 'https://numpy.org/doc/stable/reference/generated/numpy.char.islower.html#numpy.char.islower',
                            'numpy.char.isnumeric': 'https://numpy.org/doc/stable/reference/generated/numpy.char.isnumeric.html#numpy.char.isnumeric',
                            'numpy.char.isspace': 'https://numpy.org/doc/stable/reference/generated/numpy.char.isspace.html#numpy.char.isspace',
                            'numpy.char.istitle': 'https://numpy.org/doc/stable/reference/generated/numpy.char.istitle.html#numpy.char.istitle',
                            'numpy.char.isupper': 'https://numpy.org/doc/stable/reference/generated/numpy.char.isupper.html#numpy.char.isupper',
                            'numpy.char.join': 'https://numpy.org/doc/stable/reference/generated/numpy.char.join.html#numpy.char.join',
                            'numpy.char.less': 'https://numpy.org/doc/stable/reference/generated/numpy.char.less.html#numpy.char.less',
                            'numpy.char.less_equal': 'https://numpy.org/doc/stable/reference/generated/numpy.char.less_equal.html#numpy.char.less_equal',
                            'numpy.char.ljust': 'https://numpy.org/doc/stable/reference/generated/numpy.char.ljust.html#numpy.char.ljust',
                            'numpy.char.lower': 'https://numpy.org/doc/stable/reference/generated/numpy.char.lower.html#numpy.char.lower',
                            'numpy.char.lstrip': 'https://numpy.org/doc/stable/reference/generated/numpy.char.lstrip.html#numpy.char.lstrip',
                            'numpy.char.mod': 'https://numpy.org/doc/stable/reference/generated/numpy.char.mod.html#numpy.char.mod',
                            'numpy.char.multiply': 'https://numpy.org/doc/stable/reference/generated/numpy.char.multiply.html#numpy.char.multiply',
                            'numpy.char.not_equal': 'https://numpy.org/doc/stable/reference/generated/numpy.char.not_equal.html#numpy.char.not_equal',
                            'numpy.char.partition': 'https://numpy.org/doc/stable/reference/generated/numpy.char.partition.html#numpy.char.partition',
                            'numpy.char.replace': 'https://numpy.org/doc/stable/reference/generated/numpy.char.replace.html#numpy.char.replace',
                            'numpy.char.rfind': 'https://numpy.org/doc/stable/reference/generated/numpy.char.rfind.html#numpy.char.rfind',
                            'numpy.char.rindex': 'https://numpy.org/doc/stable/reference/generated/numpy.char.rindex.html#numpy.char.rindex',
                            'numpy.char.rjust': 'https://numpy.org/doc/stable/reference/generated/numpy.char.rjust.html#numpy.char.rjust',
                            'numpy.char.rpartition': 'https://numpy.org/doc/stable/reference/generated/numpy.char.rpartition.html#numpy.char.rpartition',
                            'numpy.char.rsplit': 'https://numpy.org/doc/stable/reference/generated/numpy.char.rsplit.html#numpy.char.rsplit',
                            'numpy.char.rstrip': 'https://numpy.org/doc/stable/reference/generated/numpy.char.rstrip.html#numpy.char.rstrip',
                            'numpy.char.split': 'https://numpy.org/doc/stable/reference/generated/numpy.char.split.html#numpy.char.split',
                            'numpy.char.splitlines': 'https://numpy.org/doc/stable/reference/generated/numpy.char.splitlines.html#numpy.char.splitlines',
                            'numpy.char.startswith': 'https://numpy.org/doc/stable/reference/generated/numpy.char.startswith.html#numpy.char.startswith',
                            'numpy.char.str_len': 'https://numpy.org/doc/stable/reference/generated/numpy.char.str_len.html#numpy.char.str_len',
                            'numpy.char.strip': 'https://numpy.org/doc/stable/reference/generated/numpy.char.strip.html#numpy.char.strip',
                            'numpy.char.swapcase': 'https://numpy.org/doc/stable/reference/generated/numpy.char.swapcase.html#numpy.char.swapcase',
                            'numpy.char.title': 'https://numpy.org/doc/stable/reference/generated/numpy.char.title.html#numpy.char.title',
                            'numpy.char.translate': 'https://numpy.org/doc/stable/reference/generated/numpy.char.translate.html#numpy.char.translate',
                            'numpy.char.upper': 'https://numpy.org/doc/stable/reference/generated/numpy.char.upper.html#numpy.char.upper',
                            'numpy.char.zfill': 'https://numpy.org/doc/stable/reference/generated/numpy.char.zfill.html#numpy.char.zfill'},
            'numpy.core.defchararray': { 'numpy.core.defchararray.array': 'https://numpy.org/doc/stable/reference/generated/numpy.core.defchararray.array.html#numpy.core.defchararray.array',
                                         'numpy.core.defchararray.asarray': 'https://numpy.org/doc/stable/reference/generated/numpy.core.defchararray.asarray.html#numpy.core.defchararray.asarray'},
            'numpy.core.records': { 'numpy.core.records.array': 'https://numpy.org/doc/stable/reference/generated/numpy.core.records.array.html#numpy.core.records.array',
                                    'numpy.core.records.fromarrays': 'https://numpy.org/doc/stable/reference/generated/numpy.core.records.fromarrays.html#numpy.core.records.fromarrays',
                                    'numpy.core.records.fromfile': 'https://numpy.org/doc/stable/reference/generated/numpy.core.records.fromfile.html#numpy.core.records.fromfile',
                                    'numpy.core.records.fromrecords': 'https://numpy.org/doc/stable/reference/generated/numpy.core.records.fromrecords.html#numpy.core.records.fromrecords',
                                    'numpy.core.records.fromstring': 'https://numpy.org/doc/stable/reference/generated/numpy.core.records.fromstring.html#numpy.core.records.fromstring'},
            'numpy.ctypeslib': { 'numpy.ctypeslib.as_array': 'https://numpy.org/doc/stable/reference/routines.ctypeslib.html#numpy.ctypeslib.as_array',
                                 'numpy.ctypeslib.as_ctypes': 'https://numpy.org/doc/stable/reference/routines.ctypeslib.html#numpy.ctypeslib.as_ctypes',
                                 'numpy.ctypeslib.as_ctypes_type': 'https://numpy.org/doc/stable/reference/routines.ctypeslib.html#numpy.ctypeslib.as_ctypes_type',
                                 'numpy.ctypeslib.c_intp': 'https://numpy.org/doc/stable/reference/routines.ctypeslib.html#numpy.ctypeslib.c_intp',
                                 'numpy.ctypeslib.load_library': 'https://numpy.org/doc/stable/reference/routines.ctypeslib.html#numpy.ctypeslib.load_library',
                                 'numpy.ctypeslib.ndpointer': 'https://numpy.org/doc/stable/reference/routines.ctypeslib.html#numpy.ctypeslib.ndpointer'},
            'numpy.distutils': { 'numpy.distutils.ccompiler': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler.html#module-numpy.distutils.ccompiler',
                                 'numpy.distutils.ccompiler_opt': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.html#module-numpy.distutils.ccompiler_opt',
                                 'numpy.distutils.exec_command': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.exec_command.html#module-numpy.distutils.exec_command',
                                 'numpy.distutils.misc_util': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#module-numpy.distutils.misc_util'},
            'numpy.distutils.ccompiler': { 'numpy.distutils.ccompiler.CCompiler_compile': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler.CCompiler_compile.html#numpy.distutils.ccompiler.CCompiler_compile',
                                           'numpy.distutils.ccompiler.CCompiler_customize': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler.CCompiler_customize.html#numpy.distutils.ccompiler.CCompiler_customize',
                                           'numpy.distutils.ccompiler.CCompiler_customize_cmd': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler.CCompiler_customize_cmd.html#numpy.distutils.ccompiler.CCompiler_customize_cmd',
                                           'numpy.distutils.ccompiler.CCompiler_cxx_compiler': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler.CCompiler_cxx_compiler.html#numpy.distutils.ccompiler.CCompiler_cxx_compiler',
                                           'numpy.distutils.ccompiler.CCompiler_find_executables': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler.CCompiler_find_executables.html#numpy.distutils.ccompiler.CCompiler_find_executables',
                                           'numpy.distutils.ccompiler.CCompiler_get_version': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler.CCompiler_get_version.html#numpy.distutils.ccompiler.CCompiler_get_version',
                                           'numpy.distutils.ccompiler.CCompiler_object_filenames': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler.CCompiler_object_filenames.html#numpy.distutils.ccompiler.CCompiler_object_filenames',
                                           'numpy.distutils.ccompiler.CCompiler_show_customization': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler.CCompiler_show_customization.html#numpy.distutils.ccompiler.CCompiler_show_customization',
                                           'numpy.distutils.ccompiler.CCompiler_spawn': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler.CCompiler_spawn.html#numpy.distutils.ccompiler.CCompiler_spawn',
                                           'numpy.distutils.ccompiler.gen_lib_options': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler.gen_lib_options.html#numpy.distutils.ccompiler.gen_lib_options',
                                           'numpy.distutils.ccompiler.new_compiler': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler.new_compiler.html#numpy.distutils.ccompiler.new_compiler',
                                           'numpy.distutils.ccompiler.replace_method': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler.replace_method.html#numpy.distutils.ccompiler.replace_method',
                                           'numpy.distutils.ccompiler.simple_version_match': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler.simple_version_match.html#numpy.distutils.ccompiler.simple_version_match'},
            'numpy.distutils.ccompiler_opt': { 'numpy.distutils.ccompiler_opt.CCompilerOpt': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.html#numpy.distutils.ccompiler_opt.CCompilerOpt',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.cache_flush': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.cache_flush.html#numpy.distutils.ccompiler_opt.CCompilerOpt.cache_flush',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.cache_hash': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.cache_hash.html#numpy.distutils.ccompiler_opt.CCompilerOpt.cache_hash',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.cc_normalize_flags': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.cc_normalize_flags.html#numpy.distutils.ccompiler_opt.CCompilerOpt.cc_normalize_flags',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.cc_test_cexpr': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.cc_test_cexpr.html#numpy.distutils.ccompiler_opt.CCompilerOpt.cc_test_cexpr',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.cc_test_flags': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.cc_test_flags.html#numpy.distutils.ccompiler_opt.CCompilerOpt.cc_test_flags',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.conf_features_partial': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.conf_features_partial.html#numpy.distutils.ccompiler_opt.CCompilerOpt.conf_features_partial',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.cpu_baseline_flags': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.cpu_baseline_flags.html#numpy.distutils.ccompiler_opt.CCompilerOpt.cpu_baseline_flags',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.cpu_baseline_names': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.cpu_baseline_names.html#numpy.distutils.ccompiler_opt.CCompilerOpt.cpu_baseline_names',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.cpu_dispatch_names': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.cpu_dispatch_names.html#numpy.distutils.ccompiler_opt.CCompilerOpt.cpu_dispatch_names',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.dist_compile': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.dist_compile.html#numpy.distutils.ccompiler_opt.CCompilerOpt.dist_compile',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.dist_error': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.dist_error.html#numpy.distutils.ccompiler_opt.CCompilerOpt.dist_error',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.dist_fatal': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.dist_fatal.html#numpy.distutils.ccompiler_opt.CCompilerOpt.dist_fatal',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.dist_info': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.dist_info.html#numpy.distutils.ccompiler_opt.CCompilerOpt.dist_info',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.dist_load_module': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.dist_load_module.html#numpy.distutils.ccompiler_opt.CCompilerOpt.dist_load_module',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.dist_log': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.dist_log.html#numpy.distutils.ccompiler_opt.CCompilerOpt.dist_log',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.dist_test': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.dist_test.html#numpy.distutils.ccompiler_opt.CCompilerOpt.dist_test',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.feature_ahead': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.feature_ahead.html#numpy.distutils.ccompiler_opt.CCompilerOpt.feature_ahead',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.feature_c_preprocessor': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.feature_c_preprocessor.html#numpy.distutils.ccompiler_opt.CCompilerOpt.feature_c_preprocessor',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.feature_can_autovec': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.feature_can_autovec.html#numpy.distutils.ccompiler_opt.CCompilerOpt.feature_can_autovec',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.feature_detect': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.feature_detect.html#numpy.distutils.ccompiler_opt.CCompilerOpt.feature_detect',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.feature_extra_checks': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.feature_extra_checks.html#numpy.distutils.ccompiler_opt.CCompilerOpt.feature_extra_checks',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.feature_flags': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.feature_flags.html#numpy.distutils.ccompiler_opt.CCompilerOpt.feature_flags',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.feature_get_til': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.feature_get_til.html#numpy.distutils.ccompiler_opt.CCompilerOpt.feature_get_til',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.feature_implies': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.feature_implies.html#numpy.distutils.ccompiler_opt.CCompilerOpt.feature_implies',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.feature_implies_c': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.feature_implies_c.html#numpy.distutils.ccompiler_opt.CCompilerOpt.feature_implies_c',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.feature_is_exist': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.feature_is_exist.html#numpy.distutils.ccompiler_opt.CCompilerOpt.feature_is_exist',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.feature_is_supported': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.feature_is_supported.html#numpy.distutils.ccompiler_opt.CCompilerOpt.feature_is_supported',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.feature_names': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.feature_names.html#numpy.distutils.ccompiler_opt.CCompilerOpt.feature_names',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.feature_sorted': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.feature_sorted.html#numpy.distutils.ccompiler_opt.CCompilerOpt.feature_sorted',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.feature_test': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.feature_test.html#numpy.distutils.ccompiler_opt.CCompilerOpt.feature_test',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.feature_untied': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.feature_untied.html#numpy.distutils.ccompiler_opt.CCompilerOpt.feature_untied',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.generate_dispatch_header': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.generate_dispatch_header.html#numpy.distutils.ccompiler_opt.CCompilerOpt.generate_dispatch_header',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.is_cached': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.is_cached.html#numpy.distutils.ccompiler_opt.CCompilerOpt.is_cached',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.me': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.me.html#numpy.distutils.ccompiler_opt.CCompilerOpt.me',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.parse_targets': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.parse_targets.html#numpy.distutils.ccompiler_opt.CCompilerOpt.parse_targets',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.report': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.report.html#numpy.distutils.ccompiler_opt.CCompilerOpt.report',
                                               'numpy.distutils.ccompiler_opt.CCompilerOpt.try_dispatch': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.CCompilerOpt.try_dispatch.html#numpy.distutils.ccompiler_opt.CCompilerOpt.try_dispatch',
                                               'numpy.distutils.ccompiler_opt.new_ccompiler_opt': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.ccompiler_opt.new_ccompiler_opt.html#numpy.distutils.ccompiler_opt.new_ccompiler_opt'},
            'numpy.distutils.core': { 'numpy.distutils.core.Extension': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.core.Extension.html#numpy.distutils.core.Extension',
                                      'numpy.distutils.core.Extension.has_cxx_sources': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.core.Extension.has_cxx_sources.html#numpy.distutils.core.Extension.has_cxx_sources',
                                      'numpy.distutils.core.Extension.has_f2py_sources': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.core.Extension.has_f2py_sources.html#numpy.distutils.core.Extension.has_f2py_sources'},
            'numpy.distutils.exec_command': { 'numpy.distutils.exec_command.exec_command': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.exec_command.exec_command.html#numpy.distutils.exec_command.exec_command',
                                              'numpy.distutils.exec_command.filepath_from_subprocess_output': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.exec_command.filepath_from_subprocess_output.html#numpy.distutils.exec_command.filepath_from_subprocess_output',
                                              'numpy.distutils.exec_command.find_executable': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.exec_command.find_executable.html#numpy.distutils.exec_command.find_executable',
                                              'numpy.distutils.exec_command.forward_bytes_to_stdout': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.exec_command.forward_bytes_to_stdout.html#numpy.distutils.exec_command.forward_bytes_to_stdout',
                                              'numpy.distutils.exec_command.get_pythonexe': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.exec_command.get_pythonexe.html#numpy.distutils.exec_command.get_pythonexe',
                                              'numpy.distutils.exec_command.temp_file_name': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.exec_command.temp_file_name.html#numpy.distutils.exec_command.temp_file_name'},
            'numpy.distutils.extension': { 'numpy.distutils.extension.Extension': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.core.Extension.html#numpy.distutils.core.Extension'},
            'numpy.distutils.log': { 'numpy.distutils.log.set_verbosity': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.log.set_verbosity.html#numpy.distutils.log.set_verbosity'},
            'numpy.distutils.misc_util': { 'numpy.distutils.misc_util.Configuration': 'https://numpy.org/doc/stable/reference/distutils.html#numpy.distutils.misc_util.Configuration',
                                           'numpy.distutils.misc_util.Configuration.add_data_dir': 'https://numpy.org/doc/stable/reference/distutils.html#numpy.distutils.misc_util.Configuration.add_data_dir',
                                           'numpy.distutils.misc_util.Configuration.add_data_files': 'https://numpy.org/doc/stable/reference/distutils.html#numpy.distutils.misc_util.Configuration.add_data_files',
                                           'numpy.distutils.misc_util.Configuration.add_extension': 'https://numpy.org/doc/stable/reference/distutils.html#numpy.distutils.misc_util.Configuration.add_extension',
                                           'numpy.distutils.misc_util.Configuration.add_headers': 'https://numpy.org/doc/stable/reference/distutils.html#numpy.distutils.misc_util.Configuration.add_headers',
                                           'numpy.distutils.misc_util.Configuration.add_include_dirs': 'https://numpy.org/doc/stable/reference/distutils.html#numpy.distutils.misc_util.Configuration.add_include_dirs',
                                           'numpy.distutils.misc_util.Configuration.add_installed_library': 'https://numpy.org/doc/stable/reference/distutils.html#numpy.distutils.misc_util.Configuration.add_installed_library',
                                           'numpy.distutils.misc_util.Configuration.add_library': 'https://numpy.org/doc/stable/reference/distutils.html#numpy.distutils.misc_util.Configuration.add_library',
                                           'numpy.distutils.misc_util.Configuration.add_npy_pkg_config': 'https://numpy.org/doc/stable/reference/distutils.html#numpy.distutils.misc_util.Configuration.add_npy_pkg_config',
                                           'numpy.distutils.misc_util.Configuration.add_scripts': 'https://numpy.org/doc/stable/reference/distutils.html#numpy.distutils.misc_util.Configuration.add_scripts',
                                           'numpy.distutils.misc_util.Configuration.add_subpackage': 'https://numpy.org/doc/stable/reference/distutils.html#numpy.distutils.misc_util.Configuration.add_subpackage',
                                           'numpy.distutils.misc_util.Configuration.get_build_temp_dir': 'https://numpy.org/doc/stable/reference/distutils.html#numpy.distutils.misc_util.Configuration.get_build_temp_dir',
                                           'numpy.distutils.misc_util.Configuration.get_config_cmd': 'https://numpy.org/doc/stable/reference/distutils.html#numpy.distutils.misc_util.Configuration.get_config_cmd',
                                           'numpy.distutils.misc_util.Configuration.get_distribution': 'https://numpy.org/doc/stable/reference/distutils.html#numpy.distutils.misc_util.Configuration.get_distribution',
                                           'numpy.distutils.misc_util.Configuration.get_info': 'https://numpy.org/doc/stable/reference/distutils.html#numpy.distutils.misc_util.Configuration.get_info',
                                           'numpy.distutils.misc_util.Configuration.get_subpackage': 'https://numpy.org/doc/stable/reference/distutils.html#numpy.distutils.misc_util.Configuration.get_subpackage',
                                           'numpy.distutils.misc_util.Configuration.get_version': 'https://numpy.org/doc/stable/reference/distutils.html#numpy.distutils.misc_util.Configuration.get_version',
                                           'numpy.distutils.misc_util.Configuration.have_f77c': 'https://numpy.org/doc/stable/reference/distutils.html#numpy.distutils.misc_util.Configuration.have_f77c',
                                           'numpy.distutils.misc_util.Configuration.have_f90c': 'https://numpy.org/doc/stable/reference/distutils.html#numpy.distutils.misc_util.Configuration.have_f90c',
                                           'numpy.distutils.misc_util.Configuration.make_config_py': 'https://numpy.org/doc/stable/reference/distutils.html#numpy.distutils.misc_util.Configuration.make_config_py',
                                           'numpy.distutils.misc_util.Configuration.make_svn_version_py': 'https://numpy.org/doc/stable/reference/distutils.html#numpy.distutils.misc_util.Configuration.make_svn_version_py',
                                           'numpy.distutils.misc_util.Configuration.paths': 'https://numpy.org/doc/stable/reference/distutils.html#numpy.distutils.misc_util.Configuration.paths',
                                           'numpy.distutils.misc_util.Configuration.todict': 'https://numpy.org/doc/stable/reference/distutils.html#numpy.distutils.misc_util.Configuration.todict',
                                           'numpy.distutils.misc_util.all_strings': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.all_strings',
                                           'numpy.distutils.misc_util.allpath': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.allpath',
                                           'numpy.distutils.misc_util.appendpath': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.appendpath',
                                           'numpy.distutils.misc_util.as_list': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.as_list',
                                           'numpy.distutils.misc_util.blue_text': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.blue_text',
                                           'numpy.distutils.misc_util.cyan_text': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.cyan_text',
                                           'numpy.distutils.misc_util.cyg2win32': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.cyg2win32',
                                           'numpy.distutils.misc_util.default_config_dict': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.default_config_dict',
                                           'numpy.distutils.misc_util.dict_append': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.dict_append',
                                           'numpy.distutils.misc_util.dot_join': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.dot_join',
                                           'numpy.distutils.misc_util.exec_mod_from_location': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.exec_mod_from_location',
                                           'numpy.distutils.misc_util.filter_sources': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.filter_sources',
                                           'numpy.distutils.misc_util.generate_config_py': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.generate_config_py',
                                           'numpy.distutils.misc_util.get_build_architecture': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.get_build_architecture',
                                           'numpy.distutils.misc_util.get_cmd': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.get_cmd',
                                           'numpy.distutils.misc_util.get_data_files': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.get_data_files',
                                           'numpy.distutils.misc_util.get_dependencies': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.get_dependencies',
                                           'numpy.distutils.misc_util.get_ext_source_files': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.get_ext_source_files',
                                           'numpy.distutils.misc_util.get_frame': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.get_frame',
                                           'numpy.distutils.misc_util.get_info': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.get_info',
                                           'numpy.distutils.misc_util.get_language': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.get_language',
                                           'numpy.distutils.misc_util.get_lib_source_files': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.get_lib_source_files',
                                           'numpy.distutils.misc_util.get_mathlibs': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.get_mathlibs',
                                           'numpy.distutils.misc_util.get_num_build_jobs': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.get_num_build_jobs',
                                           'numpy.distutils.misc_util.get_numpy_include_dirs': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.get_numpy_include_dirs',
                                           'numpy.distutils.misc_util.get_pkg_info': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.get_pkg_info',
                                           'numpy.distutils.misc_util.get_script_files': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.get_script_files',
                                           'numpy.distutils.misc_util.gpaths': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.gpaths',
                                           'numpy.distutils.misc_util.green_text': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.green_text',
                                           'numpy.distutils.misc_util.has_cxx_sources': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.has_cxx_sources',
                                           'numpy.distutils.misc_util.has_f_sources': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.has_f_sources',
                                           'numpy.distutils.misc_util.is_local_src_dir': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.is_local_src_dir',
                                           'numpy.distutils.misc_util.is_sequence': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.is_sequence',
                                           'numpy.distutils.misc_util.is_string': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.is_string',
                                           'numpy.distutils.misc_util.mingw32': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.mingw32',
                                           'numpy.distutils.misc_util.minrelpath': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.minrelpath',
                                           'numpy.distutils.misc_util.njoin': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.njoin',
                                           'numpy.distutils.misc_util.red_text': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.red_text',
                                           'numpy.distutils.misc_util.sanitize_cxx_flags': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.sanitize_cxx_flags',
                                           'numpy.distutils.misc_util.terminal_has_colors': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.terminal_has_colors',
                                           'numpy.distutils.misc_util.yellow_text': 'https://numpy.org/doc/stable/reference/distutils/misc_util.html#numpy.distutils.misc_util.yellow_text'},
            'numpy.distutils.system_info': { 'numpy.distutils.system_info.get_info': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.system_info.get_info.html#numpy.distutils.system_info.get_info',
                                             'numpy.distutils.system_info.get_standard_file': 'https://numpy.org/doc/stable/reference/generated/numpy.distutils.system_info.get_standard_file.html#numpy.distutils.system_info.get_standard_file'},
            'numpy.doc': {'numpy.doc.constants': 'https://numpy.org/doc/stable/reference/constants.html#module-numpy.doc.constants'},
            'numpy.emath': { 'numpy.emath.arccos': 'https://numpy.org/doc/stable/reference/generated/numpy.emath.arccos.html#numpy.emath.arccos',
                             'numpy.emath.arcsin': 'https://numpy.org/doc/stable/reference/generated/numpy.emath.arcsin.html#numpy.emath.arcsin',
                             'numpy.emath.arctanh': 'https://numpy.org/doc/stable/reference/generated/numpy.emath.arctanh.html#numpy.emath.arctanh',
                             'numpy.emath.log': 'https://numpy.org/doc/stable/reference/generated/numpy.emath.log.html#numpy.emath.log',
                             'numpy.emath.log10': 'https://numpy.org/doc/stable/reference/generated/numpy.emath.log10.html#numpy.emath.log10',
                             'numpy.emath.log2': 'https://numpy.org/doc/stable/reference/generated/numpy.emath.log2.html#numpy.emath.log2',
                             'numpy.emath.logn': 'https://numpy.org/doc/stable/reference/generated/numpy.emath.logn.html#numpy.emath.logn',
                             'numpy.emath.power': 'https://numpy.org/doc/stable/reference/generated/numpy.emath.power.html#numpy.emath.power',
                             'numpy.emath.sqrt': 'https://numpy.org/doc/stable/reference/generated/numpy.emath.sqrt.html#numpy.emath.sqrt'},
            'numpy.f2py': { 'numpy.f2py.compile': 'https://numpy.org/doc/stable/f2py/usage.html#numpy.f2py.compile',
                            'numpy.f2py.get_include': 'https://numpy.org/doc/stable/f2py/usage.html#numpy.f2py.get_include',
                            'numpy.f2py.run_main': 'https://numpy.org/doc/stable/f2py/usage.html#numpy.f2py.run_main'},
            'numpy.fft': { 'numpy.fft.fft': 'https://numpy.org/doc/stable/reference/generated/numpy.fft.fft.html#numpy.fft.fft',
                           'numpy.fft.fft2': 'https://numpy.org/doc/stable/reference/generated/numpy.fft.fft2.html#numpy.fft.fft2',
                           'numpy.fft.fftfreq': 'https://numpy.org/doc/stable/reference/generated/numpy.fft.fftfreq.html#numpy.fft.fftfreq',
                           'numpy.fft.fftn': 'https://numpy.org/doc/stable/reference/generated/numpy.fft.fftn.html#numpy.fft.fftn',
                           'numpy.fft.fftshift': 'https://numpy.org/doc/stable/reference/generated/numpy.fft.fftshift.html#numpy.fft.fftshift',
                           'numpy.fft.hfft': 'https://numpy.org/doc/stable/reference/generated/numpy.fft.hfft.html#numpy.fft.hfft',
                           'numpy.fft.ifft': 'https://numpy.org/doc/stable/reference/generated/numpy.fft.ifft.html#numpy.fft.ifft',
                           'numpy.fft.ifft2': 'https://numpy.org/doc/stable/reference/generated/numpy.fft.ifft2.html#numpy.fft.ifft2',
                           'numpy.fft.ifftn': 'https://numpy.org/doc/stable/reference/generated/numpy.fft.ifftn.html#numpy.fft.ifftn',
                           'numpy.fft.ifftshift': 'https://numpy.org/doc/stable/reference/generated/numpy.fft.ifftshift.html#numpy.fft.ifftshift',
                           'numpy.fft.ihfft': 'https://numpy.org/doc/stable/reference/generated/numpy.fft.ihfft.html#numpy.fft.ihfft',
                           'numpy.fft.irfft': 'https://numpy.org/doc/stable/reference/generated/numpy.fft.irfft.html#numpy.fft.irfft',
                           'numpy.fft.irfft2': 'https://numpy.org/doc/stable/reference/generated/numpy.fft.irfft2.html#numpy.fft.irfft2',
                           'numpy.fft.irfftn': 'https://numpy.org/doc/stable/reference/generated/numpy.fft.irfftn.html#numpy.fft.irfftn',
                           'numpy.fft.rfft': 'https://numpy.org/doc/stable/reference/generated/numpy.fft.rfft.html#numpy.fft.rfft',
                           'numpy.fft.rfft2': 'https://numpy.org/doc/stable/reference/generated/numpy.fft.rfft2.html#numpy.fft.rfft2',
                           'numpy.fft.rfftfreq': 'https://numpy.org/doc/stable/reference/generated/numpy.fft.rfftfreq.html#numpy.fft.rfftfreq',
                           'numpy.fft.rfftn': 'https://numpy.org/doc/stable/reference/generated/numpy.fft.rfftn.html#numpy.fft.rfftn'},
            'numpy.lib': { 'numpy.lib.Arrayterator': 'https://numpy.org/doc/stable/reference/generated/numpy.lib.Arrayterator.html#numpy.lib.Arrayterator',
                           'numpy.lib.NumpyVersion': 'https://numpy.org/doc/stable/reference/generated/numpy.lib.NumpyVersion.html#numpy.lib.NumpyVersion',
                           'numpy.lib.arraysetops': 'https://numpy.org/doc/stable/reference/generated/numpy.lib.arraysetops.html#module-numpy.lib.arraysetops',
                           'numpy.lib.format': 'https://numpy.org/doc/stable/reference/generated/numpy.lib.format.html#module-numpy.lib.format',
                           'numpy.lib.recfunctions': 'https://numpy.org/doc/stable/user/basics.rec.html#module-numpy.lib.recfunctions'},
            'numpy.lib._version': { 'numpy.lib._version.NumpyVersion': 'https://numpy.org/doc/stable/reference/generated/numpy.lib.NumpyVersion.html#numpy.lib.NumpyVersion'},
            'numpy.lib.arrayterator': { 'numpy.lib.arrayterator.Arrayterator': 'https://numpy.org/doc/stable/reference/generated/numpy.lib.Arrayterator.html#numpy.lib.Arrayterator'},
            'numpy.lib.format': { 'numpy.lib.format.descr_to_dtype': 'https://numpy.org/doc/stable/reference/generated/numpy.lib.format.descr_to_dtype.html#numpy.lib.format.descr_to_dtype',
                                  'numpy.lib.format.dtype_to_descr': 'https://numpy.org/doc/stable/reference/generated/numpy.lib.format.dtype_to_descr.html#numpy.lib.format.dtype_to_descr',
                                  'numpy.lib.format.header_data_from_array_1_0': 'https://numpy.org/doc/stable/reference/generated/numpy.lib.format.header_data_from_array_1_0.html#numpy.lib.format.header_data_from_array_1_0',
                                  'numpy.lib.format.magic': 'https://numpy.org/doc/stable/reference/generated/numpy.lib.format.magic.html#numpy.lib.format.magic',
                                  'numpy.lib.format.open_memmap': 'https://numpy.org/doc/stable/reference/generated/numpy.lib.format.open_memmap.html#numpy.lib.format.open_memmap',
                                  'numpy.lib.format.read_array': 'https://numpy.org/doc/stable/reference/generated/numpy.lib.format.read_array.html#numpy.lib.format.read_array',
                                  'numpy.lib.format.read_array_header_1_0': 'https://numpy.org/doc/stable/reference/generated/numpy.lib.format.read_array_header_1_0.html#numpy.lib.format.read_array_header_1_0',
                                  'numpy.lib.format.read_array_header_2_0': 'https://numpy.org/doc/stable/reference/generated/numpy.lib.format.read_array_header_2_0.html#numpy.lib.format.read_array_header_2_0',
                                  'numpy.lib.format.read_magic': 'https://numpy.org/doc/stable/reference/generated/numpy.lib.format.read_magic.html#numpy.lib.format.read_magic',
                                  'numpy.lib.format.write_array': 'https://numpy.org/doc/stable/reference/generated/numpy.lib.format.write_array.html#numpy.lib.format.write_array',
                                  'numpy.lib.format.write_array_header_1_0': 'https://numpy.org/doc/stable/reference/generated/numpy.lib.format.write_array_header_1_0.html#numpy.lib.format.write_array_header_1_0',
                                  'numpy.lib.format.write_array_header_2_0': 'https://numpy.org/doc/stable/reference/generated/numpy.lib.format.write_array_header_2_0.html#numpy.lib.format.write_array_header_2_0'},
            'numpy.lib.mixins': { 'numpy.lib.mixins.NDArrayOperatorsMixin': 'https://numpy.org/doc/stable/reference/generated/numpy.lib.mixins.NDArrayOperatorsMixin.html#numpy.lib.mixins.NDArrayOperatorsMixin'},
            'numpy.lib.recfunctions': { 'numpy.lib.recfunctions.append_fields': 'https://numpy.org/doc/stable/user/basics.rec.html#numpy.lib.recfunctions.append_fields',
                                        'numpy.lib.recfunctions.apply_along_fields': 'https://numpy.org/doc/stable/user/basics.rec.html#numpy.lib.recfunctions.apply_along_fields',
                                        'numpy.lib.recfunctions.assign_fields_by_name': 'https://numpy.org/doc/stable/user/basics.rec.html#numpy.lib.recfunctions.assign_fields_by_name',
                                        'numpy.lib.recfunctions.drop_fields': 'https://numpy.org/doc/stable/user/basics.rec.html#numpy.lib.recfunctions.drop_fields',
                                        'numpy.lib.recfunctions.find_duplicates': 'https://numpy.org/doc/stable/user/basics.rec.html#numpy.lib.recfunctions.find_duplicates',
                                        'numpy.lib.recfunctions.flatten_descr': 'https://numpy.org/doc/stable/user/basics.rec.html#numpy.lib.recfunctions.flatten_descr',
                                        'numpy.lib.recfunctions.get_fieldstructure': 'https://numpy.org/doc/stable/user/basics.rec.html#numpy.lib.recfunctions.get_fieldstructure',
                                        'numpy.lib.recfunctions.get_names': 'https://numpy.org/doc/stable/user/basics.rec.html#numpy.lib.recfunctions.get_names',
                                        'numpy.lib.recfunctions.get_names_flat': 'https://numpy.org/doc/stable/user/basics.rec.html#numpy.lib.recfunctions.get_names_flat',
                                        'numpy.lib.recfunctions.join_by': 'https://numpy.org/doc/stable/user/basics.rec.html#numpy.lib.recfunctions.join_by',
                                        'numpy.lib.recfunctions.merge_arrays': 'https://numpy.org/doc/stable/user/basics.rec.html#numpy.lib.recfunctions.merge_arrays',
                                        'numpy.lib.recfunctions.rec_append_fields': 'https://numpy.org/doc/stable/user/basics.rec.html#numpy.lib.recfunctions.rec_append_fields',
                                        'numpy.lib.recfunctions.rec_drop_fields': 'https://numpy.org/doc/stable/user/basics.rec.html#numpy.lib.recfunctions.rec_drop_fields',
                                        'numpy.lib.recfunctions.rec_join': 'https://numpy.org/doc/stable/user/basics.rec.html#numpy.lib.recfunctions.rec_join',
                                        'numpy.lib.recfunctions.recursive_fill_fields': 'https://numpy.org/doc/stable/user/basics.rec.html#numpy.lib.recfunctions.recursive_fill_fields',
                                        'numpy.lib.recfunctions.rename_fields': 'https://numpy.org/doc/stable/user/basics.rec.html#numpy.lib.recfunctions.rename_fields',
                                        'numpy.lib.recfunctions.repack_fields': 'https://numpy.org/doc/stable/user/basics.rec.html#numpy.lib.recfunctions.repack_fields',
                                        'numpy.lib.recfunctions.require_fields': 'https://numpy.org/doc/stable/user/basics.rec.html#numpy.lib.recfunctions.require_fields',
                                        'numpy.lib.recfunctions.stack_arrays': 'https://numpy.org/doc/stable/user/basics.rec.html#numpy.lib.recfunctions.stack_arrays',
                                        'numpy.lib.recfunctions.structured_to_unstructured': 'https://numpy.org/doc/stable/user/basics.rec.html#numpy.lib.recfunctions.structured_to_unstructured',
                                        'numpy.lib.recfunctions.unstructured_to_structured': 'https://numpy.org/doc/stable/user/basics.rec.html#numpy.lib.recfunctions.unstructured_to_structured'},
            'numpy.lib.stride_tricks': { 'numpy.lib.stride_tricks.as_strided': 'https://numpy.org/doc/stable/reference/generated/numpy.lib.stride_tricks.as_strided.html#numpy.lib.stride_tricks.as_strided',
                                         'numpy.lib.stride_tricks.sliding_window_view': 'https://numpy.org/doc/stable/reference/generated/numpy.lib.stride_tricks.sliding_window_view.html#numpy.lib.stride_tricks.sliding_window_view'},
            'numpy.lib.user_array': { 'numpy.lib.user_array.container': 'https://numpy.org/doc/stable/reference/generated/numpy.lib.user_array.container.html#numpy.lib.user_array.container',
                                      'numpy.lib.user_array.container.astype': 'https://numpy.org/doc/stable/reference/generated/numpy.lib.user_array.container.astype.html#numpy.lib.user_array.container.astype',
                                      'numpy.lib.user_array.container.byteswap': 'https://numpy.org/doc/stable/reference/generated/numpy.lib.user_array.container.byteswap.html#numpy.lib.user_array.container.byteswap',
                                      'numpy.lib.user_array.container.copy': 'https://numpy.org/doc/stable/reference/generated/numpy.lib.user_array.container.copy.html#numpy.lib.user_array.container.copy',
                                      'numpy.lib.user_array.container.tobytes': 'https://numpy.org/doc/stable/reference/generated/numpy.lib.user_array.container.tobytes.html#numpy.lib.user_array.container.tobytes',
                                      'numpy.lib.user_array.container.tostring': 'https://numpy.org/doc/stable/reference/generated/numpy.lib.user_array.container.tostring.html#numpy.lib.user_array.container.tostring'},
            'numpy.linalg': { 'numpy.linalg.cholesky': 'https://numpy.org/doc/stable/reference/generated/numpy.linalg.cholesky.html#numpy.linalg.cholesky',
                              'numpy.linalg.cond': 'https://numpy.org/doc/stable/reference/generated/numpy.linalg.cond.html#numpy.linalg.cond',
                              'numpy.linalg.det': 'https://numpy.org/doc/stable/reference/generated/numpy.linalg.det.html#numpy.linalg.det',
                              'numpy.linalg.eig': 'https://numpy.org/doc/stable/reference/generated/numpy.linalg.eig.html#numpy.linalg.eig',
                              'numpy.linalg.eigh': 'https://numpy.org/doc/stable/reference/generated/numpy.linalg.eigh.html#numpy.linalg.eigh',
                              'numpy.linalg.eigvals': 'https://numpy.org/doc/stable/reference/generated/numpy.linalg.eigvals.html#numpy.linalg.eigvals',
                              'numpy.linalg.eigvalsh': 'https://numpy.org/doc/stable/reference/generated/numpy.linalg.eigvalsh.html#numpy.linalg.eigvalsh',
                              'numpy.linalg.inv': 'https://numpy.org/doc/stable/reference/generated/numpy.linalg.inv.html#numpy.linalg.inv',
                              'numpy.linalg.lstsq': 'https://numpy.org/doc/stable/reference/generated/numpy.linalg.lstsq.html#numpy.linalg.lstsq',
                              'numpy.linalg.matrix_power': 'https://numpy.org/doc/stable/reference/generated/numpy.linalg.matrix_power.html#numpy.linalg.matrix_power',
                              'numpy.linalg.matrix_rank': 'https://numpy.org/doc/stable/reference/generated/numpy.linalg.matrix_rank.html#numpy.linalg.matrix_rank',
                              'numpy.linalg.multi_dot': 'https://numpy.org/doc/stable/reference/generated/numpy.linalg.multi_dot.html#numpy.linalg.multi_dot',
                              'numpy.linalg.norm': 'https://numpy.org/doc/stable/reference/generated/numpy.linalg.norm.html#numpy.linalg.norm',
                              'numpy.linalg.pinv': 'https://numpy.org/doc/stable/reference/generated/numpy.linalg.pinv.html#numpy.linalg.pinv',
                              'numpy.linalg.qr': 'https://numpy.org/doc/stable/reference/generated/numpy.linalg.qr.html#numpy.linalg.qr',
                              'numpy.linalg.slogdet': 'https://numpy.org/doc/stable/reference/generated/numpy.linalg.slogdet.html#numpy.linalg.slogdet',
                              'numpy.linalg.solve': 'https://numpy.org/doc/stable/reference/generated/numpy.linalg.solve.html#numpy.linalg.solve',
                              'numpy.linalg.svd': 'https://numpy.org/doc/stable/reference/generated/numpy.linalg.svd.html#numpy.linalg.svd',
                              'numpy.linalg.tensorinv': 'https://numpy.org/doc/stable/reference/generated/numpy.linalg.tensorinv.html#numpy.linalg.tensorinv',
                              'numpy.linalg.tensorsolve': 'https://numpy.org/doc/stable/reference/generated/numpy.linalg.tensorsolve.html#numpy.linalg.tensorsolve'},
            'numpy.ma': { 'numpy.ma.MaskType.all': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.all.html#numpy.ma.MaskType.all',
                          'numpy.ma.MaskType.any': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.any.html#numpy.ma.MaskType.any',
                          'numpy.ma.MaskType.argmax': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.argmax.html#numpy.ma.MaskType.argmax',
                          'numpy.ma.MaskType.argmin': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.argmin.html#numpy.ma.MaskType.argmin',
                          'numpy.ma.MaskType.argsort': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.argsort.html#numpy.ma.MaskType.argsort',
                          'numpy.ma.MaskType.astype': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.astype.html#numpy.ma.MaskType.astype',
                          'numpy.ma.MaskType.byteswap': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.byteswap.html#numpy.ma.MaskType.byteswap',
                          'numpy.ma.MaskType.choose': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.choose.html#numpy.ma.MaskType.choose',
                          'numpy.ma.MaskType.clip': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.clip.html#numpy.ma.MaskType.clip',
                          'numpy.ma.MaskType.compress': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.compress.html#numpy.ma.MaskType.compress',
                          'numpy.ma.MaskType.conj': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.conj.html#numpy.ma.MaskType.conj',
                          'numpy.ma.MaskType.conjugate': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.conjugate.html#numpy.ma.MaskType.conjugate',
                          'numpy.ma.MaskType.copy': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.copy.html#numpy.ma.MaskType.copy',
                          'numpy.ma.MaskType.cumprod': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.cumprod.html#numpy.ma.MaskType.cumprod',
                          'numpy.ma.MaskType.cumsum': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.cumsum.html#numpy.ma.MaskType.cumsum',
                          'numpy.ma.MaskType.diagonal': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.diagonal.html#numpy.ma.MaskType.diagonal',
                          'numpy.ma.MaskType.dump': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.dump.html#numpy.ma.MaskType.dump',
                          'numpy.ma.MaskType.dumps': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.dumps.html#numpy.ma.MaskType.dumps',
                          'numpy.ma.MaskType.fill': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.fill.html#numpy.ma.MaskType.fill',
                          'numpy.ma.MaskType.flatten': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.flatten.html#numpy.ma.MaskType.flatten',
                          'numpy.ma.MaskType.getfield': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.getfield.html#numpy.ma.MaskType.getfield',
                          'numpy.ma.MaskType.item': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.item.html#numpy.ma.MaskType.item',
                          'numpy.ma.MaskType.itemset': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.itemset.html#numpy.ma.MaskType.itemset',
                          'numpy.ma.MaskType.max': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.max.html#numpy.ma.MaskType.max',
                          'numpy.ma.MaskType.mean': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.mean.html#numpy.ma.MaskType.mean',
                          'numpy.ma.MaskType.min': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.min.html#numpy.ma.MaskType.min',
                          'numpy.ma.MaskType.newbyteorder': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.newbyteorder.html#numpy.ma.MaskType.newbyteorder',
                          'numpy.ma.MaskType.nonzero': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.nonzero.html#numpy.ma.MaskType.nonzero',
                          'numpy.ma.MaskType.prod': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.prod.html#numpy.ma.MaskType.prod',
                          'numpy.ma.MaskType.ptp': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.ptp.html#numpy.ma.MaskType.ptp',
                          'numpy.ma.MaskType.put': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.put.html#numpy.ma.MaskType.put',
                          'numpy.ma.MaskType.ravel': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.ravel.html#numpy.ma.MaskType.ravel',
                          'numpy.ma.MaskType.repeat': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.repeat.html#numpy.ma.MaskType.repeat',
                          'numpy.ma.MaskType.reshape': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.reshape.html#numpy.ma.MaskType.reshape',
                          'numpy.ma.MaskType.resize': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.resize.html#numpy.ma.MaskType.resize',
                          'numpy.ma.MaskType.round': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.round.html#numpy.ma.MaskType.round',
                          'numpy.ma.MaskType.searchsorted': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.searchsorted.html#numpy.ma.MaskType.searchsorted',
                          'numpy.ma.MaskType.setfield': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.setfield.html#numpy.ma.MaskType.setfield',
                          'numpy.ma.MaskType.setflags': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.setflags.html#numpy.ma.MaskType.setflags',
                          'numpy.ma.MaskType.sort': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.sort.html#numpy.ma.MaskType.sort',
                          'numpy.ma.MaskType.squeeze': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.squeeze.html#numpy.ma.MaskType.squeeze',
                          'numpy.ma.MaskType.std': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.std.html#numpy.ma.MaskType.std',
                          'numpy.ma.MaskType.sum': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.sum.html#numpy.ma.MaskType.sum',
                          'numpy.ma.MaskType.swapaxes': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.swapaxes.html#numpy.ma.MaskType.swapaxes',
                          'numpy.ma.MaskType.take': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.take.html#numpy.ma.MaskType.take',
                          'numpy.ma.MaskType.tobytes': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.tobytes.html#numpy.ma.MaskType.tobytes',
                          'numpy.ma.MaskType.tofile': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.tofile.html#numpy.ma.MaskType.tofile',
                          'numpy.ma.MaskType.tolist': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.tolist.html#numpy.ma.MaskType.tolist',
                          'numpy.ma.MaskType.tostring': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.tostring.html#numpy.ma.MaskType.tostring',
                          'numpy.ma.MaskType.trace': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.trace.html#numpy.ma.MaskType.trace',
                          'numpy.ma.MaskType.transpose': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.transpose.html#numpy.ma.MaskType.transpose',
                          'numpy.ma.MaskType.var': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.var.html#numpy.ma.MaskType.var',
                          'numpy.ma.MaskType.view': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskType.view.html#numpy.ma.MaskType.view',
                          'numpy.ma.MaskedArray': 'https://numpy.org/doc/stable/reference/maskedarray.baseclass.html#numpy.ma.MaskedArray',
                          'numpy.ma.MaskedArray.__abs__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__abs__.html#numpy.ma.MaskedArray.__abs__',
                          'numpy.ma.MaskedArray.__add__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__add__.html#numpy.ma.MaskedArray.__add__',
                          'numpy.ma.MaskedArray.__and__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__and__.html#numpy.ma.MaskedArray.__and__',
                          'numpy.ma.MaskedArray.__array__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__array__.html#numpy.ma.MaskedArray.__array__',
                          'numpy.ma.MaskedArray.__array_wrap__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__array_wrap__.html#numpy.ma.MaskedArray.__array_wrap__',
                          'numpy.ma.MaskedArray.__bool__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__bool__.html#numpy.ma.MaskedArray.__bool__',
                          'numpy.ma.MaskedArray.__contains__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__contains__.html#numpy.ma.MaskedArray.__contains__',
                          'numpy.ma.MaskedArray.__copy__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__copy__.html#numpy.ma.MaskedArray.__copy__',
                          'numpy.ma.MaskedArray.__deepcopy__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__deepcopy__.html#numpy.ma.MaskedArray.__deepcopy__',
                          'numpy.ma.MaskedArray.__delitem__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__delitem__.html#numpy.ma.MaskedArray.__delitem__',
                          'numpy.ma.MaskedArray.__div__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__div__.html#numpy.ma.MaskedArray.__div__',
                          'numpy.ma.MaskedArray.__divmod__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__divmod__.html#numpy.ma.MaskedArray.__divmod__',
                          'numpy.ma.MaskedArray.__eq__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__eq__.html#numpy.ma.MaskedArray.__eq__',
                          'numpy.ma.MaskedArray.__float__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__float__.html#numpy.ma.MaskedArray.__float__',
                          'numpy.ma.MaskedArray.__floordiv__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__floordiv__.html#numpy.ma.MaskedArray.__floordiv__',
                          'numpy.ma.MaskedArray.__ge__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__ge__.html#numpy.ma.MaskedArray.__ge__',
                          'numpy.ma.MaskedArray.__getitem__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__getitem__.html#numpy.ma.MaskedArray.__getitem__',
                          'numpy.ma.MaskedArray.__getstate__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__getstate__.html#numpy.ma.MaskedArray.__getstate__',
                          'numpy.ma.MaskedArray.__gt__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__gt__.html#numpy.ma.MaskedArray.__gt__',
                          'numpy.ma.MaskedArray.__iadd__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__iadd__.html#numpy.ma.MaskedArray.__iadd__',
                          'numpy.ma.MaskedArray.__iand__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__iand__.html#numpy.ma.MaskedArray.__iand__',
                          'numpy.ma.MaskedArray.__idiv__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__idiv__.html#numpy.ma.MaskedArray.__idiv__',
                          'numpy.ma.MaskedArray.__ifloordiv__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__ifloordiv__.html#numpy.ma.MaskedArray.__ifloordiv__',
                          'numpy.ma.MaskedArray.__ilshift__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__ilshift__.html#numpy.ma.MaskedArray.__ilshift__',
                          'numpy.ma.MaskedArray.__imod__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__imod__.html#numpy.ma.MaskedArray.__imod__',
                          'numpy.ma.MaskedArray.__imul__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__imul__.html#numpy.ma.MaskedArray.__imul__',
                          'numpy.ma.MaskedArray.__int__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__int__.html#numpy.ma.MaskedArray.__int__',
                          'numpy.ma.MaskedArray.__ior__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__ior__.html#numpy.ma.MaskedArray.__ior__',
                          'numpy.ma.MaskedArray.__ipow__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__ipow__.html#numpy.ma.MaskedArray.__ipow__',
                          'numpy.ma.MaskedArray.__irshift__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__irshift__.html#numpy.ma.MaskedArray.__irshift__',
                          'numpy.ma.MaskedArray.__isub__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__isub__.html#numpy.ma.MaskedArray.__isub__',
                          'numpy.ma.MaskedArray.__itruediv__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__itruediv__.html#numpy.ma.MaskedArray.__itruediv__',
                          'numpy.ma.MaskedArray.__ixor__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__ixor__.html#numpy.ma.MaskedArray.__ixor__',
                          'numpy.ma.MaskedArray.__le__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__le__.html#numpy.ma.MaskedArray.__le__',
                          'numpy.ma.MaskedArray.__len__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__len__.html#numpy.ma.MaskedArray.__len__',
                          'numpy.ma.MaskedArray.__lshift__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__lshift__.html#numpy.ma.MaskedArray.__lshift__',
                          'numpy.ma.MaskedArray.__lt__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__lt__.html#numpy.ma.MaskedArray.__lt__',
                          'numpy.ma.MaskedArray.__mod__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__mod__.html#numpy.ma.MaskedArray.__mod__',
                          'numpy.ma.MaskedArray.__mul__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__mul__.html#numpy.ma.MaskedArray.__mul__',
                          'numpy.ma.MaskedArray.__ne__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__ne__.html#numpy.ma.MaskedArray.__ne__',
                          'numpy.ma.MaskedArray.__new__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__new__.html#numpy.ma.MaskedArray.__new__',
                          'numpy.ma.MaskedArray.__or__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__or__.html#numpy.ma.MaskedArray.__or__',
                          'numpy.ma.MaskedArray.__pow__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__pow__.html#numpy.ma.MaskedArray.__pow__',
                          'numpy.ma.MaskedArray.__radd__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__radd__.html#numpy.ma.MaskedArray.__radd__',
                          'numpy.ma.MaskedArray.__rand__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__rand__.html#numpy.ma.MaskedArray.__rand__',
                          'numpy.ma.MaskedArray.__rdivmod__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__rdivmod__.html#numpy.ma.MaskedArray.__rdivmod__',
                          'numpy.ma.MaskedArray.__reduce__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__reduce__.html#numpy.ma.MaskedArray.__reduce__',
                          'numpy.ma.MaskedArray.__repr__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__repr__.html#numpy.ma.MaskedArray.__repr__',
                          'numpy.ma.MaskedArray.__rfloordiv__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__rfloordiv__.html#numpy.ma.MaskedArray.__rfloordiv__',
                          'numpy.ma.MaskedArray.__rlshift__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__rlshift__.html#numpy.ma.MaskedArray.__rlshift__',
                          'numpy.ma.MaskedArray.__rmod__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__rmod__.html#numpy.ma.MaskedArray.__rmod__',
                          'numpy.ma.MaskedArray.__rmul__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__rmul__.html#numpy.ma.MaskedArray.__rmul__',
                          'numpy.ma.MaskedArray.__ror__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__ror__.html#numpy.ma.MaskedArray.__ror__',
                          'numpy.ma.MaskedArray.__rpow__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__rpow__.html#numpy.ma.MaskedArray.__rpow__',
                          'numpy.ma.MaskedArray.__rrshift__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__rrshift__.html#numpy.ma.MaskedArray.__rrshift__',
                          'numpy.ma.MaskedArray.__rshift__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__rshift__.html#numpy.ma.MaskedArray.__rshift__',
                          'numpy.ma.MaskedArray.__rsub__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__rsub__.html#numpy.ma.MaskedArray.__rsub__',
                          'numpy.ma.MaskedArray.__rtruediv__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__rtruediv__.html#numpy.ma.MaskedArray.__rtruediv__',
                          'numpy.ma.MaskedArray.__rxor__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__rxor__.html#numpy.ma.MaskedArray.__rxor__',
                          'numpy.ma.MaskedArray.__setitem__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__setitem__.html#numpy.ma.MaskedArray.__setitem__',
                          'numpy.ma.MaskedArray.__setmask__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__setmask__.html#numpy.ma.MaskedArray.__setmask__',
                          'numpy.ma.MaskedArray.__setstate__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__setstate__.html#numpy.ma.MaskedArray.__setstate__',
                          'numpy.ma.MaskedArray.__str__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__str__.html#numpy.ma.MaskedArray.__str__',
                          'numpy.ma.MaskedArray.__sub__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__sub__.html#numpy.ma.MaskedArray.__sub__',
                          'numpy.ma.MaskedArray.__truediv__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__truediv__.html#numpy.ma.MaskedArray.__truediv__',
                          'numpy.ma.MaskedArray.__xor__': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.__xor__.html#numpy.ma.MaskedArray.__xor__',
                          'numpy.ma.MaskedArray.all': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.all.html#numpy.ma.MaskedArray.all',
                          'numpy.ma.MaskedArray.anom': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.anom.html#numpy.ma.MaskedArray.anom',
                          'numpy.ma.MaskedArray.any': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.any.html#numpy.ma.MaskedArray.any',
                          'numpy.ma.MaskedArray.argmax': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.argmax.html#numpy.ma.MaskedArray.argmax',
                          'numpy.ma.MaskedArray.argmin': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.argmin.html#numpy.ma.MaskedArray.argmin',
                          'numpy.ma.MaskedArray.argsort': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.argsort.html#numpy.ma.MaskedArray.argsort',
                          'numpy.ma.MaskedArray.astype': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.astype.html#numpy.ma.MaskedArray.astype',
                          'numpy.ma.MaskedArray.byteswap': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.byteswap.html#numpy.ma.MaskedArray.byteswap',
                          'numpy.ma.MaskedArray.choose': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.choose.html#numpy.ma.MaskedArray.choose',
                          'numpy.ma.MaskedArray.clip': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.clip.html#numpy.ma.MaskedArray.clip',
                          'numpy.ma.MaskedArray.compress': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.compress.html#numpy.ma.MaskedArray.compress',
                          'numpy.ma.MaskedArray.compressed': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.compressed.html#numpy.ma.MaskedArray.compressed',
                          'numpy.ma.MaskedArray.conj': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.conj.html#numpy.ma.MaskedArray.conj',
                          'numpy.ma.MaskedArray.conjugate': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.conjugate.html#numpy.ma.MaskedArray.conjugate',
                          'numpy.ma.MaskedArray.copy': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.copy.html#numpy.ma.MaskedArray.copy',
                          'numpy.ma.MaskedArray.count': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.count.html#numpy.ma.MaskedArray.count',
                          'numpy.ma.MaskedArray.cumprod': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.cumprod.html#numpy.ma.MaskedArray.cumprod',
                          'numpy.ma.MaskedArray.cumsum': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.cumsum.html#numpy.ma.MaskedArray.cumsum',
                          'numpy.ma.MaskedArray.diagonal': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.diagonal.html#numpy.ma.MaskedArray.diagonal',
                          'numpy.ma.MaskedArray.dump': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.dump.html#numpy.ma.MaskedArray.dump',
                          'numpy.ma.MaskedArray.dumps': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.dumps.html#numpy.ma.MaskedArray.dumps',
                          'numpy.ma.MaskedArray.fill': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.fill.html#numpy.ma.MaskedArray.fill',
                          'numpy.ma.MaskedArray.filled': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.filled.html#numpy.ma.MaskedArray.filled',
                          'numpy.ma.MaskedArray.flatten': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.flatten.html#numpy.ma.MaskedArray.flatten',
                          'numpy.ma.MaskedArray.get_fill_value': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.get_fill_value.html#numpy.ma.MaskedArray.get_fill_value',
                          'numpy.ma.MaskedArray.harden_mask': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.harden_mask.html#numpy.ma.MaskedArray.harden_mask',
                          'numpy.ma.MaskedArray.ids': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.ids.html#numpy.ma.MaskedArray.ids',
                          'numpy.ma.MaskedArray.iscontiguous': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.iscontiguous.html#numpy.ma.MaskedArray.iscontiguous',
                          'numpy.ma.MaskedArray.item': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.item.html#numpy.ma.MaskedArray.item',
                          'numpy.ma.MaskedArray.max': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.max.html#numpy.ma.MaskedArray.max',
                          'numpy.ma.MaskedArray.mean': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.mean.html#numpy.ma.MaskedArray.mean',
                          'numpy.ma.MaskedArray.min': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.min.html#numpy.ma.MaskedArray.min',
                          'numpy.ma.MaskedArray.nonzero': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.nonzero.html#numpy.ma.MaskedArray.nonzero',
                          'numpy.ma.MaskedArray.prod': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.prod.html#numpy.ma.MaskedArray.prod',
                          'numpy.ma.MaskedArray.product': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.product.html#numpy.ma.MaskedArray.product',
                          'numpy.ma.MaskedArray.ptp': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.ptp.html#numpy.ma.MaskedArray.ptp',
                          'numpy.ma.MaskedArray.put': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.put.html#numpy.ma.MaskedArray.put',
                          'numpy.ma.MaskedArray.ravel': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.ravel.html#numpy.ma.MaskedArray.ravel',
                          'numpy.ma.MaskedArray.repeat': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.repeat.html#numpy.ma.MaskedArray.repeat',
                          'numpy.ma.MaskedArray.reshape': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.reshape.html#numpy.ma.MaskedArray.reshape',
                          'numpy.ma.MaskedArray.resize': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.resize.html#numpy.ma.MaskedArray.resize',
                          'numpy.ma.MaskedArray.round': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.round.html#numpy.ma.MaskedArray.round',
                          'numpy.ma.MaskedArray.searchsorted': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.searchsorted.html#numpy.ma.MaskedArray.searchsorted',
                          'numpy.ma.MaskedArray.set_fill_value': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.set_fill_value.html#numpy.ma.MaskedArray.set_fill_value',
                          'numpy.ma.MaskedArray.shrink_mask': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.shrink_mask.html#numpy.ma.MaskedArray.shrink_mask',
                          'numpy.ma.MaskedArray.soften_mask': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.soften_mask.html#numpy.ma.MaskedArray.soften_mask',
                          'numpy.ma.MaskedArray.sort': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.sort.html#numpy.ma.MaskedArray.sort',
                          'numpy.ma.MaskedArray.squeeze': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.squeeze.html#numpy.ma.MaskedArray.squeeze',
                          'numpy.ma.MaskedArray.std': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.std.html#numpy.ma.MaskedArray.std',
                          'numpy.ma.MaskedArray.sum': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.sum.html#numpy.ma.MaskedArray.sum',
                          'numpy.ma.MaskedArray.swapaxes': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.swapaxes.html#numpy.ma.MaskedArray.swapaxes',
                          'numpy.ma.MaskedArray.take': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.take.html#numpy.ma.MaskedArray.take',
                          'numpy.ma.MaskedArray.tobytes': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.tobytes.html#numpy.ma.MaskedArray.tobytes',
                          'numpy.ma.MaskedArray.tofile': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.tofile.html#numpy.ma.MaskedArray.tofile',
                          'numpy.ma.MaskedArray.toflex': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.toflex.html#numpy.ma.MaskedArray.toflex',
                          'numpy.ma.MaskedArray.tolist': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.tolist.html#numpy.ma.MaskedArray.tolist',
                          'numpy.ma.MaskedArray.torecords': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.torecords.html#numpy.ma.MaskedArray.torecords',
                          'numpy.ma.MaskedArray.tostring': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.tostring.html#numpy.ma.MaskedArray.tostring',
                          'numpy.ma.MaskedArray.trace': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.trace.html#numpy.ma.MaskedArray.trace',
                          'numpy.ma.MaskedArray.transpose': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.transpose.html#numpy.ma.MaskedArray.transpose',
                          'numpy.ma.MaskedArray.unshare_mask': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.unshare_mask.html#numpy.ma.MaskedArray.unshare_mask',
                          'numpy.ma.MaskedArray.var': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.var.html#numpy.ma.MaskedArray.var',
                          'numpy.ma.MaskedArray.view': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.MaskedArray.view.html#numpy.ma.MaskedArray.view',
                          'numpy.ma.allclose': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.allclose.html#numpy.ma.allclose',
                          'numpy.ma.allequal': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.allequal.html#numpy.ma.allequal',
                          'numpy.ma.append': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.append.html#numpy.ma.append',
                          'numpy.ma.apply_along_axis': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.apply_along_axis.html#numpy.ma.apply_along_axis',
                          'numpy.ma.apply_over_axes': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.apply_over_axes.html#numpy.ma.apply_over_axes',
                          'numpy.ma.argsort': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.argsort.html#numpy.ma.argsort',
                          'numpy.ma.array': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.array.html#numpy.ma.array',
                          'numpy.ma.asanyarray': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.asanyarray.html#numpy.ma.asanyarray',
                          'numpy.ma.asarray': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.asarray.html#numpy.ma.asarray',
                          'numpy.ma.average': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.average.html#numpy.ma.average',
                          'numpy.ma.choose': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.choose.html#numpy.ma.choose',
                          'numpy.ma.clump_masked': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.clump_masked.html#numpy.ma.clump_masked',
                          'numpy.ma.clump_unmasked': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.clump_unmasked.html#numpy.ma.clump_unmasked',
                          'numpy.ma.common_fill_value': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.common_fill_value.html#numpy.ma.common_fill_value',
                          'numpy.ma.compress_cols': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.compress_cols.html#numpy.ma.compress_cols',
                          'numpy.ma.compress_rowcols': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.compress_rowcols.html#numpy.ma.compress_rowcols',
                          'numpy.ma.compress_rows': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.compress_rows.html#numpy.ma.compress_rows',
                          'numpy.ma.compressed': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.compressed.html#numpy.ma.compressed',
                          'numpy.ma.concatenate': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.concatenate.html#numpy.ma.concatenate',
                          'numpy.ma.corrcoef': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.corrcoef.html#numpy.ma.corrcoef',
                          'numpy.ma.count_masked': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.count_masked.html#numpy.ma.count_masked',
                          'numpy.ma.cov': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.cov.html#numpy.ma.cov',
                          'numpy.ma.default_fill_value': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.default_fill_value.html#numpy.ma.default_fill_value',
                          'numpy.ma.diag': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.diag.html#numpy.ma.diag',
                          'numpy.ma.dot': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.dot.html#numpy.ma.dot',
                          'numpy.ma.ediff1d': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.ediff1d.html#numpy.ma.ediff1d',
                          'numpy.ma.expand_dims': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.expand_dims.html#numpy.ma.expand_dims',
                          'numpy.ma.filled': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.filled.html#numpy.ma.filled',
                          'numpy.ma.fix_invalid': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.fix_invalid.html#numpy.ma.fix_invalid',
                          'numpy.ma.flatnotmasked_contiguous': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.flatnotmasked_contiguous.html#numpy.ma.flatnotmasked_contiguous',
                          'numpy.ma.flatnotmasked_edges': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.flatnotmasked_edges.html#numpy.ma.flatnotmasked_edges',
                          'numpy.ma.getdata': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.getdata.html#numpy.ma.getdata',
                          'numpy.ma.getmask': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.getmask.html#numpy.ma.getmask',
                          'numpy.ma.getmaskarray': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.getmaskarray.html#numpy.ma.getmaskarray',
                          'numpy.ma.inner': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.inner.html#numpy.ma.inner',
                          'numpy.ma.innerproduct': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.innerproduct.html#numpy.ma.innerproduct',
                          'numpy.ma.isMA': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.isMA.html#numpy.ma.isMA',
                          'numpy.ma.isMaskedArray': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.isMaskedArray.html#numpy.ma.isMaskedArray',
                          'numpy.ma.is_mask': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.is_mask.html#numpy.ma.is_mask',
                          'numpy.ma.is_masked': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.is_masked.html#numpy.ma.is_masked',
                          'numpy.ma.isarray': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.isarray.html#numpy.ma.isarray',
                          'numpy.ma.make_mask': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.make_mask.html#numpy.ma.make_mask',
                          'numpy.ma.make_mask_descr': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.make_mask_descr.html#numpy.ma.make_mask_descr',
                          'numpy.ma.make_mask_none': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.make_mask_none.html#numpy.ma.make_mask_none',
                          'numpy.ma.mask_cols': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.mask_cols.html#numpy.ma.mask_cols',
                          'numpy.ma.mask_or': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.mask_or.html#numpy.ma.mask_or',
                          'numpy.ma.mask_rowcols': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.mask_rowcols.html#numpy.ma.mask_rowcols',
                          'numpy.ma.mask_rows': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.mask_rows.html#numpy.ma.mask_rows',
                          'numpy.ma.masked_all': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_all.html#numpy.ma.masked_all',
                          'numpy.ma.masked_all_like': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_all_like.html#numpy.ma.masked_all_like',
                          'numpy.ma.masked_array.all': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.all.html#numpy.ma.masked_array.all',
                          'numpy.ma.masked_array.anom': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.anom.html#numpy.ma.masked_array.anom',
                          'numpy.ma.masked_array.any': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.any.html#numpy.ma.masked_array.any',
                          'numpy.ma.masked_array.argmax': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.argmax.html#numpy.ma.masked_array.argmax',
                          'numpy.ma.masked_array.argmin': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.argmin.html#numpy.ma.masked_array.argmin',
                          'numpy.ma.masked_array.argpartition': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.argpartition.html#numpy.ma.masked_array.argpartition',
                          'numpy.ma.masked_array.argsort': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.argsort.html#numpy.ma.masked_array.argsort',
                          'numpy.ma.masked_array.astype': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.astype.html#numpy.ma.masked_array.astype',
                          'numpy.ma.masked_array.byteswap': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.byteswap.html#numpy.ma.masked_array.byteswap',
                          'numpy.ma.masked_array.choose': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.choose.html#numpy.ma.masked_array.choose',
                          'numpy.ma.masked_array.clip': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.clip.html#numpy.ma.masked_array.clip',
                          'numpy.ma.masked_array.compress': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.compress.html#numpy.ma.masked_array.compress',
                          'numpy.ma.masked_array.compressed': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.compressed.html#numpy.ma.masked_array.compressed',
                          'numpy.ma.masked_array.conj': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.conj.html#numpy.ma.masked_array.conj',
                          'numpy.ma.masked_array.conjugate': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.conjugate.html#numpy.ma.masked_array.conjugate',
                          'numpy.ma.masked_array.copy': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.copy.html#numpy.ma.masked_array.copy',
                          'numpy.ma.masked_array.count': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.count.html#numpy.ma.masked_array.count',
                          'numpy.ma.masked_array.cumprod': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.cumprod.html#numpy.ma.masked_array.cumprod',
                          'numpy.ma.masked_array.cumsum': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.cumsum.html#numpy.ma.masked_array.cumsum',
                          'numpy.ma.masked_array.diagonal': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.diagonal.html#numpy.ma.masked_array.diagonal',
                          'numpy.ma.masked_array.dot': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.dot.html#numpy.ma.masked_array.dot',
                          'numpy.ma.masked_array.dump': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.dump.html#numpy.ma.masked_array.dump',
                          'numpy.ma.masked_array.dumps': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.dumps.html#numpy.ma.masked_array.dumps',
                          'numpy.ma.masked_array.fill': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.fill.html#numpy.ma.masked_array.fill',
                          'numpy.ma.masked_array.filled': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.filled.html#numpy.ma.masked_array.filled',
                          'numpy.ma.masked_array.flatten': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.flatten.html#numpy.ma.masked_array.flatten',
                          'numpy.ma.masked_array.get_fill_value': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.get_fill_value.html#numpy.ma.masked_array.get_fill_value',
                          'numpy.ma.masked_array.get_imag': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.get_imag.html#numpy.ma.masked_array.get_imag',
                          'numpy.ma.masked_array.get_real': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.get_real.html#numpy.ma.masked_array.get_real',
                          'numpy.ma.masked_array.getfield': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.getfield.html#numpy.ma.masked_array.getfield',
                          'numpy.ma.masked_array.harden_mask': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.harden_mask.html#numpy.ma.masked_array.harden_mask',
                          'numpy.ma.masked_array.ids': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.ids.html#numpy.ma.masked_array.ids',
                          'numpy.ma.masked_array.iscontiguous': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.iscontiguous.html#numpy.ma.masked_array.iscontiguous',
                          'numpy.ma.masked_array.item': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.item.html#numpy.ma.masked_array.item',
                          'numpy.ma.masked_array.itemset': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.itemset.html#numpy.ma.masked_array.itemset',
                          'numpy.ma.masked_array.max': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.max.html#numpy.ma.masked_array.max',
                          'numpy.ma.masked_array.mean': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.mean.html#numpy.ma.masked_array.mean',
                          'numpy.ma.masked_array.min': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.min.html#numpy.ma.masked_array.min',
                          'numpy.ma.masked_array.mini': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.mini.html#numpy.ma.masked_array.mini',
                          'numpy.ma.masked_array.newbyteorder': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.newbyteorder.html#numpy.ma.masked_array.newbyteorder',
                          'numpy.ma.masked_array.nonzero': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.nonzero.html#numpy.ma.masked_array.nonzero',
                          'numpy.ma.masked_array.partition': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.partition.html#numpy.ma.masked_array.partition',
                          'numpy.ma.masked_array.prod': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.prod.html#numpy.ma.masked_array.prod',
                          'numpy.ma.masked_array.product': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.product.html#numpy.ma.masked_array.product',
                          'numpy.ma.masked_array.ptp': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.ptp.html#numpy.ma.masked_array.ptp',
                          'numpy.ma.masked_array.put': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.put.html#numpy.ma.masked_array.put',
                          'numpy.ma.masked_array.ravel': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.ravel.html#numpy.ma.masked_array.ravel',
                          'numpy.ma.masked_array.repeat': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.repeat.html#numpy.ma.masked_array.repeat',
                          'numpy.ma.masked_array.reshape': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.reshape.html#numpy.ma.masked_array.reshape',
                          'numpy.ma.masked_array.resize': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.resize.html#numpy.ma.masked_array.resize',
                          'numpy.ma.masked_array.round': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.round.html#numpy.ma.masked_array.round',
                          'numpy.ma.masked_array.searchsorted': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.searchsorted.html#numpy.ma.masked_array.searchsorted',
                          'numpy.ma.masked_array.set_fill_value': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.set_fill_value.html#numpy.ma.masked_array.set_fill_value',
                          'numpy.ma.masked_array.setfield': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.setfield.html#numpy.ma.masked_array.setfield',
                          'numpy.ma.masked_array.setflags': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.setflags.html#numpy.ma.masked_array.setflags',
                          'numpy.ma.masked_array.shrink_mask': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.shrink_mask.html#numpy.ma.masked_array.shrink_mask',
                          'numpy.ma.masked_array.soften_mask': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.soften_mask.html#numpy.ma.masked_array.soften_mask',
                          'numpy.ma.masked_array.sort': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.sort.html#numpy.ma.masked_array.sort',
                          'numpy.ma.masked_array.squeeze': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.squeeze.html#numpy.ma.masked_array.squeeze',
                          'numpy.ma.masked_array.std': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.std.html#numpy.ma.masked_array.std',
                          'numpy.ma.masked_array.sum': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.sum.html#numpy.ma.masked_array.sum',
                          'numpy.ma.masked_array.swapaxes': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.swapaxes.html#numpy.ma.masked_array.swapaxes',
                          'numpy.ma.masked_array.take': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.take.html#numpy.ma.masked_array.take',
                          'numpy.ma.masked_array.tobytes': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.tobytes.html#numpy.ma.masked_array.tobytes',
                          'numpy.ma.masked_array.tofile': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.tofile.html#numpy.ma.masked_array.tofile',
                          'numpy.ma.masked_array.toflex': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.toflex.html#numpy.ma.masked_array.toflex',
                          'numpy.ma.masked_array.tolist': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.tolist.html#numpy.ma.masked_array.tolist',
                          'numpy.ma.masked_array.torecords': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.torecords.html#numpy.ma.masked_array.torecords',
                          'numpy.ma.masked_array.tostring': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.tostring.html#numpy.ma.masked_array.tostring',
                          'numpy.ma.masked_array.trace': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.trace.html#numpy.ma.masked_array.trace',
                          'numpy.ma.masked_array.transpose': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.transpose.html#numpy.ma.masked_array.transpose',
                          'numpy.ma.masked_array.unshare_mask': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.unshare_mask.html#numpy.ma.masked_array.unshare_mask',
                          'numpy.ma.masked_array.var': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.var.html#numpy.ma.masked_array.var',
                          'numpy.ma.masked_array.view': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_array.view.html#numpy.ma.masked_array.view',
                          'numpy.ma.masked_equal': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_equal.html#numpy.ma.masked_equal',
                          'numpy.ma.masked_greater': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_greater.html#numpy.ma.masked_greater',
                          'numpy.ma.masked_greater_equal': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_greater_equal.html#numpy.ma.masked_greater_equal',
                          'numpy.ma.masked_inside': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_inside.html#numpy.ma.masked_inside',
                          'numpy.ma.masked_invalid': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_invalid.html#numpy.ma.masked_invalid',
                          'numpy.ma.masked_less': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_less.html#numpy.ma.masked_less',
                          'numpy.ma.masked_less_equal': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_less_equal.html#numpy.ma.masked_less_equal',
                          'numpy.ma.masked_not_equal': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_not_equal.html#numpy.ma.masked_not_equal',
                          'numpy.ma.masked_object': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_object.html#numpy.ma.masked_object',
                          'numpy.ma.masked_outside': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_outside.html#numpy.ma.masked_outside',
                          'numpy.ma.masked_values': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_values.html#numpy.ma.masked_values',
                          'numpy.ma.masked_where': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.masked_where.html#numpy.ma.masked_where',
                          'numpy.ma.max': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.max.html#numpy.ma.max',
                          'numpy.ma.maximum_fill_value': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.maximum_fill_value.html#numpy.ma.maximum_fill_value',
                          'numpy.ma.median': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.median.html#numpy.ma.median',
                          'numpy.ma.min': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.min.html#numpy.ma.min',
                          'numpy.ma.minimum_fill_value': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.minimum_fill_value.html#numpy.ma.minimum_fill_value',
                          'numpy.ma.ndenumerate': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.ndenumerate.html#numpy.ma.ndenumerate',
                          'numpy.ma.notmasked_contiguous': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.notmasked_contiguous.html#numpy.ma.notmasked_contiguous',
                          'numpy.ma.notmasked_edges': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.notmasked_edges.html#numpy.ma.notmasked_edges',
                          'numpy.ma.outer': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.outer.html#numpy.ma.outer',
                          'numpy.ma.outerproduct': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.outerproduct.html#numpy.ma.outerproduct',
                          'numpy.ma.polyfit': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.polyfit.html#numpy.ma.polyfit',
                          'numpy.ma.power': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.power.html#numpy.ma.power',
                          'numpy.ma.ptp': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.ptp.html#numpy.ma.ptp',
                          'numpy.ma.reshape': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.reshape.html#numpy.ma.reshape',
                          'numpy.ma.resize': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.resize.html#numpy.ma.resize',
                          'numpy.ma.round': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.round.html#numpy.ma.round',
                          'numpy.ma.set_fill_value': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.set_fill_value.html#numpy.ma.set_fill_value',
                          'numpy.ma.shape': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.shape.html#numpy.ma.shape',
                          'numpy.ma.size': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.size.html#numpy.ma.size',
                          'numpy.ma.sort': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.sort.html#numpy.ma.sort',
                          'numpy.ma.transpose': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.transpose.html#numpy.ma.transpose',
                          'numpy.ma.vander': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.vander.html#numpy.ma.vander',
                          'numpy.ma.where': 'https://numpy.org/doc/stable/reference/generated/numpy.ma.where.html#numpy.ma.where'},
            'numpy.matlib': { 'numpy.matlib.empty': 'https://numpy.org/doc/stable/reference/generated/numpy.matlib.empty.html#numpy.matlib.empty',
                              'numpy.matlib.eye': 'https://numpy.org/doc/stable/reference/generated/numpy.matlib.eye.html#numpy.matlib.eye',
                              'numpy.matlib.identity': 'https://numpy.org/doc/stable/reference/generated/numpy.matlib.identity.html#numpy.matlib.identity',
                              'numpy.matlib.ones': 'https://numpy.org/doc/stable/reference/generated/numpy.matlib.ones.html#numpy.matlib.ones',
                              'numpy.matlib.rand': 'https://numpy.org/doc/stable/reference/generated/numpy.matlib.rand.html#numpy.matlib.rand',
                              'numpy.matlib.randn': 'https://numpy.org/doc/stable/reference/generated/numpy.matlib.randn.html#numpy.matlib.randn',
                              'numpy.matlib.repmat': 'https://numpy.org/doc/stable/reference/generated/numpy.matlib.repmat.html#numpy.matlib.repmat',
                              'numpy.matlib.zeros': 'https://numpy.org/doc/stable/reference/generated/numpy.matlib.zeros.html#numpy.matlib.zeros'},
            'numpy.polynomial': { 'numpy.polynomial.chebyshev': 'https://numpy.org/doc/stable/reference/routines.polynomials.chebyshev.html#module-numpy.polynomial.chebyshev',
                                  'numpy.polynomial.hermite': 'https://numpy.org/doc/stable/reference/routines.polynomials.hermite.html#module-numpy.polynomial.hermite',
                                  'numpy.polynomial.hermite_e': 'https://numpy.org/doc/stable/reference/routines.polynomials.hermite_e.html#module-numpy.polynomial.hermite_e',
                                  'numpy.polynomial.laguerre': 'https://numpy.org/doc/stable/reference/routines.polynomials.laguerre.html#module-numpy.polynomial.laguerre',
                                  'numpy.polynomial.legendre': 'https://numpy.org/doc/stable/reference/routines.polynomials.legendre.html#module-numpy.polynomial.legendre',
                                  'numpy.polynomial.polynomial': 'https://numpy.org/doc/stable/reference/routines.polynomials.polynomial.html#module-numpy.polynomial.polynomial',
                                  'numpy.polynomial.polyutils': 'https://numpy.org/doc/stable/reference/routines.polynomials.polyutils.html#module-numpy.polynomial.polyutils',
                                  'numpy.polynomial.set_default_printstyle': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.set_default_printstyle.html#numpy.polynomial.set_default_printstyle'},
            'numpy.polynomial.chebyshev': { 'numpy.polynomial.chebyshev.Chebyshev': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.Chebyshev.html#numpy.polynomial.chebyshev.Chebyshev',
                                            'numpy.polynomial.chebyshev.Chebyshev.__call__': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.Chebyshev.__call__.html#numpy.polynomial.chebyshev.Chebyshev.__call__',
                                            'numpy.polynomial.chebyshev.Chebyshev.basis': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.Chebyshev.basis.html#numpy.polynomial.chebyshev.Chebyshev.basis',
                                            'numpy.polynomial.chebyshev.Chebyshev.cast': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.Chebyshev.cast.html#numpy.polynomial.chebyshev.Chebyshev.cast',
                                            'numpy.polynomial.chebyshev.Chebyshev.convert': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.Chebyshev.convert.html#numpy.polynomial.chebyshev.Chebyshev.convert',
                                            'numpy.polynomial.chebyshev.Chebyshev.copy': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.Chebyshev.copy.html#numpy.polynomial.chebyshev.Chebyshev.copy',
                                            'numpy.polynomial.chebyshev.Chebyshev.cutdeg': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.Chebyshev.cutdeg.html#numpy.polynomial.chebyshev.Chebyshev.cutdeg',
                                            'numpy.polynomial.chebyshev.Chebyshev.degree': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.Chebyshev.degree.html#numpy.polynomial.chebyshev.Chebyshev.degree',
                                            'numpy.polynomial.chebyshev.Chebyshev.deriv': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.Chebyshev.deriv.html#numpy.polynomial.chebyshev.Chebyshev.deriv',
                                            'numpy.polynomial.chebyshev.Chebyshev.fit': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.Chebyshev.fit.html#numpy.polynomial.chebyshev.Chebyshev.fit',
                                            'numpy.polynomial.chebyshev.Chebyshev.fromroots': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.Chebyshev.fromroots.html#numpy.polynomial.chebyshev.Chebyshev.fromroots',
                                            'numpy.polynomial.chebyshev.Chebyshev.has_samecoef': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.Chebyshev.has_samecoef.html#numpy.polynomial.chebyshev.Chebyshev.has_samecoef',
                                            'numpy.polynomial.chebyshev.Chebyshev.has_samedomain': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.Chebyshev.has_samedomain.html#numpy.polynomial.chebyshev.Chebyshev.has_samedomain',
                                            'numpy.polynomial.chebyshev.Chebyshev.has_sametype': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.Chebyshev.has_sametype.html#numpy.polynomial.chebyshev.Chebyshev.has_sametype',
                                            'numpy.polynomial.chebyshev.Chebyshev.has_samewindow': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.Chebyshev.has_samewindow.html#numpy.polynomial.chebyshev.Chebyshev.has_samewindow',
                                            'numpy.polynomial.chebyshev.Chebyshev.identity': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.Chebyshev.identity.html#numpy.polynomial.chebyshev.Chebyshev.identity',
                                            'numpy.polynomial.chebyshev.Chebyshev.integ': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.Chebyshev.integ.html#numpy.polynomial.chebyshev.Chebyshev.integ',
                                            'numpy.polynomial.chebyshev.Chebyshev.interpolate': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.Chebyshev.interpolate.html#numpy.polynomial.chebyshev.Chebyshev.interpolate',
                                            'numpy.polynomial.chebyshev.Chebyshev.linspace': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.Chebyshev.linspace.html#numpy.polynomial.chebyshev.Chebyshev.linspace',
                                            'numpy.polynomial.chebyshev.Chebyshev.mapparms': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.Chebyshev.mapparms.html#numpy.polynomial.chebyshev.Chebyshev.mapparms',
                                            'numpy.polynomial.chebyshev.Chebyshev.roots': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.Chebyshev.roots.html#numpy.polynomial.chebyshev.Chebyshev.roots',
                                            'numpy.polynomial.chebyshev.Chebyshev.trim': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.Chebyshev.trim.html#numpy.polynomial.chebyshev.Chebyshev.trim',
                                            'numpy.polynomial.chebyshev.Chebyshev.truncate': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.Chebyshev.truncate.html#numpy.polynomial.chebyshev.Chebyshev.truncate',
                                            'numpy.polynomial.chebyshev.cheb2poly': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.cheb2poly.html#numpy.polynomial.chebyshev.cheb2poly',
                                            'numpy.polynomial.chebyshev.chebadd': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.chebadd.html#numpy.polynomial.chebyshev.chebadd',
                                            'numpy.polynomial.chebyshev.chebcompanion': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.chebcompanion.html#numpy.polynomial.chebyshev.chebcompanion',
                                            'numpy.polynomial.chebyshev.chebder': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.chebder.html#numpy.polynomial.chebyshev.chebder',
                                            'numpy.polynomial.chebyshev.chebdiv': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.chebdiv.html#numpy.polynomial.chebyshev.chebdiv',
                                            'numpy.polynomial.chebyshev.chebfit': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.chebfit.html#numpy.polynomial.chebyshev.chebfit',
                                            'numpy.polynomial.chebyshev.chebfromroots': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.chebfromroots.html#numpy.polynomial.chebyshev.chebfromroots',
                                            'numpy.polynomial.chebyshev.chebgauss': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.chebgauss.html#numpy.polynomial.chebyshev.chebgauss',
                                            'numpy.polynomial.chebyshev.chebgrid2d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.chebgrid2d.html#numpy.polynomial.chebyshev.chebgrid2d',
                                            'numpy.polynomial.chebyshev.chebgrid3d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.chebgrid3d.html#numpy.polynomial.chebyshev.chebgrid3d',
                                            'numpy.polynomial.chebyshev.chebint': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.chebint.html#numpy.polynomial.chebyshev.chebint',
                                            'numpy.polynomial.chebyshev.chebinterpolate': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.chebinterpolate.html#numpy.polynomial.chebyshev.chebinterpolate',
                                            'numpy.polynomial.chebyshev.chebline': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.chebline.html#numpy.polynomial.chebyshev.chebline',
                                            'numpy.polynomial.chebyshev.chebmul': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.chebmul.html#numpy.polynomial.chebyshev.chebmul',
                                            'numpy.polynomial.chebyshev.chebmulx': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.chebmulx.html#numpy.polynomial.chebyshev.chebmulx',
                                            'numpy.polynomial.chebyshev.chebpow': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.chebpow.html#numpy.polynomial.chebyshev.chebpow',
                                            'numpy.polynomial.chebyshev.chebpts1': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.chebpts1.html#numpy.polynomial.chebyshev.chebpts1',
                                            'numpy.polynomial.chebyshev.chebpts2': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.chebpts2.html#numpy.polynomial.chebyshev.chebpts2',
                                            'numpy.polynomial.chebyshev.chebroots': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.chebroots.html#numpy.polynomial.chebyshev.chebroots',
                                            'numpy.polynomial.chebyshev.chebsub': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.chebsub.html#numpy.polynomial.chebyshev.chebsub',
                                            'numpy.polynomial.chebyshev.chebtrim': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.chebtrim.html#numpy.polynomial.chebyshev.chebtrim',
                                            'numpy.polynomial.chebyshev.chebval': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.chebval.html#numpy.polynomial.chebyshev.chebval',
                                            'numpy.polynomial.chebyshev.chebval2d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.chebval2d.html#numpy.polynomial.chebyshev.chebval2d',
                                            'numpy.polynomial.chebyshev.chebval3d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.chebval3d.html#numpy.polynomial.chebyshev.chebval3d',
                                            'numpy.polynomial.chebyshev.chebvander': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.chebvander.html#numpy.polynomial.chebyshev.chebvander',
                                            'numpy.polynomial.chebyshev.chebvander2d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.chebvander2d.html#numpy.polynomial.chebyshev.chebvander2d',
                                            'numpy.polynomial.chebyshev.chebvander3d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.chebvander3d.html#numpy.polynomial.chebyshev.chebvander3d',
                                            'numpy.polynomial.chebyshev.chebweight': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.chebweight.html#numpy.polynomial.chebyshev.chebweight',
                                            'numpy.polynomial.chebyshev.poly2cheb': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.chebyshev.poly2cheb.html#numpy.polynomial.chebyshev.poly2cheb'},
            'numpy.polynomial.hermite': { 'numpy.polynomial.hermite.Hermite': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.Hermite.html#numpy.polynomial.hermite.Hermite',
                                          'numpy.polynomial.hermite.Hermite.__call__': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.Hermite.__call__.html#numpy.polynomial.hermite.Hermite.__call__',
                                          'numpy.polynomial.hermite.Hermite.basis': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.Hermite.basis.html#numpy.polynomial.hermite.Hermite.basis',
                                          'numpy.polynomial.hermite.Hermite.cast': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.Hermite.cast.html#numpy.polynomial.hermite.Hermite.cast',
                                          'numpy.polynomial.hermite.Hermite.convert': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.Hermite.convert.html#numpy.polynomial.hermite.Hermite.convert',
                                          'numpy.polynomial.hermite.Hermite.copy': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.Hermite.copy.html#numpy.polynomial.hermite.Hermite.copy',
                                          'numpy.polynomial.hermite.Hermite.cutdeg': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.Hermite.cutdeg.html#numpy.polynomial.hermite.Hermite.cutdeg',
                                          'numpy.polynomial.hermite.Hermite.degree': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.Hermite.degree.html#numpy.polynomial.hermite.Hermite.degree',
                                          'numpy.polynomial.hermite.Hermite.deriv': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.Hermite.deriv.html#numpy.polynomial.hermite.Hermite.deriv',
                                          'numpy.polynomial.hermite.Hermite.fit': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.Hermite.fit.html#numpy.polynomial.hermite.Hermite.fit',
                                          'numpy.polynomial.hermite.Hermite.fromroots': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.Hermite.fromroots.html#numpy.polynomial.hermite.Hermite.fromroots',
                                          'numpy.polynomial.hermite.Hermite.has_samecoef': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.Hermite.has_samecoef.html#numpy.polynomial.hermite.Hermite.has_samecoef',
                                          'numpy.polynomial.hermite.Hermite.has_samedomain': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.Hermite.has_samedomain.html#numpy.polynomial.hermite.Hermite.has_samedomain',
                                          'numpy.polynomial.hermite.Hermite.has_sametype': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.Hermite.has_sametype.html#numpy.polynomial.hermite.Hermite.has_sametype',
                                          'numpy.polynomial.hermite.Hermite.has_samewindow': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.Hermite.has_samewindow.html#numpy.polynomial.hermite.Hermite.has_samewindow',
                                          'numpy.polynomial.hermite.Hermite.identity': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.Hermite.identity.html#numpy.polynomial.hermite.Hermite.identity',
                                          'numpy.polynomial.hermite.Hermite.integ': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.Hermite.integ.html#numpy.polynomial.hermite.Hermite.integ',
                                          'numpy.polynomial.hermite.Hermite.linspace': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.Hermite.linspace.html#numpy.polynomial.hermite.Hermite.linspace',
                                          'numpy.polynomial.hermite.Hermite.mapparms': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.Hermite.mapparms.html#numpy.polynomial.hermite.Hermite.mapparms',
                                          'numpy.polynomial.hermite.Hermite.roots': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.Hermite.roots.html#numpy.polynomial.hermite.Hermite.roots',
                                          'numpy.polynomial.hermite.Hermite.trim': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.Hermite.trim.html#numpy.polynomial.hermite.Hermite.trim',
                                          'numpy.polynomial.hermite.Hermite.truncate': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.Hermite.truncate.html#numpy.polynomial.hermite.Hermite.truncate',
                                          'numpy.polynomial.hermite.herm2poly': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.herm2poly.html#numpy.polynomial.hermite.herm2poly',
                                          'numpy.polynomial.hermite.hermadd': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.hermadd.html#numpy.polynomial.hermite.hermadd',
                                          'numpy.polynomial.hermite.hermcompanion': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.hermcompanion.html#numpy.polynomial.hermite.hermcompanion',
                                          'numpy.polynomial.hermite.hermder': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.hermder.html#numpy.polynomial.hermite.hermder',
                                          'numpy.polynomial.hermite.hermdiv': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.hermdiv.html#numpy.polynomial.hermite.hermdiv',
                                          'numpy.polynomial.hermite.hermfit': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.hermfit.html#numpy.polynomial.hermite.hermfit',
                                          'numpy.polynomial.hermite.hermfromroots': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.hermfromroots.html#numpy.polynomial.hermite.hermfromroots',
                                          'numpy.polynomial.hermite.hermgauss': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.hermgauss.html#numpy.polynomial.hermite.hermgauss',
                                          'numpy.polynomial.hermite.hermgrid2d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.hermgrid2d.html#numpy.polynomial.hermite.hermgrid2d',
                                          'numpy.polynomial.hermite.hermgrid3d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.hermgrid3d.html#numpy.polynomial.hermite.hermgrid3d',
                                          'numpy.polynomial.hermite.hermint': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.hermint.html#numpy.polynomial.hermite.hermint',
                                          'numpy.polynomial.hermite.hermline': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.hermline.html#numpy.polynomial.hermite.hermline',
                                          'numpy.polynomial.hermite.hermmul': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.hermmul.html#numpy.polynomial.hermite.hermmul',
                                          'numpy.polynomial.hermite.hermmulx': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.hermmulx.html#numpy.polynomial.hermite.hermmulx',
                                          'numpy.polynomial.hermite.hermpow': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.hermpow.html#numpy.polynomial.hermite.hermpow',
                                          'numpy.polynomial.hermite.hermroots': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.hermroots.html#numpy.polynomial.hermite.hermroots',
                                          'numpy.polynomial.hermite.hermsub': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.hermsub.html#numpy.polynomial.hermite.hermsub',
                                          'numpy.polynomial.hermite.hermtrim': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.hermtrim.html#numpy.polynomial.hermite.hermtrim',
                                          'numpy.polynomial.hermite.hermval': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.hermval.html#numpy.polynomial.hermite.hermval',
                                          'numpy.polynomial.hermite.hermval2d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.hermval2d.html#numpy.polynomial.hermite.hermval2d',
                                          'numpy.polynomial.hermite.hermval3d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.hermval3d.html#numpy.polynomial.hermite.hermval3d',
                                          'numpy.polynomial.hermite.hermvander': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.hermvander.html#numpy.polynomial.hermite.hermvander',
                                          'numpy.polynomial.hermite.hermvander2d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.hermvander2d.html#numpy.polynomial.hermite.hermvander2d',
                                          'numpy.polynomial.hermite.hermvander3d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.hermvander3d.html#numpy.polynomial.hermite.hermvander3d',
                                          'numpy.polynomial.hermite.hermweight': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.hermweight.html#numpy.polynomial.hermite.hermweight',
                                          'numpy.polynomial.hermite.poly2herm': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite.poly2herm.html#numpy.polynomial.hermite.poly2herm'},
            'numpy.polynomial.hermite_e': { 'numpy.polynomial.hermite_e.HermiteE': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.HermiteE.html#numpy.polynomial.hermite_e.HermiteE',
                                            'numpy.polynomial.hermite_e.HermiteE.__call__': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.HermiteE.__call__.html#numpy.polynomial.hermite_e.HermiteE.__call__',
                                            'numpy.polynomial.hermite_e.HermiteE.basis': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.HermiteE.basis.html#numpy.polynomial.hermite_e.HermiteE.basis',
                                            'numpy.polynomial.hermite_e.HermiteE.cast': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.HermiteE.cast.html#numpy.polynomial.hermite_e.HermiteE.cast',
                                            'numpy.polynomial.hermite_e.HermiteE.convert': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.HermiteE.convert.html#numpy.polynomial.hermite_e.HermiteE.convert',
                                            'numpy.polynomial.hermite_e.HermiteE.copy': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.HermiteE.copy.html#numpy.polynomial.hermite_e.HermiteE.copy',
                                            'numpy.polynomial.hermite_e.HermiteE.cutdeg': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.HermiteE.cutdeg.html#numpy.polynomial.hermite_e.HermiteE.cutdeg',
                                            'numpy.polynomial.hermite_e.HermiteE.degree': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.HermiteE.degree.html#numpy.polynomial.hermite_e.HermiteE.degree',
                                            'numpy.polynomial.hermite_e.HermiteE.deriv': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.HermiteE.deriv.html#numpy.polynomial.hermite_e.HermiteE.deriv',
                                            'numpy.polynomial.hermite_e.HermiteE.fit': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.HermiteE.fit.html#numpy.polynomial.hermite_e.HermiteE.fit',
                                            'numpy.polynomial.hermite_e.HermiteE.fromroots': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.HermiteE.fromroots.html#numpy.polynomial.hermite_e.HermiteE.fromroots',
                                            'numpy.polynomial.hermite_e.HermiteE.has_samecoef': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.HermiteE.has_samecoef.html#numpy.polynomial.hermite_e.HermiteE.has_samecoef',
                                            'numpy.polynomial.hermite_e.HermiteE.has_samedomain': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.HermiteE.has_samedomain.html#numpy.polynomial.hermite_e.HermiteE.has_samedomain',
                                            'numpy.polynomial.hermite_e.HermiteE.has_sametype': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.HermiteE.has_sametype.html#numpy.polynomial.hermite_e.HermiteE.has_sametype',
                                            'numpy.polynomial.hermite_e.HermiteE.has_samewindow': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.HermiteE.has_samewindow.html#numpy.polynomial.hermite_e.HermiteE.has_samewindow',
                                            'numpy.polynomial.hermite_e.HermiteE.identity': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.HermiteE.identity.html#numpy.polynomial.hermite_e.HermiteE.identity',
                                            'numpy.polynomial.hermite_e.HermiteE.integ': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.HermiteE.integ.html#numpy.polynomial.hermite_e.HermiteE.integ',
                                            'numpy.polynomial.hermite_e.HermiteE.linspace': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.HermiteE.linspace.html#numpy.polynomial.hermite_e.HermiteE.linspace',
                                            'numpy.polynomial.hermite_e.HermiteE.mapparms': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.HermiteE.mapparms.html#numpy.polynomial.hermite_e.HermiteE.mapparms',
                                            'numpy.polynomial.hermite_e.HermiteE.roots': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.HermiteE.roots.html#numpy.polynomial.hermite_e.HermiteE.roots',
                                            'numpy.polynomial.hermite_e.HermiteE.trim': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.HermiteE.trim.html#numpy.polynomial.hermite_e.HermiteE.trim',
                                            'numpy.polynomial.hermite_e.HermiteE.truncate': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.HermiteE.truncate.html#numpy.polynomial.hermite_e.HermiteE.truncate',
                                            'numpy.polynomial.hermite_e.herme2poly': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.herme2poly.html#numpy.polynomial.hermite_e.herme2poly',
                                            'numpy.polynomial.hermite_e.hermeadd': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.hermeadd.html#numpy.polynomial.hermite_e.hermeadd',
                                            'numpy.polynomial.hermite_e.hermecompanion': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.hermecompanion.html#numpy.polynomial.hermite_e.hermecompanion',
                                            'numpy.polynomial.hermite_e.hermeder': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.hermeder.html#numpy.polynomial.hermite_e.hermeder',
                                            'numpy.polynomial.hermite_e.hermediv': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.hermediv.html#numpy.polynomial.hermite_e.hermediv',
                                            'numpy.polynomial.hermite_e.hermefit': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.hermefit.html#numpy.polynomial.hermite_e.hermefit',
                                            'numpy.polynomial.hermite_e.hermefromroots': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.hermefromroots.html#numpy.polynomial.hermite_e.hermefromroots',
                                            'numpy.polynomial.hermite_e.hermegauss': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.hermegauss.html#numpy.polynomial.hermite_e.hermegauss',
                                            'numpy.polynomial.hermite_e.hermegrid2d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.hermegrid2d.html#numpy.polynomial.hermite_e.hermegrid2d',
                                            'numpy.polynomial.hermite_e.hermegrid3d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.hermegrid3d.html#numpy.polynomial.hermite_e.hermegrid3d',
                                            'numpy.polynomial.hermite_e.hermeint': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.hermeint.html#numpy.polynomial.hermite_e.hermeint',
                                            'numpy.polynomial.hermite_e.hermeline': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.hermeline.html#numpy.polynomial.hermite_e.hermeline',
                                            'numpy.polynomial.hermite_e.hermemul': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.hermemul.html#numpy.polynomial.hermite_e.hermemul',
                                            'numpy.polynomial.hermite_e.hermemulx': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.hermemulx.html#numpy.polynomial.hermite_e.hermemulx',
                                            'numpy.polynomial.hermite_e.hermepow': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.hermepow.html#numpy.polynomial.hermite_e.hermepow',
                                            'numpy.polynomial.hermite_e.hermeroots': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.hermeroots.html#numpy.polynomial.hermite_e.hermeroots',
                                            'numpy.polynomial.hermite_e.hermesub': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.hermesub.html#numpy.polynomial.hermite_e.hermesub',
                                            'numpy.polynomial.hermite_e.hermetrim': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.hermetrim.html#numpy.polynomial.hermite_e.hermetrim',
                                            'numpy.polynomial.hermite_e.hermeval': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.hermeval.html#numpy.polynomial.hermite_e.hermeval',
                                            'numpy.polynomial.hermite_e.hermeval2d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.hermeval2d.html#numpy.polynomial.hermite_e.hermeval2d',
                                            'numpy.polynomial.hermite_e.hermeval3d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.hermeval3d.html#numpy.polynomial.hermite_e.hermeval3d',
                                            'numpy.polynomial.hermite_e.hermevander': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.hermevander.html#numpy.polynomial.hermite_e.hermevander',
                                            'numpy.polynomial.hermite_e.hermevander2d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.hermevander2d.html#numpy.polynomial.hermite_e.hermevander2d',
                                            'numpy.polynomial.hermite_e.hermevander3d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.hermevander3d.html#numpy.polynomial.hermite_e.hermevander3d',
                                            'numpy.polynomial.hermite_e.hermeweight': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.hermeweight.html#numpy.polynomial.hermite_e.hermeweight',
                                            'numpy.polynomial.hermite_e.poly2herme': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.hermite_e.poly2herme.html#numpy.polynomial.hermite_e.poly2herme'},
            'numpy.polynomial.laguerre': { 'numpy.polynomial.laguerre.Laguerre': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.Laguerre.html#numpy.polynomial.laguerre.Laguerre',
                                           'numpy.polynomial.laguerre.Laguerre.__call__': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.Laguerre.__call__.html#numpy.polynomial.laguerre.Laguerre.__call__',
                                           'numpy.polynomial.laguerre.Laguerre.basis': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.Laguerre.basis.html#numpy.polynomial.laguerre.Laguerre.basis',
                                           'numpy.polynomial.laguerre.Laguerre.cast': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.Laguerre.cast.html#numpy.polynomial.laguerre.Laguerre.cast',
                                           'numpy.polynomial.laguerre.Laguerre.convert': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.Laguerre.convert.html#numpy.polynomial.laguerre.Laguerre.convert',
                                           'numpy.polynomial.laguerre.Laguerre.copy': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.Laguerre.copy.html#numpy.polynomial.laguerre.Laguerre.copy',
                                           'numpy.polynomial.laguerre.Laguerre.cutdeg': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.Laguerre.cutdeg.html#numpy.polynomial.laguerre.Laguerre.cutdeg',
                                           'numpy.polynomial.laguerre.Laguerre.degree': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.Laguerre.degree.html#numpy.polynomial.laguerre.Laguerre.degree',
                                           'numpy.polynomial.laguerre.Laguerre.deriv': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.Laguerre.deriv.html#numpy.polynomial.laguerre.Laguerre.deriv',
                                           'numpy.polynomial.laguerre.Laguerre.fit': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.Laguerre.fit.html#numpy.polynomial.laguerre.Laguerre.fit',
                                           'numpy.polynomial.laguerre.Laguerre.fromroots': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.Laguerre.fromroots.html#numpy.polynomial.laguerre.Laguerre.fromroots',
                                           'numpy.polynomial.laguerre.Laguerre.has_samecoef': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.Laguerre.has_samecoef.html#numpy.polynomial.laguerre.Laguerre.has_samecoef',
                                           'numpy.polynomial.laguerre.Laguerre.has_samedomain': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.Laguerre.has_samedomain.html#numpy.polynomial.laguerre.Laguerre.has_samedomain',
                                           'numpy.polynomial.laguerre.Laguerre.has_sametype': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.Laguerre.has_sametype.html#numpy.polynomial.laguerre.Laguerre.has_sametype',
                                           'numpy.polynomial.laguerre.Laguerre.has_samewindow': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.Laguerre.has_samewindow.html#numpy.polynomial.laguerre.Laguerre.has_samewindow',
                                           'numpy.polynomial.laguerre.Laguerre.identity': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.Laguerre.identity.html#numpy.polynomial.laguerre.Laguerre.identity',
                                           'numpy.polynomial.laguerre.Laguerre.integ': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.Laguerre.integ.html#numpy.polynomial.laguerre.Laguerre.integ',
                                           'numpy.polynomial.laguerre.Laguerre.linspace': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.Laguerre.linspace.html#numpy.polynomial.laguerre.Laguerre.linspace',
                                           'numpy.polynomial.laguerre.Laguerre.mapparms': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.Laguerre.mapparms.html#numpy.polynomial.laguerre.Laguerre.mapparms',
                                           'numpy.polynomial.laguerre.Laguerre.roots': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.Laguerre.roots.html#numpy.polynomial.laguerre.Laguerre.roots',
                                           'numpy.polynomial.laguerre.Laguerre.trim': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.Laguerre.trim.html#numpy.polynomial.laguerre.Laguerre.trim',
                                           'numpy.polynomial.laguerre.Laguerre.truncate': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.Laguerre.truncate.html#numpy.polynomial.laguerre.Laguerre.truncate',
                                           'numpy.polynomial.laguerre.lag2poly': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.lag2poly.html#numpy.polynomial.laguerre.lag2poly',
                                           'numpy.polynomial.laguerre.lagadd': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.lagadd.html#numpy.polynomial.laguerre.lagadd',
                                           'numpy.polynomial.laguerre.lagcompanion': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.lagcompanion.html#numpy.polynomial.laguerre.lagcompanion',
                                           'numpy.polynomial.laguerre.lagder': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.lagder.html#numpy.polynomial.laguerre.lagder',
                                           'numpy.polynomial.laguerre.lagdiv': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.lagdiv.html#numpy.polynomial.laguerre.lagdiv',
                                           'numpy.polynomial.laguerre.lagfit': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.lagfit.html#numpy.polynomial.laguerre.lagfit',
                                           'numpy.polynomial.laguerre.lagfromroots': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.lagfromroots.html#numpy.polynomial.laguerre.lagfromroots',
                                           'numpy.polynomial.laguerre.laggauss': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.laggauss.html#numpy.polynomial.laguerre.laggauss',
                                           'numpy.polynomial.laguerre.laggrid2d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.laggrid2d.html#numpy.polynomial.laguerre.laggrid2d',
                                           'numpy.polynomial.laguerre.laggrid3d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.laggrid3d.html#numpy.polynomial.laguerre.laggrid3d',
                                           'numpy.polynomial.laguerre.lagint': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.lagint.html#numpy.polynomial.laguerre.lagint',
                                           'numpy.polynomial.laguerre.lagline': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.lagline.html#numpy.polynomial.laguerre.lagline',
                                           'numpy.polynomial.laguerre.lagmul': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.lagmul.html#numpy.polynomial.laguerre.lagmul',
                                           'numpy.polynomial.laguerre.lagmulx': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.lagmulx.html#numpy.polynomial.laguerre.lagmulx',
                                           'numpy.polynomial.laguerre.lagpow': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.lagpow.html#numpy.polynomial.laguerre.lagpow',
                                           'numpy.polynomial.laguerre.lagroots': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.lagroots.html#numpy.polynomial.laguerre.lagroots',
                                           'numpy.polynomial.laguerre.lagsub': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.lagsub.html#numpy.polynomial.laguerre.lagsub',
                                           'numpy.polynomial.laguerre.lagtrim': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.lagtrim.html#numpy.polynomial.laguerre.lagtrim',
                                           'numpy.polynomial.laguerre.lagval': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.lagval.html#numpy.polynomial.laguerre.lagval',
                                           'numpy.polynomial.laguerre.lagval2d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.lagval2d.html#numpy.polynomial.laguerre.lagval2d',
                                           'numpy.polynomial.laguerre.lagval3d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.lagval3d.html#numpy.polynomial.laguerre.lagval3d',
                                           'numpy.polynomial.laguerre.lagvander': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.lagvander.html#numpy.polynomial.laguerre.lagvander',
                                           'numpy.polynomial.laguerre.lagvander2d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.lagvander2d.html#numpy.polynomial.laguerre.lagvander2d',
                                           'numpy.polynomial.laguerre.lagvander3d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.lagvander3d.html#numpy.polynomial.laguerre.lagvander3d',
                                           'numpy.polynomial.laguerre.lagweight': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.lagweight.html#numpy.polynomial.laguerre.lagweight',
                                           'numpy.polynomial.laguerre.poly2lag': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.laguerre.poly2lag.html#numpy.polynomial.laguerre.poly2lag'},
            'numpy.polynomial.legendre': { 'numpy.polynomial.legendre.Legendre': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.Legendre.html#numpy.polynomial.legendre.Legendre',
                                           'numpy.polynomial.legendre.Legendre.__call__': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.Legendre.__call__.html#numpy.polynomial.legendre.Legendre.__call__',
                                           'numpy.polynomial.legendre.Legendre.basis': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.Legendre.basis.html#numpy.polynomial.legendre.Legendre.basis',
                                           'numpy.polynomial.legendre.Legendre.cast': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.Legendre.cast.html#numpy.polynomial.legendre.Legendre.cast',
                                           'numpy.polynomial.legendre.Legendre.convert': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.Legendre.convert.html#numpy.polynomial.legendre.Legendre.convert',
                                           'numpy.polynomial.legendre.Legendre.copy': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.Legendre.copy.html#numpy.polynomial.legendre.Legendre.copy',
                                           'numpy.polynomial.legendre.Legendre.cutdeg': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.Legendre.cutdeg.html#numpy.polynomial.legendre.Legendre.cutdeg',
                                           'numpy.polynomial.legendre.Legendre.degree': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.Legendre.degree.html#numpy.polynomial.legendre.Legendre.degree',
                                           'numpy.polynomial.legendre.Legendre.deriv': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.Legendre.deriv.html#numpy.polynomial.legendre.Legendre.deriv',
                                           'numpy.polynomial.legendre.Legendre.fit': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.Legendre.fit.html#numpy.polynomial.legendre.Legendre.fit',
                                           'numpy.polynomial.legendre.Legendre.fromroots': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.Legendre.fromroots.html#numpy.polynomial.legendre.Legendre.fromroots',
                                           'numpy.polynomial.legendre.Legendre.has_samecoef': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.Legendre.has_samecoef.html#numpy.polynomial.legendre.Legendre.has_samecoef',
                                           'numpy.polynomial.legendre.Legendre.has_samedomain': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.Legendre.has_samedomain.html#numpy.polynomial.legendre.Legendre.has_samedomain',
                                           'numpy.polynomial.legendre.Legendre.has_sametype': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.Legendre.has_sametype.html#numpy.polynomial.legendre.Legendre.has_sametype',
                                           'numpy.polynomial.legendre.Legendre.has_samewindow': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.Legendre.has_samewindow.html#numpy.polynomial.legendre.Legendre.has_samewindow',
                                           'numpy.polynomial.legendre.Legendre.identity': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.Legendre.identity.html#numpy.polynomial.legendre.Legendre.identity',
                                           'numpy.polynomial.legendre.Legendre.integ': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.Legendre.integ.html#numpy.polynomial.legendre.Legendre.integ',
                                           'numpy.polynomial.legendre.Legendre.linspace': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.Legendre.linspace.html#numpy.polynomial.legendre.Legendre.linspace',
                                           'numpy.polynomial.legendre.Legendre.mapparms': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.Legendre.mapparms.html#numpy.polynomial.legendre.Legendre.mapparms',
                                           'numpy.polynomial.legendre.Legendre.roots': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.Legendre.roots.html#numpy.polynomial.legendre.Legendre.roots',
                                           'numpy.polynomial.legendre.Legendre.trim': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.Legendre.trim.html#numpy.polynomial.legendre.Legendre.trim',
                                           'numpy.polynomial.legendre.Legendre.truncate': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.Legendre.truncate.html#numpy.polynomial.legendre.Legendre.truncate',
                                           'numpy.polynomial.legendre.leg2poly': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.leg2poly.html#numpy.polynomial.legendre.leg2poly',
                                           'numpy.polynomial.legendre.legadd': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.legadd.html#numpy.polynomial.legendre.legadd',
                                           'numpy.polynomial.legendre.legcompanion': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.legcompanion.html#numpy.polynomial.legendre.legcompanion',
                                           'numpy.polynomial.legendre.legder': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.legder.html#numpy.polynomial.legendre.legder',
                                           'numpy.polynomial.legendre.legdiv': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.legdiv.html#numpy.polynomial.legendre.legdiv',
                                           'numpy.polynomial.legendre.legfit': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.legfit.html#numpy.polynomial.legendre.legfit',
                                           'numpy.polynomial.legendre.legfromroots': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.legfromroots.html#numpy.polynomial.legendre.legfromroots',
                                           'numpy.polynomial.legendre.leggauss': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.leggauss.html#numpy.polynomial.legendre.leggauss',
                                           'numpy.polynomial.legendre.leggrid2d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.leggrid2d.html#numpy.polynomial.legendre.leggrid2d',
                                           'numpy.polynomial.legendre.leggrid3d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.leggrid3d.html#numpy.polynomial.legendre.leggrid3d',
                                           'numpy.polynomial.legendre.legint': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.legint.html#numpy.polynomial.legendre.legint',
                                           'numpy.polynomial.legendre.legline': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.legline.html#numpy.polynomial.legendre.legline',
                                           'numpy.polynomial.legendre.legmul': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.legmul.html#numpy.polynomial.legendre.legmul',
                                           'numpy.polynomial.legendre.legmulx': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.legmulx.html#numpy.polynomial.legendre.legmulx',
                                           'numpy.polynomial.legendre.legpow': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.legpow.html#numpy.polynomial.legendre.legpow',
                                           'numpy.polynomial.legendre.legroots': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.legroots.html#numpy.polynomial.legendre.legroots',
                                           'numpy.polynomial.legendre.legsub': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.legsub.html#numpy.polynomial.legendre.legsub',
                                           'numpy.polynomial.legendre.legtrim': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.legtrim.html#numpy.polynomial.legendre.legtrim',
                                           'numpy.polynomial.legendre.legval': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.legval.html#numpy.polynomial.legendre.legval',
                                           'numpy.polynomial.legendre.legval2d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.legval2d.html#numpy.polynomial.legendre.legval2d',
                                           'numpy.polynomial.legendre.legval3d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.legval3d.html#numpy.polynomial.legendre.legval3d',
                                           'numpy.polynomial.legendre.legvander': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.legvander.html#numpy.polynomial.legendre.legvander',
                                           'numpy.polynomial.legendre.legvander2d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.legvander2d.html#numpy.polynomial.legendre.legvander2d',
                                           'numpy.polynomial.legendre.legvander3d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.legvander3d.html#numpy.polynomial.legendre.legvander3d',
                                           'numpy.polynomial.legendre.legweight': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.legweight.html#numpy.polynomial.legendre.legweight',
                                           'numpy.polynomial.legendre.poly2leg': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.legendre.poly2leg.html#numpy.polynomial.legendre.poly2leg'},
            'numpy.polynomial.polynomial': { 'numpy.polynomial.polynomial.Polynomial': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.Polynomial.html#numpy.polynomial.polynomial.Polynomial',
                                             'numpy.polynomial.polynomial.Polynomial.__call__': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.Polynomial.__call__.html#numpy.polynomial.polynomial.Polynomial.__call__',
                                             'numpy.polynomial.polynomial.Polynomial.basis': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.Polynomial.basis.html#numpy.polynomial.polynomial.Polynomial.basis',
                                             'numpy.polynomial.polynomial.Polynomial.cast': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.Polynomial.cast.html#numpy.polynomial.polynomial.Polynomial.cast',
                                             'numpy.polynomial.polynomial.Polynomial.convert': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.Polynomial.convert.html#numpy.polynomial.polynomial.Polynomial.convert',
                                             'numpy.polynomial.polynomial.Polynomial.copy': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.Polynomial.copy.html#numpy.polynomial.polynomial.Polynomial.copy',
                                             'numpy.polynomial.polynomial.Polynomial.cutdeg': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.Polynomial.cutdeg.html#numpy.polynomial.polynomial.Polynomial.cutdeg',
                                             'numpy.polynomial.polynomial.Polynomial.degree': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.Polynomial.degree.html#numpy.polynomial.polynomial.Polynomial.degree',
                                             'numpy.polynomial.polynomial.Polynomial.deriv': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.Polynomial.deriv.html#numpy.polynomial.polynomial.Polynomial.deriv',
                                             'numpy.polynomial.polynomial.Polynomial.fit': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.Polynomial.fit.html#numpy.polynomial.polynomial.Polynomial.fit',
                                             'numpy.polynomial.polynomial.Polynomial.fromroots': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.Polynomial.fromroots.html#numpy.polynomial.polynomial.Polynomial.fromroots',
                                             'numpy.polynomial.polynomial.Polynomial.has_samecoef': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.Polynomial.has_samecoef.html#numpy.polynomial.polynomial.Polynomial.has_samecoef',
                                             'numpy.polynomial.polynomial.Polynomial.has_samedomain': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.Polynomial.has_samedomain.html#numpy.polynomial.polynomial.Polynomial.has_samedomain',
                                             'numpy.polynomial.polynomial.Polynomial.has_sametype': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.Polynomial.has_sametype.html#numpy.polynomial.polynomial.Polynomial.has_sametype',
                                             'numpy.polynomial.polynomial.Polynomial.has_samewindow': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.Polynomial.has_samewindow.html#numpy.polynomial.polynomial.Polynomial.has_samewindow',
                                             'numpy.polynomial.polynomial.Polynomial.identity': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.Polynomial.identity.html#numpy.polynomial.polynomial.Polynomial.identity',
                                             'numpy.polynomial.polynomial.Polynomial.integ': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.Polynomial.integ.html#numpy.polynomial.polynomial.Polynomial.integ',
                                             'numpy.polynomial.polynomial.Polynomial.linspace': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.Polynomial.linspace.html#numpy.polynomial.polynomial.Polynomial.linspace',
                                             'numpy.polynomial.polynomial.Polynomial.mapparms': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.Polynomial.mapparms.html#numpy.polynomial.polynomial.Polynomial.mapparms',
                                             'numpy.polynomial.polynomial.Polynomial.roots': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.Polynomial.roots.html#numpy.polynomial.polynomial.Polynomial.roots',
                                             'numpy.polynomial.polynomial.Polynomial.trim': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.Polynomial.trim.html#numpy.polynomial.polynomial.Polynomial.trim',
                                             'numpy.polynomial.polynomial.Polynomial.truncate': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.Polynomial.truncate.html#numpy.polynomial.polynomial.Polynomial.truncate',
                                             'numpy.polynomial.polynomial.polyadd': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.polyadd.html#numpy.polynomial.polynomial.polyadd',
                                             'numpy.polynomial.polynomial.polycompanion': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.polycompanion.html#numpy.polynomial.polynomial.polycompanion',
                                             'numpy.polynomial.polynomial.polyder': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.polyder.html#numpy.polynomial.polynomial.polyder',
                                             'numpy.polynomial.polynomial.polydiv': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.polydiv.html#numpy.polynomial.polynomial.polydiv',
                                             'numpy.polynomial.polynomial.polyfit': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.polyfit.html#numpy.polynomial.polynomial.polyfit',
                                             'numpy.polynomial.polynomial.polyfromroots': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.polyfromroots.html#numpy.polynomial.polynomial.polyfromroots',
                                             'numpy.polynomial.polynomial.polygrid2d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.polygrid2d.html#numpy.polynomial.polynomial.polygrid2d',
                                             'numpy.polynomial.polynomial.polygrid3d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.polygrid3d.html#numpy.polynomial.polynomial.polygrid3d',
                                             'numpy.polynomial.polynomial.polyint': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.polyint.html#numpy.polynomial.polynomial.polyint',
                                             'numpy.polynomial.polynomial.polyline': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.polyline.html#numpy.polynomial.polynomial.polyline',
                                             'numpy.polynomial.polynomial.polymul': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.polymul.html#numpy.polynomial.polynomial.polymul',
                                             'numpy.polynomial.polynomial.polymulx': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.polymulx.html#numpy.polynomial.polynomial.polymulx',
                                             'numpy.polynomial.polynomial.polypow': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.polypow.html#numpy.polynomial.polynomial.polypow',
                                             'numpy.polynomial.polynomial.polyroots': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.polyroots.html#numpy.polynomial.polynomial.polyroots',
                                             'numpy.polynomial.polynomial.polysub': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.polysub.html#numpy.polynomial.polynomial.polysub',
                                             'numpy.polynomial.polynomial.polytrim': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.polytrim.html#numpy.polynomial.polynomial.polytrim',
                                             'numpy.polynomial.polynomial.polyval': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.polyval.html#numpy.polynomial.polynomial.polyval',
                                             'numpy.polynomial.polynomial.polyval2d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.polyval2d.html#numpy.polynomial.polynomial.polyval2d',
                                             'numpy.polynomial.polynomial.polyval3d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.polyval3d.html#numpy.polynomial.polynomial.polyval3d',
                                             'numpy.polynomial.polynomial.polyvalfromroots': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.polyvalfromroots.html#numpy.polynomial.polynomial.polyvalfromroots',
                                             'numpy.polynomial.polynomial.polyvander': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.polyvander.html#numpy.polynomial.polynomial.polyvander',
                                             'numpy.polynomial.polynomial.polyvander2d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.polyvander2d.html#numpy.polynomial.polynomial.polyvander2d',
                                             'numpy.polynomial.polynomial.polyvander3d': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polynomial.polyvander3d.html#numpy.polynomial.polynomial.polyvander3d'},
            'numpy.polynomial.polyutils': { 'numpy.polynomial.polyutils.as_series': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polyutils.as_series.html#numpy.polynomial.polyutils.as_series',
                                            'numpy.polynomial.polyutils.getdomain': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polyutils.getdomain.html#numpy.polynomial.polyutils.getdomain',
                                            'numpy.polynomial.polyutils.mapdomain': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polyutils.mapdomain.html#numpy.polynomial.polyutils.mapdomain',
                                            'numpy.polynomial.polyutils.mapparms': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polyutils.mapparms.html#numpy.polynomial.polyutils.mapparms',
                                            'numpy.polynomial.polyutils.trimcoef': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polyutils.trimcoef.html#numpy.polynomial.polyutils.trimcoef',
                                            'numpy.polynomial.polyutils.trimseq': 'https://numpy.org/doc/stable/reference/generated/numpy.polynomial.polyutils.trimseq.html#numpy.polynomial.polyutils.trimseq'},
            'numpy.random': { 'numpy.random.BitGenerator': 'https://numpy.org/doc/stable/reference/random/bit_generators/generated/numpy.random.BitGenerator.html#numpy.random.BitGenerator',
                              'numpy.random.BitGenerator.random_raw': 'https://numpy.org/doc/stable/reference/random/bit_generators/generated/numpy.random.BitGenerator.random_raw.html#numpy.random.BitGenerator.random_raw',
                              'numpy.random.Generator': 'https://numpy.org/doc/stable/reference/random/generator.html#numpy.random.Generator',
                              'numpy.random.Generator.beta': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.beta.html#numpy.random.Generator.beta',
                              'numpy.random.Generator.binomial': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.binomial.html#numpy.random.Generator.binomial',
                              'numpy.random.Generator.bytes': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.bytes.html#numpy.random.Generator.bytes',
                              'numpy.random.Generator.chisquare': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.chisquare.html#numpy.random.Generator.chisquare',
                              'numpy.random.Generator.choice': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.choice.html#numpy.random.Generator.choice',
                              'numpy.random.Generator.dirichlet': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.dirichlet.html#numpy.random.Generator.dirichlet',
                              'numpy.random.Generator.exponential': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.exponential.html#numpy.random.Generator.exponential',
                              'numpy.random.Generator.f': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.f.html#numpy.random.Generator.f',
                              'numpy.random.Generator.gamma': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.gamma.html#numpy.random.Generator.gamma',
                              'numpy.random.Generator.geometric': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.geometric.html#numpy.random.Generator.geometric',
                              'numpy.random.Generator.gumbel': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.gumbel.html#numpy.random.Generator.gumbel',
                              'numpy.random.Generator.hypergeometric': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.hypergeometric.html#numpy.random.Generator.hypergeometric',
                              'numpy.random.Generator.integers': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.integers.html#numpy.random.Generator.integers',
                              'numpy.random.Generator.laplace': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.laplace.html#numpy.random.Generator.laplace',
                              'numpy.random.Generator.logistic': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.logistic.html#numpy.random.Generator.logistic',
                              'numpy.random.Generator.lognormal': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.lognormal.html#numpy.random.Generator.lognormal',
                              'numpy.random.Generator.logseries': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.logseries.html#numpy.random.Generator.logseries',
                              'numpy.random.Generator.multinomial': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.multinomial.html#numpy.random.Generator.multinomial',
                              'numpy.random.Generator.multivariate_hypergeometric': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.multivariate_hypergeometric.html#numpy.random.Generator.multivariate_hypergeometric',
                              'numpy.random.Generator.multivariate_normal': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.multivariate_normal.html#numpy.random.Generator.multivariate_normal',
                              'numpy.random.Generator.negative_binomial': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.negative_binomial.html#numpy.random.Generator.negative_binomial',
                              'numpy.random.Generator.noncentral_chisquare': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.noncentral_chisquare.html#numpy.random.Generator.noncentral_chisquare',
                              'numpy.random.Generator.noncentral_f': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.noncentral_f.html#numpy.random.Generator.noncentral_f',
                              'numpy.random.Generator.normal': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.normal.html#numpy.random.Generator.normal',
                              'numpy.random.Generator.pareto': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.pareto.html#numpy.random.Generator.pareto',
                              'numpy.random.Generator.permutation': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.permutation.html#numpy.random.Generator.permutation',
                              'numpy.random.Generator.permuted': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.permuted.html#numpy.random.Generator.permuted',
                              'numpy.random.Generator.poisson': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.poisson.html#numpy.random.Generator.poisson',
                              'numpy.random.Generator.power': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.power.html#numpy.random.Generator.power',
                              'numpy.random.Generator.random': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.random.html#numpy.random.Generator.random',
                              'numpy.random.Generator.rayleigh': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.rayleigh.html#numpy.random.Generator.rayleigh',
                              'numpy.random.Generator.shuffle': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.shuffle.html#numpy.random.Generator.shuffle',
                              'numpy.random.Generator.standard_cauchy': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.standard_cauchy.html#numpy.random.Generator.standard_cauchy',
                              'numpy.random.Generator.standard_exponential': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.standard_exponential.html#numpy.random.Generator.standard_exponential',
                              'numpy.random.Generator.standard_gamma': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.standard_gamma.html#numpy.random.Generator.standard_gamma',
                              'numpy.random.Generator.standard_normal': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.standard_normal.html#numpy.random.Generator.standard_normal',
                              'numpy.random.Generator.standard_t': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.standard_t.html#numpy.random.Generator.standard_t',
                              'numpy.random.Generator.triangular': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.triangular.html#numpy.random.Generator.triangular',
                              'numpy.random.Generator.uniform': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.uniform.html#numpy.random.Generator.uniform',
                              'numpy.random.Generator.vonmises': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.vonmises.html#numpy.random.Generator.vonmises',
                              'numpy.random.Generator.wald': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.wald.html#numpy.random.Generator.wald',
                              'numpy.random.Generator.weibull': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.weibull.html#numpy.random.Generator.weibull',
                              'numpy.random.Generator.zipf': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.Generator.zipf.html#numpy.random.Generator.zipf',
                              'numpy.random.MT19937': 'https://numpy.org/doc/stable/reference/random/bit_generators/mt19937.html#numpy.random.MT19937',
                              'numpy.random.MT19937.jumped': 'https://numpy.org/doc/stable/reference/random/bit_generators/generated/numpy.random.MT19937.jumped.html#numpy.random.MT19937.jumped',
                              'numpy.random.PCG64': 'https://numpy.org/doc/stable/reference/random/bit_generators/pcg64.html#numpy.random.PCG64',
                              'numpy.random.PCG64.advance': 'https://numpy.org/doc/stable/reference/random/bit_generators/generated/numpy.random.PCG64.advance.html#numpy.random.PCG64.advance',
                              'numpy.random.PCG64.jumped': 'https://numpy.org/doc/stable/reference/random/bit_generators/generated/numpy.random.PCG64.jumped.html#numpy.random.PCG64.jumped',
                              'numpy.random.PCG64DXSM': 'https://numpy.org/doc/stable/reference/random/bit_generators/pcg64dxsm.html#numpy.random.PCG64DXSM',
                              'numpy.random.PCG64DXSM.advance': 'https://numpy.org/doc/stable/reference/random/bit_generators/generated/numpy.random.PCG64DXSM.advance.html#numpy.random.PCG64DXSM.advance',
                              'numpy.random.PCG64DXSM.jumped': 'https://numpy.org/doc/stable/reference/random/bit_generators/generated/numpy.random.PCG64DXSM.jumped.html#numpy.random.PCG64DXSM.jumped',
                              'numpy.random.Philox': 'https://numpy.org/doc/stable/reference/random/bit_generators/philox.html#numpy.random.Philox',
                              'numpy.random.Philox.advance': 'https://numpy.org/doc/stable/reference/random/bit_generators/generated/numpy.random.Philox.advance.html#numpy.random.Philox.advance',
                              'numpy.random.Philox.jumped': 'https://numpy.org/doc/stable/reference/random/bit_generators/generated/numpy.random.Philox.jumped.html#numpy.random.Philox.jumped',
                              'numpy.random.RandomState': 'https://numpy.org/doc/stable/reference/random/legacy.html#numpy.random.RandomState',
                              'numpy.random.RandomState.beta': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.beta.html#numpy.random.RandomState.beta',
                              'numpy.random.RandomState.binomial': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.binomial.html#numpy.random.RandomState.binomial',
                              'numpy.random.RandomState.bytes': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.bytes.html#numpy.random.RandomState.bytes',
                              'numpy.random.RandomState.chisquare': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.chisquare.html#numpy.random.RandomState.chisquare',
                              'numpy.random.RandomState.choice': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.choice.html#numpy.random.RandomState.choice',
                              'numpy.random.RandomState.dirichlet': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.dirichlet.html#numpy.random.RandomState.dirichlet',
                              'numpy.random.RandomState.exponential': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.exponential.html#numpy.random.RandomState.exponential',
                              'numpy.random.RandomState.f': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.f.html#numpy.random.RandomState.f',
                              'numpy.random.RandomState.gamma': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.gamma.html#numpy.random.RandomState.gamma',
                              'numpy.random.RandomState.geometric': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.geometric.html#numpy.random.RandomState.geometric',
                              'numpy.random.RandomState.get_state': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.get_state.html#numpy.random.RandomState.get_state',
                              'numpy.random.RandomState.gumbel': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.gumbel.html#numpy.random.RandomState.gumbel',
                              'numpy.random.RandomState.hypergeometric': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.hypergeometric.html#numpy.random.RandomState.hypergeometric',
                              'numpy.random.RandomState.laplace': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.laplace.html#numpy.random.RandomState.laplace',
                              'numpy.random.RandomState.logistic': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.logistic.html#numpy.random.RandomState.logistic',
                              'numpy.random.RandomState.lognormal': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.lognormal.html#numpy.random.RandomState.lognormal',
                              'numpy.random.RandomState.logseries': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.logseries.html#numpy.random.RandomState.logseries',
                              'numpy.random.RandomState.multinomial': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.multinomial.html#numpy.random.RandomState.multinomial',
                              'numpy.random.RandomState.multivariate_normal': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.multivariate_normal.html#numpy.random.RandomState.multivariate_normal',
                              'numpy.random.RandomState.negative_binomial': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.negative_binomial.html#numpy.random.RandomState.negative_binomial',
                              'numpy.random.RandomState.noncentral_chisquare': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.noncentral_chisquare.html#numpy.random.RandomState.noncentral_chisquare',
                              'numpy.random.RandomState.noncentral_f': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.noncentral_f.html#numpy.random.RandomState.noncentral_f',
                              'numpy.random.RandomState.normal': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.normal.html#numpy.random.RandomState.normal',
                              'numpy.random.RandomState.pareto': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.pareto.html#numpy.random.RandomState.pareto',
                              'numpy.random.RandomState.permutation': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.permutation.html#numpy.random.RandomState.permutation',
                              'numpy.random.RandomState.poisson': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.poisson.html#numpy.random.RandomState.poisson',
                              'numpy.random.RandomState.power': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.power.html#numpy.random.RandomState.power',
                              'numpy.random.RandomState.rand': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.rand.html#numpy.random.RandomState.rand',
                              'numpy.random.RandomState.randint': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.randint.html#numpy.random.RandomState.randint',
                              'numpy.random.RandomState.randn': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.randn.html#numpy.random.RandomState.randn',
                              'numpy.random.RandomState.random_integers': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.random_integers.html#numpy.random.RandomState.random_integers',
                              'numpy.random.RandomState.random_sample': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.random_sample.html#numpy.random.RandomState.random_sample',
                              'numpy.random.RandomState.rayleigh': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.rayleigh.html#numpy.random.RandomState.rayleigh',
                              'numpy.random.RandomState.seed': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.seed.html#numpy.random.RandomState.seed',
                              'numpy.random.RandomState.set_state': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.set_state.html#numpy.random.RandomState.set_state',
                              'numpy.random.RandomState.shuffle': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.shuffle.html#numpy.random.RandomState.shuffle',
                              'numpy.random.RandomState.standard_cauchy': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.standard_cauchy.html#numpy.random.RandomState.standard_cauchy',
                              'numpy.random.RandomState.standard_exponential': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.standard_exponential.html#numpy.random.RandomState.standard_exponential',
                              'numpy.random.RandomState.standard_gamma': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.standard_gamma.html#numpy.random.RandomState.standard_gamma',
                              'numpy.random.RandomState.standard_normal': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.standard_normal.html#numpy.random.RandomState.standard_normal',
                              'numpy.random.RandomState.standard_t': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.standard_t.html#numpy.random.RandomState.standard_t',
                              'numpy.random.RandomState.triangular': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.triangular.html#numpy.random.RandomState.triangular',
                              'numpy.random.RandomState.uniform': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.uniform.html#numpy.random.RandomState.uniform',
                              'numpy.random.RandomState.vonmises': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.vonmises.html#numpy.random.RandomState.vonmises',
                              'numpy.random.RandomState.wald': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.wald.html#numpy.random.RandomState.wald',
                              'numpy.random.RandomState.weibull': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.weibull.html#numpy.random.RandomState.weibull',
                              'numpy.random.RandomState.zipf': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.RandomState.zipf.html#numpy.random.RandomState.zipf',
                              'numpy.random.SFC64': 'https://numpy.org/doc/stable/reference/random/bit_generators/sfc64.html#numpy.random.SFC64',
                              'numpy.random.SeedSequence': 'https://numpy.org/doc/stable/reference/random/bit_generators/generated/numpy.random.SeedSequence.html#numpy.random.SeedSequence',
                              'numpy.random.SeedSequence.generate_state': 'https://numpy.org/doc/stable/reference/random/bit_generators/generated/numpy.random.SeedSequence.generate_state.html#numpy.random.SeedSequence.generate_state',
                              'numpy.random.SeedSequence.spawn': 'https://numpy.org/doc/stable/reference/random/bit_generators/generated/numpy.random.SeedSequence.spawn.html#numpy.random.SeedSequence.spawn',
                              'numpy.random.beta': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.beta.html#numpy.random.beta',
                              'numpy.random.binomial': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.binomial.html#numpy.random.binomial',
                              'numpy.random.bytes': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.bytes.html#numpy.random.bytes',
                              'numpy.random.chisquare': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.chisquare.html#numpy.random.chisquare',
                              'numpy.random.choice': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.choice.html#numpy.random.choice',
                              'numpy.random.default_rng': 'https://numpy.org/doc/stable/reference/random/generator.html#numpy.random.default_rng',
                              'numpy.random.dirichlet': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.dirichlet.html#numpy.random.dirichlet',
                              'numpy.random.exponential': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.exponential.html#numpy.random.exponential',
                              'numpy.random.f': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.f.html#numpy.random.f',
                              'numpy.random.gamma': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.gamma.html#numpy.random.gamma',
                              'numpy.random.geometric': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.geometric.html#numpy.random.geometric',
                              'numpy.random.get_state': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.get_state.html#numpy.random.get_state',
                              'numpy.random.gumbel': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.gumbel.html#numpy.random.gumbel',
                              'numpy.random.hypergeometric': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.hypergeometric.html#numpy.random.hypergeometric',
                              'numpy.random.laplace': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.laplace.html#numpy.random.laplace',
                              'numpy.random.logistic': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.logistic.html#numpy.random.logistic',
                              'numpy.random.lognormal': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.lognormal.html#numpy.random.lognormal',
                              'numpy.random.logseries': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.logseries.html#numpy.random.logseries',
                              'numpy.random.multinomial': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.multinomial.html#numpy.random.multinomial',
                              'numpy.random.multivariate_normal': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.multivariate_normal.html#numpy.random.multivariate_normal',
                              'numpy.random.negative_binomial': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.negative_binomial.html#numpy.random.negative_binomial',
                              'numpy.random.noncentral_chisquare': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.noncentral_chisquare.html#numpy.random.noncentral_chisquare',
                              'numpy.random.noncentral_f': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.noncentral_f.html#numpy.random.noncentral_f',
                              'numpy.random.normal': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.normal.html#numpy.random.normal',
                              'numpy.random.pareto': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.pareto.html#numpy.random.pareto',
                              'numpy.random.permutation': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.permutation.html#numpy.random.permutation',
                              'numpy.random.poisson': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.poisson.html#numpy.random.poisson',
                              'numpy.random.power': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.power.html#numpy.random.power',
                              'numpy.random.rand': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.rand.html#numpy.random.rand',
                              'numpy.random.randint': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.randint.html#numpy.random.randint',
                              'numpy.random.randn': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.randn.html#numpy.random.randn',
                              'numpy.random.random': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.random.html#numpy.random.random',
                              'numpy.random.random_integers': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.random_integers.html#numpy.random.random_integers',
                              'numpy.random.random_sample': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.random_sample.html#numpy.random.random_sample',
                              'numpy.random.ranf': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.ranf.html#numpy.random.ranf',
                              'numpy.random.rayleigh': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.rayleigh.html#numpy.random.rayleigh',
                              'numpy.random.sample': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.sample.html#numpy.random.sample',
                              'numpy.random.seed': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.seed.html#numpy.random.seed',
                              'numpy.random.set_state': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.set_state.html#numpy.random.set_state',
                              'numpy.random.shuffle': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.shuffle.html#numpy.random.shuffle',
                              'numpy.random.standard_cauchy': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.standard_cauchy.html#numpy.random.standard_cauchy',
                              'numpy.random.standard_exponential': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.standard_exponential.html#numpy.random.standard_exponential',
                              'numpy.random.standard_gamma': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.standard_gamma.html#numpy.random.standard_gamma',
                              'numpy.random.standard_normal': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.standard_normal.html#numpy.random.standard_normal',
                              'numpy.random.standard_t': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.standard_t.html#numpy.random.standard_t',
                              'numpy.random.triangular': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.triangular.html#numpy.random.triangular',
                              'numpy.random.uniform': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.uniform.html#numpy.random.uniform',
                              'numpy.random.vonmises': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.vonmises.html#numpy.random.vonmises',
                              'numpy.random.wald': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.wald.html#numpy.random.wald',
                              'numpy.random.weibull': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.weibull.html#numpy.random.weibull',
                              'numpy.random.zipf': 'https://numpy.org/doc/stable/reference/random/generated/numpy.random.zipf.html#numpy.random.zipf'},
            'numpy.random._generator': { 'numpy.random._generator.Generator': 'https://numpy.org/doc/stable/reference/random/generator.html#numpy.random.Generator'},
            'numpy.random._mt19937': { 'numpy.random._mt19937.MT19937': 'https://numpy.org/doc/stable/reference/random/bit_generators/mt19937.html#numpy.random.MT19937'},
            'numpy.random._pcg64': { 'numpy.random._pcg64.PCG64': 'https://numpy.org/doc/stable/reference/random/bit_generators/pcg64.html#numpy.random.PCG64',
                                     'numpy.random._pcg64.PCG64DXSM': 'https://numpy.org/doc/stable/reference/random/bit_generators/pcg64dxsm.html#numpy.random.PCG64DXSM'},
            'numpy.random._philox': { 'numpy.random._philox.Philox': 'https://numpy.org/doc/stable/reference/random/bit_generators/philox.html#numpy.random.Philox'},
            'numpy.random._sfc64': {'numpy.random._sfc64.SFC64': 'https://numpy.org/doc/stable/reference/random/bit_generators/sfc64.html#numpy.random.SFC64'},
            'numpy.random.bit_generator': { 'numpy.random.bit_generator.BitGenerator': 'https://numpy.org/doc/stable/reference/random/bit_generators/generated/numpy.random.BitGenerator.html#numpy.random.BitGenerator',
                                            'numpy.random.bit_generator.SeedSequence': 'https://numpy.org/doc/stable/reference/random/bit_generators/generated/numpy.random.SeedSequence.html#numpy.random.SeedSequence'},
            'numpy.random.mtrand': {'numpy.random.mtrand.RandomState': 'https://numpy.org/doc/stable/reference/random/legacy.html#numpy.random.RandomState'},
            'numpy.testing': { 'numpy.testing.Tester.bench': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.Tester.bench.html#numpy.testing.Tester.bench',
                               'numpy.testing.Tester.prepare_test_args': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.Tester.prepare_test_args.html#numpy.testing.Tester.prepare_test_args',
                               'numpy.testing.Tester.test': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.Tester.test.html#numpy.testing.Tester.test',
                               'numpy.testing.assert_': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.assert_.html#numpy.testing.assert_',
                               'numpy.testing.assert_allclose': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.assert_allclose.html#numpy.testing.assert_allclose',
                               'numpy.testing.assert_almost_equal': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.assert_almost_equal.html#numpy.testing.assert_almost_equal',
                               'numpy.testing.assert_approx_equal': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.assert_approx_equal.html#numpy.testing.assert_approx_equal',
                               'numpy.testing.assert_array_almost_equal': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.assert_array_almost_equal.html#numpy.testing.assert_array_almost_equal',
                               'numpy.testing.assert_array_almost_equal_nulp': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.assert_array_almost_equal_nulp.html#numpy.testing.assert_array_almost_equal_nulp',
                               'numpy.testing.assert_array_equal': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.assert_array_equal.html#numpy.testing.assert_array_equal',
                               'numpy.testing.assert_array_less': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.assert_array_less.html#numpy.testing.assert_array_less',
                               'numpy.testing.assert_array_max_ulp': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.assert_array_max_ulp.html#numpy.testing.assert_array_max_ulp',
                               'numpy.testing.assert_equal': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.assert_equal.html#numpy.testing.assert_equal',
                               'numpy.testing.assert_no_gc_cycles': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.assert_no_gc_cycles.html#numpy.testing.assert_no_gc_cycles',
                               'numpy.testing.assert_no_warnings': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.assert_no_warnings.html#numpy.testing.assert_no_warnings',
                               'numpy.testing.assert_raises': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.assert_raises.html#numpy.testing.assert_raises',
                               'numpy.testing.assert_raises_regex': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.assert_raises_regex.html#numpy.testing.assert_raises_regex',
                               'numpy.testing.assert_string_equal': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.assert_string_equal.html#numpy.testing.assert_string_equal',
                               'numpy.testing.assert_warns': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.assert_warns.html#numpy.testing.assert_warns',
                               'numpy.testing.clear_and_catch_warnings': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.clear_and_catch_warnings.html#numpy.testing.clear_and_catch_warnings',
                               'numpy.testing.decorate_methods': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.decorate_methods.html#numpy.testing.decorate_methods',
                               'numpy.testing.measure': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.measure.html#numpy.testing.measure',
                               'numpy.testing.print_assert_equal': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.print_assert_equal.html#numpy.testing.print_assert_equal',
                               'numpy.testing.run_module_suite': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.run_module_suite.html#numpy.testing.run_module_suite',
                               'numpy.testing.rundocs': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.rundocs.html#numpy.testing.rundocs',
                               'numpy.testing.suppress_warnings': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.suppress_warnings.html#numpy.testing.suppress_warnings',
                               'numpy.testing.suppress_warnings.__call__': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.suppress_warnings.__call__.html#numpy.testing.suppress_warnings.__call__',
                               'numpy.testing.suppress_warnings.filter': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.suppress_warnings.filter.html#numpy.testing.suppress_warnings.filter',
                               'numpy.testing.suppress_warnings.record': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.suppress_warnings.record.html#numpy.testing.suppress_warnings.record'},
            'numpy.testing._private.utils': { 'numpy.testing._private.utils.clear_and_catch_warnings': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.clear_and_catch_warnings.html#numpy.testing.clear_and_catch_warnings',
                                              'numpy.testing._private.utils.suppress_warnings': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.suppress_warnings.html#numpy.testing.suppress_warnings'},
            'numpy.testing.dec': { 'numpy.testing.dec.deprecated': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.dec.deprecated.html#numpy.testing.dec.deprecated',
                                   'numpy.testing.dec.knownfailureif': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.dec.knownfailureif.html#numpy.testing.dec.knownfailureif',
                                   'numpy.testing.dec.setastest': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.dec.setastest.html#numpy.testing.dec.setastest',
                                   'numpy.testing.dec.skipif': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.dec.skipif.html#numpy.testing.dec.skipif',
                                   'numpy.testing.dec.slow': 'https://numpy.org/doc/stable/reference/generated/numpy.testing.dec.slow.html#numpy.testing.dec.slow'},
            'numpy.testing.extbuild': { 'numpy.testing.extbuild.build_and_import_extension': 'https://numpy.org/doc/stable/reference/testing.html#numpy.testing.extbuild.build_and_import_extension'},
            'numpy.typing': { 'numpy.typing.NBitBase': 'https://numpy.org/doc/stable/reference/typing.html#numpy.typing.NBitBase',
                              'numpy.typing.mypy_plugin': 'https://numpy.org/doc/stable/reference/typing.html#module-numpy.typing.mypy_plugin'}}}
